<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\daisy\Customizer;
/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Customizer {
	// Get our default values
	protected $defaults;
    protected static $instance = null;

	public function __construct() {
        // Get our Customizer defaults
		// Register Panels
		add_action( 'customize_register', array( $this, 'add_customizer_panels' ) );
		// Register sections
		add_action( 'customize_register', array( $this, 'add_customizer_sections' ) );
	}

    public static function instance() {
        if (null == self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    public function populated_default_data() {
        $this->defaults = rttheme_generate_defaults();
    }

	/**
	 * Customizer Panels
	 */
	public function add_customizer_panels( $wp_customize ) {

	    // Add Layput Panel
		$wp_customize->add_panel( 'rttheme_layouts_defaults',
		 	array(
				'title' => __( 'Layout Settings', 'daisy' ),
				'description' => esc_html__( 'Adjust the overall layout for your site.', 'daisy' ),
				'priority' => 5,
			)
		);

        // Add General Panel
        $wp_customize->add_panel( 'rttheme_blog_settings',
            array(
                'title' => __( 'Blog Settings', 'daisy' ),
                'description' => esc_html__( 'Adjust the overall layout for your site.', 'daisy' ),
                'priority' => 6,
            )
        );

        // Custom Post Types Panel
        $wp_customize->add_panel( 'rttheme_cpt_settings',
            array(
                'title' => esc_html__( 'Custom Posts', 'daisy' ),
                'description' => esc_html__( 'All custom posts settings here.', 'daisy' ),
                'priority' => 10,
            )
        );
		
	}

    /**
    * Customizer sections
    */
	public function add_customizer_sections( $wp_customize ) {

		// Rename the default Colors section
		$wp_customize->get_section( 'colors' )->title = 'Background';

		// Move the default Colors section to our new Colors Panel
		$wp_customize->get_section( 'colors' )->panel = 'colors_panel';

		// Change the Priority of the default Colors section so it's at the top of our Panel
		$wp_customize->get_section( 'colors' )->priority = 10;

		// Add General Section
		$wp_customize->add_section( 'general_section',
			array(
				'title' => __( 'General', 'daisy' ),
				'priority' => 1,
			)
		);

		// Add Header Main Section
		$wp_customize->add_section( 'header_section',
			array(
				'title' => __( 'Header', 'daisy' ),
				'priority' => 3,
			)
		);

        // Add Footer Section
        $wp_customize->add_section( 'footer_section',
            array(
                'title' => __( 'Footer', 'daisy' ),
                'priority' => 4,
            )
        );
        // Add Pages Layout Section
        $wp_customize->add_section( 'page_layout_section',
            array(
                'title' => __( 'Pages Layout', 'daisy' ),
                'panel' => 'rttheme_layouts_defaults',
            )
        );

        // Add Single Pages Layout Section
        $wp_customize->add_section( 'single_post_layout_section',
            array(
                'title' => __( 'Single Post Layout', 'daisy' ),
                'panel' => 'rttheme_layouts_defaults',
            )
        );

        // Add Blog Settings Section
        $wp_customize->add_section( 'blog_post_settings_section',
            array(
                'title' => __( 'Blog Settings', 'daisy' ),
                'priority' => 7,
                'panel' => 'rttheme_blog_settings',
            )
        );
        // Add Single Blog Settings Section
        $wp_customize->add_section( 'single_post_secttings_section',
            array(
                'title' => esc_html__( 'Single Post Settings', 'daisy' ),
                'priority' => 8,
                'panel' => 'rttheme_blog_settings',
            )
        );
        // Portfolio Archive Section
        $wp_customize->add_section( 'portfolio_section',
            array(
                'title' => __( 'Portfolio', 'daisy' ),
                'priority' => 9,
                'panel'    => 'rttheme_cpt_settings',
            )
        );
        // Service Archive Section
        $wp_customize->add_section( 'services_section',
            array(
                'title' => __( 'Services', 'daisy' ),
                'priority' => 10,
                'panel'    => 'rttheme_cpt_settings',
            )
        );
        // Team Archive Section
        $wp_customize->add_section( 'team_section',
            array(
                'title' => __( 'Team', 'daisy' ),
                'priority' => 11,
                'panel'    => 'rttheme_cpt_settings',
            )
        );
        // Add Colors Section
        $wp_customize->add_section( 'color_section',
            array(
                'title' => __( 'Theme Colors', 'daisy' ),
                'priority' => 12,
            )
        );
        // Add Error Page Section
        $wp_customize->add_section( 'error_section',
            array(
                'title' => __( 'Error Page', 'daisy' ),
                'priority' => 13,
            )
        );

	}

}
