<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\daisy\Customizer\Settings;

use radiustheme\daisy\Customizer\RDTheme_Customizer;
use radiustheme\daisy\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Image_Radio_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Blog_Post_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_blog_post_controls' ) );
	}

    /**
     * Blog Post Controls
     */
    public function register_blog_post_controls( $wp_customize ) {

        // Blog Post Style
        $wp_customize->add_setting( 'blog_style',
            array(
                'default' => $this->defaults['blog_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );

        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'blog_style',
            array(
                'label' => __( 'Post Layout', 'daisy' ),
                'description' => esc_html__( 'Blog Post layout variation you can selecr and use.', 'daisy' ),
                'section' => 'blog_post_settings_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/blog1.jpg',
                        'name' => __( 'Layout 1', 'daisy' )
                    ),
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/blog2.jpg',
                        'name' => __( 'Layout 2', 'daisy' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/blog3.jpg',
                        'name' => __( 'Layout 3', 'daisy' )
                    )
                )
            )
        ) );

        // Post Category
        $wp_customize->add_setting( 'blog_cats',
            array(
                'default' => $this->defaults['blog_cats'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_cats',
            array(
                'label' => __( 'Display Category', 'daisy' ),
                'section' => 'blog_post_settings_section',
            )
        ) );

        // Post Tags
        $wp_customize->add_setting( 'blog_tags',
            array(
                'default' => $this->defaults['blog_tags'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_tags',
            array(
                'label' => __( 'Display Tags', 'daisy' ),
                'section' => 'blog_post_settings_section',
            )
        ) );

        // Post Date
        $wp_customize->add_setting( 'blog_date',
            array(
                'default' => $this->defaults['blog_date'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_date',
            array(
                'label' => __( 'Display Date', 'daisy' ),
                'section' => 'blog_post_settings_section',
            )
        ));

        // Comments
        $wp_customize->add_setting( 'blog_meta_comments',
            array(
                'default' => $this->defaults['blog_meta_comments'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_meta_comments',
            array(
                'label' => __( 'Display Comments', 'daisy' ),
                'section' => 'blog_post_settings_section',
            )
        ) );

         // Post Author
        $wp_customize->add_setting( 'blog_author',
            array(
                'default' => $this->defaults['blog_author'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_author',
            array(
                'label' => __( 'Display Author', 'daisy' ),
                'section' => 'blog_post_settings_section',
            )
        ) );

        // Excerpt
        $wp_customize->add_setting( 'blog_excerpt',
            array(
                'default' => $this->defaults['blog_excerpt'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'blog_excerpt',
            array(
                'label' => __( 'Display Excerpt', 'daisy' ),
                'section' => 'blog_post_settings_section',
            )
        ) );

        // Excerpt Length
        $wp_customize->add_setting( 'excerpt_length',
            array(
                'default' => $this->defaults['excerpt_length'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer'
            )
        );
        $wp_customize->add_control( 'excerpt_length',
            array(
                'label' => __( 'Excerpt Length', 'daisy' ),
                'section' => 'blog_post_settings_section',
                'type' => 'number',
            )
        );


        /*Animation*/
        $wp_customize->add_setting( 'blog_animation',
            array(
                'default' => $this->defaults['blog_animation'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
            )
        );
        $wp_customize->add_control( 'blog_animation',
            array(
                'label' => __( 'Animation On/Off', 'daisy' ),
                'section' => 'blog_post_settings_section',
                'type' => 'select',
                'choices' => array(
                    'wow' => esc_html__( 'Animation On', 'daisy' ),
                    'hide' => esc_html__( 'Animation Off', 'daisy' ),
                ),
            )
        );

        $wp_customize->add_setting( 'blog_animation_effect',
            array(
                'default' => $this->defaults['blog_animation_effect'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
            )
        );
        $wp_customize->add_control( 'blog_animation_effect',
            array(
                'label' => __( 'Entrance Animation', 'daisy' ),
                'section' => 'blog_post_settings_section',
                'type' => 'select',
                'choices' => array(
                    'none' => esc_html__( 'none', 'daisy' ),
                    'bounce' => esc_html__( 'bounce', 'daisy' ),
                    'flash' => esc_html__( 'flash', 'daisy' ),
                    'pulse' => esc_html__( 'pulse', 'daisy' ),
                    'rubberBand' => esc_html__( 'rubberBand', 'daisy' ),
                    'shakeX' => esc_html__( 'shakeX', 'daisy' ),
                    'shakeY' => esc_html__( 'shakeY', 'daisy' ),
                    'headShake' => esc_html__( 'headShake', 'daisy' ),
                    'swing' => esc_html__( 'swing', 'daisy' ),                 
                    'fadeIn' => esc_html__( 'fadeIn', 'daisy' ),
                    'fadeInDown' => esc_html__( 'fadeInDown', 'daisy' ),
                    'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy' ),
                    'fadeInRight' => esc_html__( 'fadeInRight', 'daisy' ),
                    'fadeInUp' => esc_html__( 'fadeInUp', 'daisy' ),                   
                    'bounceIn' => esc_html__( 'bounceIn', 'daisy' ),
                    'bounceInDown' => esc_html__( 'bounceInDown', 'daisy' ),
                    'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy' ),
                    'bounceInRight' => esc_html__( 'bounceInRight', 'daisy' ),
                    'bounceInUp' => esc_html__( 'bounceInUp', 'daisy' ),           
                    'slideInDown' => esc_html__( 'slideInDown', 'daisy' ),
                    'slideInLeft' => esc_html__( 'slideInLeft', 'daisy' ),
                    'slideInRight' => esc_html__( 'slideInRight', 'daisy' ),
                    'slideInUp' => esc_html__( 'slideInUp', 'daisy' ), 
                ),
            )
        );

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Blog_Post_Settings();
}
