<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\daisy\Customizer\Settings;

use radiustheme\daisy\Customizer\RDTheme_Customizer;
use radiustheme\daisy\Customizer\Controls\Customizer_Heading_Control2;
use radiustheme\daisy\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Separator_Control;

use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Colors_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_colors_controls' ) );
	}

    public function register_colors_controls( $wp_customize ) {

        /*Global Color*/
        $wp_customize->add_setting('primary_color', 
            array(
                'default' => $this->defaults['primary_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color',
            array(
                'label' => esc_html__('Primary Color 1', 'daisy'),
                'section' => 'color_section', 
            )
        ));

        $wp_customize->add_setting('primary_color2', 
            array(
                'default' => $this->defaults['primary_color2'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color2',
            array(
                'label' => esc_html__('Primary Color 2', 'daisy'),
                'section' => 'color_section', 
            )
        ));

        $wp_customize->add_setting('primary_color3', 
            array(
                'default' => $this->defaults['primary_color3'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color3',
            array(
                'label' => esc_html__('Primary Color 3', 'daisy'),
                'section' => 'color_section', 
            )
        ));

        $wp_customize->add_setting('primary_color4', 
            array(
                'default' => $this->defaults['primary_color4'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color4',
            array(
                'label' => esc_html__('Primary Color 4', 'daisy'),
                'section' => 'color_section', 
            )
        ));
        
        $wp_customize->add_setting('secondary_color', 
            array(
                'default' => $this->defaults['secondary_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color',
            array(
                'label' => esc_html__('Secondary Color 1', 'daisy'),
                'section' => 'color_section', 
            )
        ));

        $wp_customize->add_setting('secondary_color2', 
            array(
                'default' => $this->defaults['secondary_color2'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color2',
            array(
                'label' => esc_html__('Secondary Color 2', 'daisy'),
                'section' => 'color_section', 
            )
        ));

        $wp_customize->add_setting('secondary_color3', 
            array(
                'default' => $this->defaults['secondary_color3'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color3',
            array(
                'label' => esc_html__('Secondary Color 3', 'daisy'),
                'section' => 'color_section', 
            )
        ));      
                
        $wp_customize->add_setting('body_color', 
            array(
                'default' => $this->defaults['body_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'body_color',
            array(
                'label' => esc_html__('Body Color', 'daisy'),
                'section' => 'color_section', 
            )
        ));

        /**
         * Main Menu Heading
         */
        $wp_customize->add_setting('theme_menu_style', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control2($wp_customize, 'theme_menu_style', array(
            'label' => __( 'Menu Color Settings', 'daisy' ),
            'section' => 'color_section',
        )));

        // Main Menu Font color
        $wp_customize->add_setting('menu_text_color', 
            array(
                'default' => $this->defaults['menu_text_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menu_text_color',
            array(
                'label' => esc_html__('Text Color', 'daisy'),
                'settings' => 'menu_text_color', 
                'priority' => 10, 
                'section' => 'color_section', 
            )
        ));

        // Menu Font hover color
        $wp_customize->add_setting('menu_text_hover_color', 
            array(
                'default' => $this->defaults['menu_text_hover_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menu_text_hover_color',
            array(
                'label' => esc_html__( 'Hover Text Color', 'daisy' ),
                'settings' => 'menu_text_hover_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));


        /**
         * Sub Menu Heading
         */
        $wp_customize->add_setting('sub_menu_style', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control2($wp_customize, 'sub_menu_style', array(
            'label' => __( 'Sub Menu Color Settings', 'daisy' ),
            'section' => 'color_section',
        )));


        // Sub Menu Font color
        $wp_customize->add_setting('sub_menu_text_color', 
            array(
                'default' => $this->defaults['sub_menu_text_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_text_color',
            array(
                'label' => esc_html__('Text Color', 'daisy'),
                'settings' => 'sub_menu_text_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));

        // Sub Menu Font hover color
        $wp_customize->add_setting('sub_menu_text_hover_color', 
            array(
                'default' => $this->defaults['sub_menu_text_hover_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_text_hover_color',
            array(
                'label' => esc_html__('Hover Text Color', 'daisy'),
                'settings' => 'sub_menu_text_hover_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));


        // Sub Menu Border color
        $wp_customize->add_setting('sub_menu_border_color', 
            array(
                'default' => $this->defaults['sub_menu_border_color'], 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sub_menu_border_color',
            array(
                'label' => esc_html__('Border Color', 'daisy'),
                'settings' => 'sub_menu_border_color', 
                'priority' => 10, 
                'section' => 'color_section',
            )
        ));

        // Color Mode
        $wp_customize->add_setting( 'color_mode',
            array(
                'default'           => $this->defaults['color_mode'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'color_mode',
            array(
                'label'   => __( 'Color Mode', 'daisy' ),
                'section' => 'color_section',
            )
        ) );        

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Colors_Settings();
}
