<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\daisy\Customizer\Settings;

use radiustheme\daisy\Customizer\RDTheme_Customizer;
use radiustheme\daisy\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Separator_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Error_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_error_controls' ) );
	}

    public function register_error_controls( $wp_customize ) {
        // Error Text
        $wp_customize->add_setting( 'error_text1',
            array(
                'default' => $this->defaults['error_text1'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'error_text1',
            array(
                'label' => __( 'Error Text 1', 'daisy' ),
                'section' => 'error_section',
                'type' => 'text',
            )
        );
        // Error Text
        $wp_customize->add_setting( 'error_text2',
            array(
                'default' => $this->defaults['error_text2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'error_text2',
            array(
                'label' => __( 'Error Text 2', 'daisy' ),
                'section' => 'error_section',
                'type' => 'text',
            )
        );
        // Button Text
        $wp_customize->add_setting( 'error_buttontext',
            array(
                'default' => $this->defaults['error_buttontext'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'error_buttontext',
            array(
                'label' => __( 'Button Text', 'daisy' ),
                'section' => 'error_section',
                'type' => 'text',
            )
        );
         // Image
        $wp_customize->add_setting( 'error_img',
            array(
                'default' => $this->defaults['error_img'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'error_img',
            array(
                'label' => __( 'Error Image', 'daisy' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'daisy' ),
                'section' => 'error_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'daisy' ),
                    'change' => __( 'Change File', 'daisy' ),
                    'default' => __( 'Default', 'daisy' ),
                    'remove' => __( 'Remove', 'daisy' ),
                    'placeholder' => __( 'No file selected', 'daisy' ),
                    'frame_title' => __( 'Select File', 'daisy' ),
                    'frame_button' => __( 'Choose File', 'daisy' ),
                )
            )
        ) );
        $wp_customize->add_setting('error_text1_color', 
            array(
                'default' => $this->defaults['error_text1_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_text1_color',
            array(
                'label' => esc_html__('Error Text 1 Color', 'daisy'),
                'section' => 'error_section', 
            )
        ));
        
        $wp_customize->add_setting('error_text2_color', 
            array(
                'default' => $this->defaults['error_text2_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_text2_color',
            array(
                'label' => esc_html__('Error Text 2 Color', 'daisy'),
                'section' => 'error_section', 
            )
        ));

        $wp_customize->add_setting('error_btnicon_color', 
            array(
                'default' => $this->defaults['error_btnicon_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_btnicon_color',
            array(
                'label' => esc_html__('Button Icon Color', 'daisy'),
                'section' => 'error_section', 
            )
        ));

        $wp_customize->add_setting('error_btntxt_color', 
            array(
                'default' => $this->defaults['error_btntxt_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'error_btntxt_color',
            array(
                'label' => esc_html__('Button Text Color', 'daisy'),
                'section' => 'error_section', 
            )
        ));

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Error_Settings();
}
