<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\daisy\Customizer\Settings;

use radiustheme\daisy\Customizer\RDTheme_Customizer;
use radiustheme\daisy\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Footer_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_footer_controls' ) );
	}

    public function register_footer_controls( $wp_customize ) {


        $wp_customize->add_setting( 'display_footer_animation',
            array(
                'default'           => $this->defaults['display_footer_animation'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer_animation',
            array(
                'label'           => __( 'Footer Animation', 'daisy' ),
                'section'         => 'footer_section',
            )
        ) );

        // Footer Style
        $wp_customize->add_setting( 'footer_style',
            array(
                'default'           => $this->defaults['footer_style'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'footer_style',
            array(
                'label'       => __( 'Footer Layout', 'daisy' ),
                'description' => esc_html__( 'You can override this settings only Mobile', 'daisy' ),
                'section'     => 'footer_section',
                'choices'     => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-1.jpg',
                        'name'  => __( 'Layout 1', 'daisy' )
                    ),                  
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-2.jpg',
                        'name'  => __( 'Layout 2', 'daisy' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-3.jpg',
                        'name'  => __( 'Layout 3', 'daisy' )
                    ),
                    '4' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-4.jpg',
                        'name'  => __( 'Layout 4', 'daisy' )
                    ),
                    '5' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/footer-5.jpg',
                        'name'  => __( 'Layout 5', 'daisy' )
                    ),
                )
            )
        ) );        

        /**
        * Footer 1 Background
        ========================================================================================*/
        $wp_customize->add_setting('footer1_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'footer1_heading', array(
            'label' => esc_html__( 'Footer 1 Background', 'daisy' ),
            'section' => 'footer_section',
            'active_callback'   => 'rttheme_is_footer1_enabled',
        )));
        // Display Footer 1 Background Image
        $wp_customize->add_setting( 'display_footer1_bg_image',
            array(
                'default'           => $this->defaults['display_footer1_bg_image'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer1_bg_image',
            array(
                'label'           => __( 'Background Image', 'daisy' ),
                'section'         => 'footer_section',
                'active_callback'   => 'rttheme_is_footer1_enabled',
            )
        ) );
        // Footer background image
        $wp_customize->add_setting( 'footer1_bg_img',
            array(
                'default' => $this->defaults['footer1_bg_img'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer1_bg_img',
            array(
                'label' => esc_html__( 'Image 1', 'daisy' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'daisy' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'daisy' ),
                    'change' => esc_html__( 'Change File', 'daisy' ),
                    'default' => esc_html__( 'Default', 'daisy' ),
                    'remove' => esc_html__( 'Remove', 'daisy' ),
                    'placeholder' => esc_html__( 'No file selected', 'daisy' ),
                    'frame_title' => esc_html__( 'Select File', 'daisy' ),
                    'frame_button' => esc_html__( 'Choose File', 'daisy' ),
                ),
                'active_callback'   => 'rttheme_is_footer1_bg_enabled',
            )
        ) );
        $wp_customize->add_setting( 'footer1_bg_img2',
            array(
                'default' => $this->defaults['footer1_bg_img2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer1_bg_img2',
            array(
                'label' => esc_html__( 'Image 2', 'daisy' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'daisy' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'daisy' ),
                    'change' => esc_html__( 'Change File', 'daisy' ),
                    'default' => esc_html__( 'Default', 'daisy' ),
                    'remove' => esc_html__( 'Remove', 'daisy' ),
                    'placeholder' => esc_html__( 'No file selected', 'daisy' ),
                    'frame_title' => esc_html__( 'Select File', 'daisy' ),
                    'frame_button' => esc_html__( 'Choose File', 'daisy' ),
                ),
                'active_callback'   => 'rttheme_is_footer1_bg_enabled',
            )
        ) );
        // Banner background color
        $wp_customize->add_setting('footer_bg_color', 
            array(
                'default' => $this->defaults['footer_bg_color'],
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bg_color',
            array(
                'label' => esc_html__('Background Color', 'daisy'),
                'settings' => 'footer_bg_color', 
                'priority' => 10, 
                'section' => 'footer_section',
            )
        ));
        // Banner background color opacity
        $wp_customize->add_setting( 'footer_bg_opacity',
            array(
                'default' => $this->defaults['footer_bg_opacity'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer_bg_opacity',
            array(
                'label' => esc_html__( 'Background Opacity', 'daisy' ),
                'section' => 'footer_section',
                'type' => 'number',
            )
        );
         // Footer 1 padding top
        $wp_customize->add_setting( 'footer_padding_top',
            array(
                'default' => $this->defaults['footer_padding_top'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer_padding_top',
            array(
                'label' => __( 'Padding Top', 'daisy' ),
                'section' => 'footer_section',
                'type' => 'number',
            )
        );
        // Footer 1 padding bottom
        $wp_customize->add_setting( 'footer_padding_bottom',
            array(
                'default' => $this->defaults['footer_padding_bottom'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
            )
        );
        $wp_customize->add_control( 'footer_padding_bottom',
            array(
                'label' => __( 'Padding Bottom', 'daisy' ),
                'section' => 'footer_section',
                'type' => 'number',
            )
        );
        /**
        * Footer 2 Background
        ========================================================================================*/
        $wp_customize->add_setting('footer2_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'footer2_heading', array(
            'label' => esc_html__( 'Footer 2 Background', 'daisy' ),
            'section' => 'footer_section',
            'active_callback'   => 'rttheme_is_footer2_enabled',
        )));
        // Display Footer 2 Background Image
        $wp_customize->add_setting( 'display_footer2_bg_image',
            array(
                'default'           => $this->defaults['display_footer2_bg_image'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer2_bg_image',
            array(
                'label'           => __( 'Background Image', 'daisy' ),
                'section'         => 'footer_section',
                'active_callback'   => 'rttheme_is_footer2_enabled',
            )
        ) );
        // Banner background image
        $wp_customize->add_setting( 'footer2_bg_img',
            array(
                'default' => $this->defaults['footer2_bg_img'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer2_bg_img',
            array(
                'label' => esc_html__( 'Image 1', 'daisy' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'daisy' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'daisy' ),
                    'change' => esc_html__( 'Change File', 'daisy' ),
                    'default' => esc_html__( 'Default', 'daisy' ),
                    'remove' => esc_html__( 'Remove', 'daisy' ),
                    'placeholder' => esc_html__( 'No file selected', 'daisy' ),
                    'frame_title' => esc_html__( 'Select File', 'daisy' ),
                    'frame_button' => esc_html__( 'Choose File', 'daisy' ),
                ),
                'active_callback'   => 'rttheme_is_footer2_bg_enabled',
            )
        ) );
        $wp_customize->add_setting( 'footer2_bg_img2',
            array(
                'default' => $this->defaults['footer2_bg_img2'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer2_bg_img2',
            array(
                'label' => esc_html__( 'Image 2', 'daisy' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'daisy' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'daisy' ),
                    'change' => esc_html__( 'Change File', 'daisy' ),
                    'default' => esc_html__( 'Default', 'daisy' ),
                    'remove' => esc_html__( 'Remove', 'daisy' ),
                    'placeholder' => esc_html__( 'No file selected', 'daisy' ),
                    'frame_title' => esc_html__( 'Select File', 'daisy' ),
                    'frame_button' => esc_html__( 'Choose File', 'daisy' ),
                ),
                'active_callback'   => 'rttheme_is_footer2_bg_enabled',
            )
        ) );
        /*===================================*/
        /**
        * Footer 2 Background
        ========================================================================================*/
        $wp_customize->add_setting('footer5_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'footer5_heading', array(
            'label' => esc_html__( 'Footer 5 Background', 'daisy' ),
            'section' => 'footer_section',
            'active_callback'   => 'rttheme_is_footer5_enabled',
        )));
        // Display Footer 2 Background Image
        $wp_customize->add_setting( 'display_footer5_bg_image',
            array(
                'default'           => $this->defaults['display_footer5_bg_image'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer5_bg_image',
            array(
                'label'           => __( 'Background Image', 'daisy' ),
                'section'         => 'footer_section',
                'active_callback'   => 'rttheme_is_footer5_enabled',
            )
        ) );
        // Banner background image
        $wp_customize->add_setting( 'footer5_bg_img',
            array(
                'default' => $this->defaults['footer5_bg_img'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'footer5_bg_img',
            array(
                'label' => esc_html__( 'Background Image', 'daisy' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'daisy' ),
                'section' => 'footer_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => esc_html__( 'Select File', 'daisy' ),
                    'change' => esc_html__( 'Change File', 'daisy' ),
                    'default' => esc_html__( 'Default', 'daisy' ),
                    'remove' => esc_html__( 'Remove', 'daisy' ),
                    'placeholder' => esc_html__( 'No file selected', 'daisy' ),
                    'frame_title' => esc_html__( 'Select File', 'daisy' ),
                    'frame_button' => esc_html__( 'Choose File', 'daisy' ),
                ),
                'active_callback'   => 'rttheme_is_footer5_bg_enabled',
            )
        ) );
        // Display Footer Top Area
        $wp_customize->add_setting( 'display_footertop_area',
            array(
                'default'           => $this->defaults['display_footertop_area'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footertop_area',
            array(
                'label'           => __( 'Display Top Area', 'daisy' ),
                'section'         => 'footer_section',
            )
        ) );
        // Display Footer Logo
        $wp_customize->add_setting( 'display_footer_logo',
            array(
                'default'           => $this->defaults['display_footer_logo'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer_logo',
            array(
                'label'           => __( 'Display Footer Logo', 'daisy' ),
                'section'         => 'footer_section',
                'active_callback'  => 'rttheme_is_footer1_and_ftop_enabled',
            )
        ) );
        // Footer Logo
        $wp_customize->add_setting('footer_logo',
             array(
                 'default'           => $this->defaults['footer_logo'],
                 'transport'         => 'refresh',
                 'sanitize_callback' => 'absint',                     
             )
        );
          $wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, 'footer_logo',
              array(
                  'label'         => esc_html__('Logo Dark', 'daisy'),
                  'description'   => esc_html__('This is the description for the Media Control', 'daisy'),
                  'section'       => 'footer_section',
                  'mime_type'     => 'image',
                  'button_labels' => array(
                      'select'       => esc_html__('Select File', 'daisy'),
                      'change'       => esc_html__('Change File', 'daisy'),
                      'default'      => esc_html__('Default', 'daisy'),
                      'remove'       => esc_html__('Remove', 'daisy'),
                      'placeholder'  => esc_html__('No file selected', 'daisy'),
                      'frame_title'  => esc_html__('Select File', 'daisy'),
                      'frame_button' => esc_html__('Choose File', 'daisy'),
                  ),
                  'active_callback'  => 'rttheme_is_footer1_flogo_enabled',
              )
          ));
          // Logo Light
          $wp_customize->add_setting('footer_logo_light',
             array(
                 'default'           => $this->defaults['footer_logo_light'],
                 'transport'         => 'refresh',
                 'sanitize_callback' => 'absint',                     
             )
        );
          $wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, 'footer_logo_light',
              array(
                  'label'         => esc_html__('Logo Light', 'daisy'),
                  'description'   => esc_html__('This is the description for the Media Control', 'daisy'),
                  'section'       => 'footer_section',
                  'mime_type'     => 'image',
                  'button_labels' => array(
                      'select'       => esc_html__('Select File', 'daisy'),
                      'change'       => esc_html__('Change File', 'daisy'),
                      'default'      => esc_html__('Default', 'daisy'),
                      'remove'       => esc_html__('Remove', 'daisy'),
                      'placeholder'  => esc_html__('No file selected', 'daisy'),
                      'frame_title'  => esc_html__('Select File', 'daisy'),
                      'frame_button' => esc_html__('Choose File', 'daisy'),
                  ),
                  'active_callback'  => 'rttheme_is_footer1_flogo_enabled',
              )
          ));
        // Display Footer Menu
        $wp_customize->add_setting( 'display_footer_menu',
            array(
                'default'           => $this->defaults['display_footer_menu'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_footer_menu',
            array(
                'label'           => __( 'Display Footer Menu', 'daisy' ),
                'section'         => 'footer_section',
                'active_callback'  => 'rttheme_is_footer1_enabled',
            )
        ) );
        // Display Copyright Area
        $wp_customize->add_setting( 'display_copyright_area',
            array(
                'default'           => $this->defaults['display_copyright_area'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_copyright_area',
            array(
                'label'           => __( 'Display Copyright Area', 'daisy' ),
                'section'         => 'footer_section',
            )
        ) );
        // Copyright Text
        $wp_customize->add_setting( 'copyright_text',
            array(
                'default'           => $this->defaults['copyright_text'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'sanitize_textarea_field',
                'active_callback'   => 'rttheme_is_display_copyright_enabled',
            )
        );
        $wp_customize->add_control( 'copyright_text',
            array(
                'label'           => __( 'Copyright Text', 'daisy' ),
                'section'         => 'footer_section',
                'type'            => 'textarea',
                'active_callback' => 'rttheme_is_display_copyright_enabled',
            )
        );
    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Footer_Settings();
}
