<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\daisy\Customizer\Settings;

use radiustheme\daisy\Customizer\RDTheme_Customizer;
use radiustheme\daisy\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Header_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_header_controls' ) );
	}

    public function register_header_controls( $wp_customize ) {

        // Header Style
        $wp_customize->add_setting( 'header_style',
            array(
                'default' => $this->defaults['header_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );

        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'header_style',
            array(
                'label' => __( 'Header Layout', 'daisy' ),
                'description' => esc_html__( 'You can override this settings only Mobile', 'daisy' ),
                'section' => 'header_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-1.png',
                        'name' => __( 'Layout 1', 'daisy' )
                    ),                  
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-2.png',
                        'name' => __( 'Layout 2', 'daisy' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-3.png',
                        'name' => __( 'Layout 3', 'daisy' )
                    ),
                    '4' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-4.png',
                        'name' => __( 'Layout 4', 'daisy' )
                    ),
                    '5' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-5.png',
                        'name' => __( 'Layout 5', 'daisy' )
                    ),
                    '6' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/header-6.png',
                        'name' => __( 'Layout 5', 'daisy' )
                    ),
                )
            )
        ) );

        /**
         * Separator
         */
        $wp_customize->add_setting('separator_top_bar', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_top_bar', array(
            'settings' => 'separator_top_bar',
            'section' => 'header_section',
            'active_callback' => 'rttheme_is_header_style5_enabled',
        )));

         // Switch for offcanvas menu
        $wp_customize->add_setting( 'display_line_animate',
            array(
                'default' => $this->defaults['display_line_animate'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'display_line_animate',
            array(
                'label' => __( 'Display Line Animation', 'daisy' ),
                'section' => 'header_section',
            )
        ) );

        // Switch for Top Bar
        $wp_customize->add_setting( 'top_bar',
            array(
                'default'           => $this->defaults['top_bar'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'top_bar',
            array(
                'label'   => __( 'Top Bar', 'daisy' ),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_header_style5_enabled',
            )
        ) );

        // Phone
        $wp_customize->add_setting( 'header_phone',
            array(
                'default'           => $this->defaults['header_phone'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_phone',
            array(
                'label'           => __( 'Phone', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_header_top_enabled',
            )
        );


        // Email
        $wp_customize->add_setting( 'header_email',
            array(
                'default'           => $this->defaults['header_email'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'header_email',
            array(
                'label'           => __( 'Phone', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_header_top_enabled',
            )
        );

         /**
         * Separator
         */
        $wp_customize->add_setting('separator_menu_right', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_menu_right', array(
            'settings' => 'separator_menu_right',
            'section' => 'header_section',
        )));

        // Switch for menu right part
        $wp_customize->add_setting( 'menu_right_part',
            array(
                'default' => $this->defaults['menu_right_part'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'menu_right_part',
            array(
                'label' => __( 'Menu Right', 'daisy' ),
                'section' => 'header_section',
            )
        ) );

        // Switch for menu search icon
        $wp_customize->add_setting( 'search_icon',
            array(
                'default' => $this->defaults['search_icon'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
                'active_callback' => 'rttheme_is_menu_right_enabled',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'search_icon',
            array(
                'label' => __( 'Search Icon', 'daisy' ),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_menu_right_enabled',
            )
        ) );
        $wp_customize->add_setting( 'hbtn_text',
            array(
                'default' => $this->defaults['hbtn_text'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
                'active_callback'   => 'rttheme_is_menu_right_enabled',
            )
        );
        $wp_customize->add_control( 'hbtn_text',
            array(
                'label' => __( 'Button Text', 'daisy' ),
                'section' => 'header_section',
                'type' => 'text',
                'active_callback'   => 'rttheme_is_menu_right_enabled',
            )
        );
        $wp_customize->add_setting( 'hbtn_link',
            array(
                'default' => $this->defaults['hbtn_link'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_url_sanitization',
                'active_callback'   => 'rttheme_is_menu_right_enabled',
            )
        );
        $wp_customize->add_control( 'hbtn_link',
            array(
                'label' => __( 'Button Link', 'daisy' ),
                'section' => 'header_section',
                'type' => 'url',
                'active_callback'   => 'rttheme_is_menu_right_enabled',
            )
        );
        // Switch for offcanvas menu
        $wp_customize->add_setting( 'offcanvas_menu',
            array(
                'default' => $this->defaults['offcanvas_menu'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'offcanvas_menu',
            array(
                'label' => __( 'Offcanvas Menu', 'daisy' ),
                'section' => 'header_section',
            )
        ) );
        // Offcanvas Menu Logo
        $wp_customize->add_setting('offcanvas_menu_logo',
             array(
                 'default'           => $this->defaults['offcanvas_menu_logo'],
                 'transport'         => 'refresh',
                 'sanitize_callback' => 'absint',                     
             )
        );
          $wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, 'offcanvas_menu_logo',
              array(
                  'label'         => esc_html__('Offcanvas Menu Logo', 'daisy'),
                  'description'   => esc_html__('This is the description for the Media Control', 'daisy'),
                  'section'       => 'header_section',
                  'mime_type'     => 'image',
                  'button_labels' => array(
                      'select'       => esc_html__('Select File', 'daisy'),
                      'change'       => esc_html__('Change File', 'daisy'),
                      'default'      => esc_html__('Default', 'daisy'),
                      'remove'       => esc_html__('Remove', 'daisy'),
                      'placeholder'  => esc_html__('No file selected', 'daisy'),
                      'frame_title'  => esc_html__('Select File', 'daisy'),
                      'frame_button' => esc_html__('Choose File', 'daisy'),
                  ),
                  'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
              )
          ));
        // Offcanvas Menu Title
        $wp_customize->add_setting( 'offcanvm_title',
            array(
                'default'           => $this->defaults['offcanvm_title'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_title',
            array(
                'label'           => __( 'Offcanvas Menu Title', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Description
        $wp_customize->add_setting( 'offcanvm_desc',
            array(
                'default'           => $this->defaults['offcanvm_desc'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'sanitize_textarea_field',
            )
        );
        $wp_customize->add_control( 'offcanvm_desc',
            array(
                'label'           => __( 'Offcanvas Menu Description', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'textarea',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Contact Title
        $wp_customize->add_setting( 'contact_title',
            array(
                'default'           => $this->defaults['contact_title'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'contact_title',
            array(
                'label'           => __( 'Contact Title', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Address
        $wp_customize->add_setting( 'offcanvm_address',
            array(
                'default'           => $this->defaults['offcanvm_address'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_address',
            array(
                'label'           => __( 'Offcanvas Menu Address', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Phone
        $wp_customize->add_setting( 'offcanvm_phone',
            array(
                'default'           => $this->defaults['offcanvm_phone'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_phone',
            array(
                'label'           => __( 'Offcanvas Menu Phone', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );
        // Offcanvas Menu Email
        $wp_customize->add_setting( 'offcanvm_email',
            array(
                'default'           => $this->defaults['offcanvm_email'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'offcanvm_email',
            array(
                'label'           => __( 'Offcanvas Menu Email', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        );

        // Socials
        $wp_customize->add_setting( 'socials',
            array(
                'default' => $this->defaults['socials'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'socials',
            array(
                'label' => __( 'Socials', 'daisy' ),
                'section' => 'header_section',
                'active_callback' => 'rttheme_is_offcanvm_hstyle_enabled',
            )
        ) );
        //Facebook
        $wp_customize->add_setting( 'social_facebook',
            array(
                'default'           => $this->defaults['social_facebook'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_facebook',
            array(
                'label'           => __( 'Facebook', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Twitter
        $wp_customize->add_setting( 'social_twitter',
            array(
                'default'           => $this->defaults['social_twitter'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_twitter',
            array(
                'label'           => __( 'Twitter', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Behance
        $wp_customize->add_setting( 'social_behance',
            array(
                'default'           => $this->defaults['social_behance'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_behance',
            array(
                'label'           => __( 'Behance', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Pinterest
        $wp_customize->add_setting( 'social_pinterest',
            array(
                'default'           => $this->defaults['social_pinterest'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_pinterest',
            array(
                'label'           => __( 'Pinterest', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Linkedin
        $wp_customize->add_setting( 'social_linkedin',
            array(
                'default'           => $this->defaults['social_linkedin'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_linkedin',
            array(
                'label'           => __( 'Linkedin', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Dribbble
        $wp_customize->add_setting( 'social_dribbble',
            array(
                'default'           => $this->defaults['social_dribbble'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_dribbble',
            array(
                'label'           => __( 'Dribbble', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Youtube
        $wp_customize->add_setting( 'social_youtube',
            array(
                'default'           => $this->defaults['social_youtube'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_youtube',
            array(
                'label'           => __( 'Youtube', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Instagram
        $wp_customize->add_setting( 'social_instagram',
            array(
                'default'           => $this->defaults['social_instagram'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_instagram',
            array(
                'label'           => __( 'Instagram', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );
        // Skype
        $wp_customize->add_setting( 'social_skype',
            array(
                'default'           => $this->defaults['social_skype'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'social_skype',
            array(
                'label'           => __( 'Skype', 'daisy' ),
                'section'         => 'header_section',
                'type'            => 'text',
                'active_callback' => 'rttheme_is_offcanvm_socials_enabled',
            )
        );

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Header_Settings();
}
