<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\daisy\Customizer\Settings;

use radiustheme\daisy\Customizer\RDTheme_Customizer;
use radiustheme\daisy\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Image_Radio_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Services_Archive_Settings extends RDTheme_Customizer {

    public function __construct() {
        parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_services_archive_controls' ) );
    }

    /**
     * Case Post Controls
     */
    public function register_services_archive_controls( $wp_customize ) {

        // Posts per page
        $wp_customize->add_setting( 'service_archive_number',
            array(
                'default' => $this->defaults['service_archive_number'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer'
            )
        );
        $wp_customize->add_control( 'service_archive_number',
            array(
                'label' => esc_html__( 'Posts Per Page', 'daisy' ),
                'section' => 'services_section',
                'type' => 'number'
            )
        );
        
        // Excerpt
        $wp_customize->add_setting( 'service_excerpt_length',
            array(
                'default' => $this->defaults['service_excerpt_length'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'service_excerpt_length',
            array(
                'label' => esc_html__( 'Excerpt Length', 'daisy' ),
                'section' => 'services_section',
                'type' => 'text',
            )
        );
        $wp_customize->add_setting( 'service_orderby',
            array(
                'default' => $this->defaults['service_orderby'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( 'service_orderby',
            array(
                'label' => esc_html__( 'Orderby', 'daisy' ),
                'section' => 'services_section',
                'description' => esc_html__( 'This is post query order.', 'daisy' ),
                'type' => 'select',
                'choices' => array(
                    'ID'  => esc_html__( 'Post Id', 'daisy' ),
                    'author' => esc_html__( 'Post Author', 'daisy' ),
                    'title' => esc_html__( 'Title', 'daisy' ),
                    'date' => esc_html__( 'Date', 'daisy' ),
                    'modified' => esc_html__( 'Modified', 'daisy' ),
                    'parent' => esc_html__( 'Parent', 'daisy' ),
                    'rand' => esc_html__( 'Random', 'daisy' ),
                    'comment_count' => esc_html__( 'Comment Count', 'daisy' ),
                    'menu_order' => esc_html__( 'Menu Order', 'daisy' ),
                ),
            )
        );
        // Columns Width
        $wp_customize->add_setting( 'service_grid_cols',
            array(
                'default' => $this->defaults['service_grid_cols'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( 'service_grid_cols',
            array(
                'label' => esc_html__( 'Grid Columns', 'daisy' ),
                'section' => 'services_section',
                'description' => esc_html__( 'Width is defined by the number of bootstrap columns. Please note, portfolio columns devided by the bootstrap columns. You can devided only 6 columns.', 'daisy' ),
                'type' => 'select',
                'choices' => array(
                    '1' => esc_html__( '1 Columns', 'daisy' ),
                    '2' => esc_html__( '2 Columns', 'daisy' ),
                    '3' => esc_html__( '3 Columns', 'daisy' ),
                    '4' => esc_html__( '4 Columns', 'daisy' ),
                    '5' => esc_html__( '5 Columns', 'daisy' ),
                    '6' => esc_html__( '6 Columns', 'daisy' ),
                ),
                'active_callback' => 'rttheme_portfolio_grid_enabled',
            )
        );
        // Service gutter
        $wp_customize->add_setting( 'service_grid_gutter',
            array(
                'default' => $this->defaults['service_grid_gutter'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'service_grid_gutter',
            array(
                'label' => esc_html__( 'Columns Gap', 'daisy' ),
                'section' => 'services_section',
            )
        ) );
        $wp_customize->add_setting( 'service_style',
            array(
                'default' => $this->defaults['service_style'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( new Customizer_Image_Radio_Control( $wp_customize, 'service_style',
            array(
                'label' => esc_html__( 'Layout', 'daisy' ),
                'description' => esc_html__( 'Select the service layout for service archive page', 'daisy' ),
                'section' => 'services_section',
                'choices' => array(
                    '1' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/service-1.jpg',
                        'name' => esc_html__( 'Layout 1', 'daisy' )
                    ),
                    '2' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/service-2.jpg',
                        'name' => esc_html__( 'Layout 2', 'daisy' )
                    ),
                    '3' => array(
                        'image' => trailingslashit( get_template_directory_uri() ) . 'assets/img/service-3.jpg',
                        'name' => esc_html__( 'Layout 3', 'daisy' )
                    ),
                )
            )
        ) );
        /**
         * Heading for single Service
         */
        $wp_customize->add_setting('single_service_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'single_service_heading', array(
            'label' => esc_html__( 'Single Service', 'daisy' ),
            'section' => 'services_section',
        )));
        // Service Page Banner
        $wp_customize->add_setting( 'service_banner',
            array(
                'default' => $this->defaults['service_banner'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'service_banner',
            array(
                'label' => __( 'Banner', 'daisy' ),
                'section' => 'services_section',
            )
        ) );
        // Banner BG Type 
        $wp_customize->add_setting( 'service_banner_bg_type',
            array(
                'default' => $this->defaults['service_banner_bg_type'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_is_service_banner_enabled',
            )
        );
        $wp_customize->add_control( 'service_banner_bg_type',
            array(
                'label' => __( 'Banner Background Type', 'daisy' ),
                'section' => 'services_section',
                'description' => esc_html__( 'This is banner background type.', 'daisy' ),
                'type' => 'select',
                'choices' => array(
                    'bgimg' => esc_html__( 'BG Image', 'daisy' ),
                    'bgcolor' => esc_html__( 'BG Color', 'daisy' ),
                ),
                'active_callback' => 'rttheme_is_service_banner_enabled',
            )
        );
        $wp_customize->add_setting( 'service_banner_bgimg',
            array(
                'default' => $this->defaults['service_banner_bgimg'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'service_banner_bgimg',
            array(
                'label' => __( 'Banner Background Image', 'daisy' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'daisy' ),
                'section' => 'services_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'daisy' ),
                    'change' => __( 'Change File', 'daisy' ),
                    'default' => __( 'Default', 'daisy' ),
                    'remove' => __( 'Remove', 'daisy' ),
                    'placeholder' => __( 'No file selected', 'daisy' ),
                    'frame_title' => __( 'Select File', 'daisy' ),
                    'frame_button' => __( 'Choose File', 'daisy' ),
                ),
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        ) );
        // Banner background image overlay
        $wp_customize->add_setting('service_banner_bgimage_overlay', 
            array(
                'default' => 'rgba(0, 0, 0, 0.5)', 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'service_banner_bgimage_overlay',
            array(
                'label' => esc_html__('Banner Background Overlay Color', 'daisy'),
                'settings' => 'service_banner_bgimage_overlay', 
                'priority' => 10, 
                'section' => 'services_section', 
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        ));
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'service_banner_bgimage_overlay',
            array(
                'label' => esc_html__('Banner Background Overlay Color', 'daisy'),
                'settings' => 'service_banner_bgimage_overlay', 
                'priority' => 10, 
                'section' => 'services_section', 
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        ));
        // Banner background color opacity
        $wp_customize->add_setting( 'service_overlay_opacity',
            array(
                'default' => $this->defaults['service_overlay_opacity'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( 'service_overlay_opacity',
            array(
                'label' => __( 'Overlay Opacity', 'daisy' ),
                'section' => 'services_section',
                'type' => 'number',
                'active_callback' => 'rttheme_service_banner_bgimg_type_condition',
            )
        );
        // Banner background color
        $wp_customize->add_setting('service_banner_bgcolor', 
            array(
                'default' => 'rgba(19, 21, 32, 1)', 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_service_banner_bgcolor_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'service_banner_bgcolor',
            array(
                'label' => esc_html__('Banner Background Color', 'daisy'),
                'settings' => 'service_banner_bgcolor', 
                'priority' => 10, 
                'section' => 'services_section', 
                'active_callback' => 'rttheme_service_banner_bgcolor_type_condition',
            )
        ));

        /**
         * Separator
         */
        $wp_customize->add_setting('separator_service_page_breadcrumb', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_service_page_breadcrumb', array(
            'settings' => 'separator_service_page_breadcrumb',
            'section' => 'services_section',
        )));
        $wp_customize->add_setting( 'service_breadcrumb',
            array(
                'default' => $this->defaults['service_breadcrumb'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'service_breadcrumb',
            array(
                'label' => __( 'Breadcrumb', 'daisy' ),
                'section' => 'services_section',
            )
        ) );
        // Single service Slug
        $wp_customize->add_setting( 'single_service_slug',
            array(
                'default' => $this->defaults['single_service_slug'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'single_service_slug',
            array(
                'label' => __( 'Single Service Slug', 'daisy' ),
                'section' => 'services_section',
                'type' => 'text'
            )
        );
        // Banner padding top
        $wp_customize->add_setting( 'service_inner_padding_top',
            array(
                'default' => $this->defaults['service_inner_padding_top'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_is_single_service_banner_enabled',
            )
        );
        $wp_customize->add_control( 'service_inner_padding_top',
            array(
                'label' => __( 'Banner Padding Top', 'daisy' ),
                'section' => 'services_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_single_service_banner_enabled',
            )
        );
        // Banner padding bottom
        $wp_customize->add_setting( 'service_inner_padding_bottom',
            array(
                'default' => $this->defaults['service_inner_padding_bottom'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_is_single_service_banner_enabled',
            )
        );
        $wp_customize->add_control( 'service_inner_padding_bottom',
            array(
                'label' => __( 'Banner Padding Bottom', 'daisy' ),
                'section' => 'services_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_single_service_banner_enabled',
            )
        );
        /**
         * Separator
         */
        $wp_customize->add_setting('separator_service_page_banner', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_service_page_banner', array(
            'settings' => 'separator_service_page_banner',
            'section' => 'services_section',
        )));

    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
    new RDTheme_Services_Archive_Settings();
}
