<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\daisy\Customizer\Settings;

use radiustheme\daisy\Customizer\RDTheme_Customizer;
use radiustheme\daisy\Customizer\Controls\Customizer_Switch_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Separator_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Heading_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Image_Radio_Control;
use radiustheme\daisy\Customizer\Controls\Customizer_Gallery_Control;
use WP_Customize_Media_Control;
use WP_Customize_Color_Control;

/**
 * Adds the individual sections, settings, and controls to the theme customizer
 */
class RDTheme_Team_Archive_Settings extends RDTheme_Customizer {

	public function __construct() {
	    parent::instance();
        $this->populated_default_data();
        // Add Controls
        add_action( 'customize_register', array( $this, 'register_team_archive_controls' ) );
	}

    /**
     * Gallery Post Controls
     */
    public function register_team_archive_controls( $wp_customize ) {
        // Posts per page
        $wp_customize->add_setting( 'team_archive_number',
            array(
                'default' => $this->defaults['team_archive_number'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer'
            )
        );
        $wp_customize->add_control( 'team_archive_number',
            array(
                'label' => esc_html__( 'Posts Per Page', 'daisy' ),
                'section' => 'team_section',
                'type' => 'number'
            )
        );

        // Switch for archive social
        $wp_customize->add_setting( 'team_archive_social',
            array(
                'default'           => $this->defaults['team_archive_social'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'team_archive_social',
            array(
                'label'   => __( 'Social Display', 'daisy' ),
                'section' => 'team_section',
            )
        ) );

        // Switch for archive social
        $wp_customize->add_setting( 'team_archive_desig',
            array(
                'default'           => $this->defaults['team_archive_desig'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'team_archive_desig',
            array(
                'label'   => __( 'Designation Display', 'daisy' ),
                'section' => 'team_section',
            )
        ) );

        // Columns Width
        $wp_customize->add_setting( 'team_arc_grid_cols',
            array(
                'default' => $this->defaults['team_arc_grid_cols'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization'
            )
        );
        $wp_customize->add_control( 'team_arc_grid_cols',
            array(
                'label' => esc_html__( 'Grid Columns', 'daisy' ),
                'section' => 'team_section',
                'description' => esc_html__( 'Width is defined by the number of bootstrap columns. Please note, portfolio columns devided by the selected bootstrap columns', 'daisy' ),
                'type' => 'select',
                'choices' => array(
                    '6' => esc_html__( '2 Columns', 'daisy' ),
                    '4' => esc_html__( '3 Columns', 'daisy' ),
                    '3' => esc_html__( '4 Columns', 'daisy' ),
                    '2' => esc_html__( '6 Columns', 'daisy' ),
                ),
            )
        );

        /**
         * Heading for single Team
         */
        $wp_customize->add_setting('single_team_heading', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Heading_Control($wp_customize, 'single_team_heading', array(
            'label' => esc_html__( 'Single Team', 'daisy' ),
            'section' => 'team_section',
        )));


        $wp_customize->add_setting( 'team_banner',
            array(
                'default' => $this->defaults['team_banner'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'team_banner',
            array(
                'label' => __( 'Banner', 'daisy' ),
                'section' => 'team_section',
            )
        ) );

        // Banner BG Type 
        $wp_customize->add_setting( 'team_banner_bg_type',
            array(
                'default' => $this->defaults['team_banner_bg_type'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
                'active_callback' => 'rttheme_is_steam_banner_enabled',
            )
        );
        $wp_customize->add_control( 'team_banner_bg_type',
            array(
                'label' => __( 'Banner Background Type', 'daisy' ),
                'section' => 'team_section',
                'description' => esc_html__( 'This is banner background type.', 'daisy' ),
                'type' => 'select',
                'choices' => array(
                    'bgimg' => esc_html__( 'BG Image', 'daisy' ),
                    'bgcolor' => esc_html__( 'BG Color', 'daisy' ),
                ),
                'active_callback' => 'rttheme_is_steam_banner_enabled',
            )
        );

        $wp_customize->add_setting( 'team_banner_bgimg',
            array(
                'default' => $this->defaults['team_banner_bgimg'],
                'transport' => 'refresh',
                'sanitize_callback' => 'absint',
                'active_callback' => 'rttheme_steam_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, 'team_banner_bgimg',
            array(
                'label' => __( 'Banner Background Image', 'daisy' ),
                'description' => esc_html__( 'This is the description for the Media Control', 'daisy' ),
                'section' => 'team_section',
                'mime_type' => 'image',
                'button_labels' => array(
                    'select' => __( 'Select File', 'daisy' ),
                    'change' => __( 'Change File', 'daisy' ),
                    'default' => __( 'Default', 'daisy' ),
                    'remove' => __( 'Remove', 'daisy' ),
                    'placeholder' => __( 'No file selected', 'daisy' ),
                    'frame_title' => __( 'Select File', 'daisy' ),
                    'frame_button' => __( 'Choose File', 'daisy' ),
                ),
                'active_callback' => 'rttheme_steam_banner_bgimg_type_condition',
            )
        ) );
        // Banner background image overlay
        $wp_customize->add_setting('team_banner_bgimage_overlay', 
            array(
                'default' => 'rgba(0, 0, 0, 0.5)', 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_steam_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'team_banner_bgimage_overlay',
            array(
                'label' => esc_html__('Banner Background Overlay Color', 'daisy'),
                'settings' => 'team_banner_bgimage_overlay', 
                'priority' => 10, 
                'section' => 'team_section', 
                'active_callback' => 'rttheme_steam_banner_bgimg_type_condition',
            )
        ));
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'team_banner_bgimage_overlay',
            array(
                'label' => esc_html__('Banner Background Overlay Color', 'daisy'),
                'settings' => 'team_banner_bgimage_overlay', 
                'priority' => 10, 
                'section' => 'team_section', 
                'active_callback' => 'rttheme_steam_banner_bgimg_type_condition',
            )
        ));
        // Banner background color opacity
        $wp_customize->add_setting( 'team_overlay_opacity',
            array(
                'default' => $this->defaults['team_overlay_opacity'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_steam_banner_bgimg_type_condition',
            )
        );
        $wp_customize->add_control( 'team_overlay_opacity',
            array(
                'label' => __( 'Overlay Opacity', 'daisy' ),
                'section' => 'team_section',
                'type' => 'number',
                'active_callback' => 'rttheme_steam_banner_bgimg_type_condition',
            )
        );

        // Banner background color
        $wp_customize->add_setting('team_banner_bgcolor', 
            array(
                'default' => 'rgba(19, 21, 32, 1)', 
                'type' => 'theme_mod', 
                'capability' => 'edit_theme_options', 
                'transport' => 'refresh', 
                'sanitize_callback' => 'sanitize_hex_color',
                'active_callback' => 'rttheme_steam_banner_bgcolor_type_condition',
            )
        );
        $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'team_banner_bgcolor',
            array(
                'label' => esc_html__('Banner Background Color', 'daisy'),
                'settings' => 'team_banner_bgcolor', 
                'priority' => 10, 
                'section' => 'team_section', 
                'active_callback' => 'rttheme_steam_banner_bgcolor_type_condition',
            )
        ));

        /**
         * Separator
         */
        $wp_customize->add_setting('separator_team_page_breadcrumb', array(
            'default' => '',
            'sanitize_callback' => 'esc_html',
        ));
        $wp_customize->add_control(new Customizer_Separator_Control($wp_customize, 'separator_team_page_breadcrumb', array(
            'settings' => 'separator_team_page_breadcrumb',
            'section' => 'team_section',
        )));

        $wp_customize->add_setting( 'team_breadcrumb',
            array(
                'default' => $this->defaults['team_breadcrumb'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'team_breadcrumb',
            array(
                'label' => __( 'Breadcrumb', 'daisy' ),
                'section' => 'team_section',
                'active_callback' => 'rttheme_is_single_team_banner_enabled',
            )
        ) );

        // Single Team Slug
        $wp_customize->add_setting( 'single_team_slug',
            array(
                'default' => $this->defaults['single_team_slug'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization'
            )
        );
        $wp_customize->add_control( 'single_team_slug',
            array(
                'label' => __( 'Single Team Slug', 'daisy' ),
                'section' => 'team_section',
                'type' => 'text'
            )
        );

        // Related
        $wp_customize->add_setting( 'team_related_post',
            array(
                'default' => $this->defaults['team_related_post'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_switch_sanitization',
            )
        );
        $wp_customize->add_control( new Customizer_Switch_Control( $wp_customize, 'team_related_post',
            array(
                'label' => esc_html__( 'Show Related Post', 'daisy' ),
                'section' => 'team_section',
            )
        ) );

        $wp_customize->add_setting( 'team_related_title',
            array(
                'default'           => $this->defaults['team_related_title'],
                'transport'         => 'refresh',
                'sanitize_callback' => 'rttheme_text_sanitization',
            )
        );
        $wp_customize->add_control( 'team_related_title',
            array(
                'label'           => __( 'Related Title', 'daisy' ),
                'section'         => 'team_section',
                'type'            => 'text',
                'active_callback'   => 'rttheme_is_related_team_enabled',
            )
        );

        // Post Query 
        $wp_customize->add_setting( 'team_related_query',
            array(
                'default' => $this->defaults['team_related_query'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
            )
        );
        $wp_customize->add_control( 'team_related_query',
            array(
                'label' => __( 'Query Type', 'daisy' ),
                'section' => 'team_section',
                'description' => esc_html__( 'Post Query', 'daisy' ),
                'type' => 'select',
                'choices' => array(
                    'cat' => esc_html__( 'Posts in the same Categories', 'daisy' ),
                    'tag' => esc_html__( 'Posts in the same Tags', 'daisy' ),
                    'author' => esc_html__( 'Posts by the same Author', 'daisy' ),
                ),
                'active_callback'   => 'rttheme_is_related_team_enabled',
            )
        );
        // Display post Order
        $wp_customize->add_setting( 'team_related_sort',
            array(
                'default' => $this->defaults['team_related_sort'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_radio_sanitization',
            )
        );
        $wp_customize->add_control( 'team_related_sort',
            array(
                'label' => __( 'Sort Order', 'daisy' ),
                'section' => 'team_section',
                'description' => esc_html__( 'Display post Order', 'daisy' ),
                'type' => 'select',
                'choices' => array(
                    'recent' => esc_html__( 'Recent Posts', 'daisy' ),
                    'rand' => esc_html__( 'Random Posts', 'daisy' ),
                    'modified' => esc_html__( 'Last Modified Posts', 'daisy' ),
                    'popular' => esc_html__( 'Most Commented posts', 'daisy' ),
                    'views' => esc_html__( 'Most Viewed posts', 'daisy' ),
                ),
                'active_callback'   => 'rttheme_is_related_team_enabled',
            )
        );

        // Banner padding top
        $wp_customize->add_setting( 'team_inner_padding_top',
            array(
                'default' => $this->defaults['team_inner_padding_top'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_is_single_team_banner_enabled',
            )
        );
        $wp_customize->add_control( 'team_inner_padding_top',
            array(
                'label' => __( 'Banner Padding Top', 'daisy' ),
                'section' => 'team_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_single_team_banner_enabled',
            )
        );
        // Banner padding bottom
        $wp_customize->add_setting( 'team_inner_padding_bottom',
            array(
                'default' => $this->defaults['team_inner_padding_bottom'],
                'transport' => 'refresh',
                'sanitize_callback' => 'rttheme_sanitize_integer',
                'active_callback' => 'rttheme_is_single_team_banner_enabled',
            )
        );
        $wp_customize->add_control( 'team_inner_padding_bottom',
            array(
                'label' => __( 'Banner Padding Bottom', 'daisy' ),
                'section' => 'team_section',
                'type' => 'number',
                'active_callback' => 'rttheme_is_single_team_banner_enabled',
            )
        );
    }

}

/**
 * Initialise our Customizer settings only when they're required
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	new RDTheme_Team_Archive_Settings();
}
