<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\daisy;
use radiustheme\daisy\inc\RDTheme;
use radiustheme\daisy\inc\Helper;

class General_Setup {

	public function __construct() {
		add_action( 'after_setup_theme',                       array( $this, 'theme_setup' ) );	
		add_action( 'widgets_init',                            array( $this, 'register_sidebars' ) );		
		add_filter( 'body_class',                              array( $this, 'body_classes' ) );
		add_filter( 'post_class',                              array( $this, 'post_classes' ) );
		add_action( 'wp_head',                                 array( $this, 'noscript_hide_preloader' ), 1 );
		add_filter( 'get_search_form',                         array( $this, 'search_form' ) );
		add_filter( 'comment_form_fields',                     array( $this, 'move_textarea_to_bottom' ) );
		add_filter( 'excerpt_more',                            array( $this, 'excerpt_more' ) );
		add_filter( 'wp_kses_allowed_html', 	               array( $this, 'daisy_kses_allowed_html' ), 10, 2 );		
		add_filter( 'elementor/widgets/wordpress/widget_args', array( $this, 'elementor_widget_args' ) );
		add_action( 'wp_head',                                 array( $this, 'daisy_pingback_header' ), 996 );
		add_action( 'wp_head',                                 array( $this, 'daisy_siteicon_header' ), 997 );
		add_action( 'wp_admin',                                array( $this, 'daisy_siteicon_header' ), 998 );
		add_action( 'site_prealoader',                         array( $this, 'daisy_preloader' ) );
		add_filter( 'wpcf7_autop_or_not',  					   '__return_false' ); // cf7 wptop
		add_filter( 'register_post_type_args',                 array( $this, 'update_daisy_custom_post_slug' ), 10, 2 );
		add_filter( 'register_taxonomy_args',                  array( $this, 'daisy_change_taxonomies_slug'), 10, 2 );
		add_action( 'template_redirect',                       array( $this, 'w3c_validator' ) );
	}

	/**
	* Add a pingback url auto-discovery header for single posts, pages, or attachments.
	*/
	public function daisy_pingback_header() {
		if ( is_singular() && pings_open() ) {
			printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
		}
	}
	/**
	* If empty site icon then the fallback
	*/
	public function daisy_siteicon_header() {
		if ( ! ( function_exists( 'has_site_icon' ) ) ) {
			echo '<link rel="shortcut icon">';
		}
	}	

	public function theme_setup() {
		$daisy = DAISY_THEME_PREFIX;
		// Theme supports
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'wp-block' );
		add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
		add_theme_support( 'post-formats', array( 'aside', 'gallery', 'video', 'audio', 'quote', 'link' ) );
		add_editor_style();
		add_theme_support( 'admin-bar', array( 'callback' => '__return_false' ) );
		remove_theme_support( 'widgets-block-editor' );
		// for gutenberg support
		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-color-palette', array(
			array(
				'name'  => esc_html__( 'Primary', 'daisy' ),
				'slug'  => 'daisy-primary',
				'color' => '#f85c70',
			),
			array(
				'name'  => esc_html__('Secondary', 'daisy' ),
				'slug'  => 'daisy-secondary',
				'color' => '#061526',
			),
			array(
				'name'  => esc_html__('Light', 'daisy' ),
				'slug'  => 'daisy-light',
				'color' => '#ffffff',
			),
			array(
				'name'  => esc_html__('Black', 'daisy' ),
				'slug'  => 'daisy-black',
				'color'  => '#000000',
			),
			array(
				'name'  => esc_html__('Dark', 'daisy' ),
				'slug'  => 'daisy-dark',
				'color'  => '#101213',
			),
			
		) );
		add_theme_support( 'editor-font-sizes', array(
			array(
				'name' => esc_html__('Small', 'daisy' ),
				'size'  => 12,
				'slug'  => 'small'
			),
			array(
				'name'  => esc_html__('Normal', 'daisy' ),
				'size'  => 16,
				'slug'  => 'normal'
			),
			array(
				'name'  => esc_html__('Large', 'daisy' ),
				'size'  => 36,
				'slug'  => 'large'
			),
			array(
				'name'  => esc_html__('Huge', 'daisy' ),
				'size'  => 50,
				'slug'  => 'huge'
			)
		) );

		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'editor-styles');		
	
		// Image sizes
		add_image_size( "daisy-thumb1", 770, 420, true ); // Blog list & grid thumb
		add_image_size( "daisy-thumb2", 1170, 458, true ); // Blog Wide Size
		add_image_size( "daisy-thumb3", 570, 420, true ); // Blog 2 & Grid thumb
		add_image_size( "daisy-thumb4", 551, 783, true ); // Service, Team, Portfolio 3  thumb
		add_image_size( "daisy-thumb5", 600, 630, true ); // Team thumb
		add_image_size( "daisy-thumb6", 538, 472, true ); // Portfolio 2  thumb
		add_image_size( "daisy-thumb7", 800, 800, true ); // Portfolio 4  thumb
		add_image_size( "daisy-thumb8", 937, 527, true ); // Portfolio 5  thumb
	
		// Register menus
		register_nav_menus( array(
			'primary'  => esc_html__( 'Primary', 'daisy' ),
			'footer' => esc_html__( 'Footer', 'daisy' ),
		) );

		// Custom Logo
		add_theme_support( 'custom-logo', array(
			'height'      => 65,
			'width'       => 245,
			'flex-height' => true,
			'header-text' => array( 'site-title', 'site-description' ),
		) );
	}


	public function register_sidebars() {
		$footer_widget_titles = array(
			'1' => esc_html__( 'Footer 1 Widget 1', 'daisy' ),
			'2' => esc_html__( 'Footer 1 Widget 2', 'daisy' ),
			'3' => esc_html__( 'Footer 1 Widget 3', 'daisy' ),
			'4' => esc_html__( 'Footer 1 Widget 4', 'daisy' ),
			'6' => esc_html__( 'Footer 1 Widget 6', 'daisy' ),
		);
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar Widgets', 'daisy' ),
			'id'            => 'sidebar',
			'description'   => esc_html__('Sidebar Widgets area', 'daisy'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="blog-post__title">',
			'after_title'   => '</h3>',
		) );

		for ( $i = 1; $i <= 4; $i++ ) {
			if (isset($footer_widget_titles[$i])) {
				register_sidebar( array(
					'name'          => $footer_widget_titles[$i],
					'id'            => 'footer-widgets-'. $i,
					'description'   => esc_html__('Footer widgets area', 'daisy'),
					'before_widget' => '<div id="%1$s" class="footer-widget %2$s">',
					'after_widget'  => '</div>',
					'before_title'  => '<h3 class="footer-widget__title">',
					'after_title'   => '</h3>',
				) );
			}
		}

		register_sidebar( array(
			'name'          => esc_html__( 'Offcanvas Menu Instagram', 'daisy' ),
			'id'            => 'off_insta_sidebar',
			'before_widget' => '<div id="%1$s" class="widget offcanvas-widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="offcanvas-widget-title">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Service Widgets', 'daisy' ),
			'id'            => 'service-widgets',
			'description'   => esc_html__('Service Widgets area', 'daisy'),
			'before_widget' => '<div id="%1$s" class="service-details__sidebar %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="serviceDetails-quotes__heading">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Service Widgets 2', 'daisy' ),
			'id'            => 'service-widgets-2',
			'description'   => esc_html__('Service Widgets area', 'daisy'),
			'before_widget' => '<div id="%1$s" class="service-details__sidebar %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="serviceDetails-quotes__heading">',
			'after_title'   => '</h3>',
		) );

	}

	public function body_classes( $classes ) {
		if ( RDTheme::$options['sticky_header'] == 1 ) {	
			$classes[] = 'sticky-header';
		}

		if (RDTheme::$tr_header === 0 || RDTheme::$tr_header == "off" ) {	
			$classes[] = 'transparent-header-disable';
		}else{
			$classes[] = 'transparent-header';
		}
		
		if( is_home() || is_page() || is_archive() || is_search() || is_404() ) {
			if ( RDTheme::$has_banner != 1 ) {	
				$classes[] = 'page-banner-disable';
			}
		}
		if (is_single()) {
			if (RDTheme::$options['single_post_banner'] != 1 ) {	
				$classes[] = 'single-page-banner-disable';
			}
		}

		if ( RDTheme::$header_style == 3 ) {	
			$classes[] = 'pagepiling';
		}

		$classes[] = 'header-style-'. RDTheme::$header_style;
		
        // Sidebar
		$classes[] = ( RDTheme::$layout == 'full-width' ) ? 'no-sidebar' : 'has-sidebar';

		return $classes;
	}


	public function post_classes( $classes ) {
		$post_thumb = '';
		if ( has_post_thumbnail() ){
		    $classes[] = 'have-post-thumb';
		}
		return $classes;
	}

	public function noscript_hide_preloader(){
		// Hide preloader if js is disabled
		echo '<noscript><style>#preloader{display:none;}</style></noscript>';
	}

	public function scroll_to_top_html(){
		// Back-to-top link
		if ( RDTheme::$options['back_to_top'] ){	
		echo '<a href="#wrapper" data-type="section-switch" class="scrollup back-top">
			<i class="fas fa-angle-double-up"></i>
		</a>';
		}
	}

	public function search_form(){
		$output = '
		<form role="search" method="get" class="blog-search" action="' . esc_url( home_url( '/' ) ) . '">
			<div class="blog-search__group">	   
		    	<input type="text" class="blog-search__input" placeholder="' . esc_attr__( 'Search Keyword', 'daisy' ) . '" value="' . get_search_query() . '" name="s" />
		        <button type="submit" class="blog-search__button">
	             <svg class="blog-search__icon" id="loupe" width="22" height="22" viewBox="0 0 22 22">
	                <g id="Group_1408" data-name="Group 1408">
	                  <g id="Group_1407" data-name="Group 1407">
	                    <path id="Path_5667" data-name="Path 5667" d="M9.688,0a9.688,9.688,0,1,0,9.688,9.688A9.7,9.7,0,0,0,9.688,0Zm0,17.588a7.9,7.9,0,1,1,7.9-7.9A7.909,7.909,0,0,1,9.688,17.588Z" fill="#fff" />
	                  </g>
	                </g>
	                <g id="Group_1410" data-name="Group 1410" transform="translate(15.084 15.084)">
	                  <g id="Group_1409" data-name="Group 1409">
	                    <path id="Path_5668" data-name="Path 5668" d="M357.7,356.435l-5.127-5.127a.894.894,0,0,0-1.265,1.265l5.127,5.127a.894.894,0,0,0,1.265-1.265Z" transform="translate(-351.046 -351.046)" fill="#fff" />
	                  </g>
	                </g>
	              </svg>
		        </button>
			</div>
		</form>
		';
		return $output;
	}

	public function daisy_preloader() {
        echo '<div id="preloader"></div>';
	}

	public function move_textarea_to_bottom( $fields ) {
		$temp = $fields['comment'];
		unset( $fields['comment'] );
		$fields['comment'] = $temp;
		return $fields;
	}

	/*Allow HTML for the kses post*/
	public function daisy_kses_allowed_html($tags, $context) {
		switch($context) {
			case 'social':
				$tags = array(
					'a' => array('href' => array()),
					'b' => array()
				);
			return $tags;
			case 'allow_link':
				$tags = array(
					'a' => array(
						'class' => array(),
						'href'  => array(),
						'rel'   => array(),
						'title' => array(),
						'target' => array(),
					),
					'b' => array()
				);
			return $tags;
			case 'alltext_allow':
				$tags = array(
					'a' => array(
						'class' => array(),
						'href'  => array(),
						'rel'   => array(),
						'title' => array(),
						'target' => array(),
					),
					'abbr' => array(
						'title' => array(),
					),
					'b' => array(),
					'br' => array(),
					'blockquote' => array(
						'cite'  => array(),
					),
					'cite' => array(
						'title' => array(),
					),
					'code' => array(),
					'del' => array(
						'datetime' => array(),
						'title' => array(),
					),
					'dd' => array(),
					'div' => array(
						'class' => array(),
						'title' => array(),
						'style' => array(),
						'id' 	=> array(),
					),
					'dl' => array(),
					'dt' => array(),
					'em' => array(),
					'h1' => array(),
					'h2' => array(),
					'h3' => array(),
					'h4' => array(),
					'h5' => array(),
					'h6' => array(),
					'i' => array(),
					'img' => array(
						'alt'    => array(),
						'class'  => array(),
						'height' => array(),
						'src'    => array(),
						'srcset' => array(),
						'width'  => array(),
					),
					'li' => array(
						'class' => array(),
					),
					'ol' => array(
						'class' => array(),
					),
					'p' => array(
						'class' => array(),
					),
					'q' => array(
						'cite' => array(),
						'title' => array(),
					),
					'span' => array(
						'class' => array(),
						'title' => array(),
						'style' => array(),
					),
					'strike' => array(),
					'strong' => array(),
					'ul' => array(
						'class' => array(),
					),
				);
				return $tags;
			default:
			return $tags;
		}
	}

	public function excerpt_more() {
		return esc_html__( '...', 'daisy' ) ;
	}
	
	public function elementor_widget_args( $args ) {
		$args['before_widget'] = '<div class="widget single-sidebar padding-bottom1">';
		$args['after_widget']  = '</div>';
		$args['before_title']  = '<h3>';
		$args['after_title']   = '</h3>';
		return $args;
	}

	function cc_mime_types( $mimes ) {
		$mimes['svg'] = 'image/svg+xml';
		return $mimes;
	}

	/* - Daisy Post and taxonomy slug change
	--------------------------------------------------------*/
	public function update_daisy_custom_post_slug( $args, $post_type ) {
		$prefix = DAISY_THEME_PREFIX;
		$theme = wp_get_theme(); // gets the current theme
		if ( 'Daisy' == $theme->name || 'Daisy' == $theme->parent_theme ) {
			$portfolio_slug = RDTheme::$options['single_portfolio_slug'];
			$service_slug = RDTheme::$options['single_service_slug'];
			$team_slug = RDTheme::$options['single_team_slug'];
		    if ( $prefix.'_portfolio' === $post_type ) {
		        $portfolio = array(
		            'rewrite' => array( 'slug' => $portfolio_slug, 'with_front' => false )
		        );
		        return array_merge( $args, $portfolio );
		    }
		    if ( $prefix.'_service' === $post_type ) {
		        $service = array(
		            'rewrite' => array( 'slug' => $service_slug, 'with_front' => false )
		        );
		        return array_merge( $args, $service );
		    }
		    if ( $prefix.'_team' === $post_type ) {
		        $team = array(
		            'rewrite' => array( 'slug' => $team_slug, 'with_front' => false )
		        );
		        return array_merge( $args, $team );
		    }
		}
		return $args;
	}

	public function daisy_change_taxonomies_slug( $args, $taxonomy ) {
		$prefix = DAISY_THEME_PREFIX;

		$portfolio_cat_slug = RDTheme::$options['portfolio_cat_slug'];
		$service_cat_slug   = RDTheme::$options['service_cat_slug'];

	    if ( $prefix.'_portfolio_category' === $taxonomy ) {
	    	$args['rewrite']['slug'] = $portfolio_cat_slug;
	    }
	    if ( $prefix.'_service_category' === $taxonomy ) {
	    	$args['rewrite']['slug'] = $service_cat_slug;
	    }
	   return $args;
	}

	public function w3c_validator() {
		/*----------------------------------------------------------------------------------------------------*/
		/*  W3C validator passing code
		/*----------------------------------------------------------------------------------------------------*/
	    ob_start( function( $buffer ){
	        $buffer = str_replace( array( '<script type="text/javascript">', "<script type='text/javascript'>" ), '<script>', $buffer );
	        return $buffer;
	    });
	    ob_start( function( $buffer2 ){
	        $buffer2 = str_replace( array( "<script type='text/javascript' src" ), '<script src', $buffer2 );
	        return $buffer2;
	    });
	    ob_start( function( $buffer3 ){
	        $buffer3 = str_replace( array( 'type="text/css"', "type='text/css'", 'type="text/css"', ), '', $buffer3 );
	        return $buffer3;
	    });
	    ob_start( function( $buffer4 ){
	        $buffer4 = str_replace( array( '<iframe frameborder="0" scrolling="no" marginheight="0" marginwidth="0"', ), '<iframe', $buffer4 );
	        return $buffer4;
	    });
		ob_start( function( $buffer5 ){
	        $buffer5 = str_replace( array( 'aria-required="true"', ), '', $buffer5 );
	        return $buffer5;
	    });
	}

}
new General_Setup;

/*user icon*/
if( !function_exists( 'radius_author_shape' ) ) {
	function radius_author_shape() {
	    return '<svg width="21" height="21" viewBox="0 0 21 21" fill="none" xmlns="http://www.w3.org/2000/svg">
		<path d="M10.25 4.53571C9.54364 4.53571 8.85314 4.74517 8.26582 5.13761C7.6785 5.53004 7.22075 6.08782 6.95043 6.74041C6.68012 7.39301 6.60939 8.1111 6.7472 8.80389C6.885 9.49668 7.22515 10.133 7.72462 10.6325C8.22409 11.132 8.86046 11.4721 9.55325 11.6099C10.246 11.7477 10.9641 11.677 11.6167 11.4067C12.2693 11.1364 12.8271 10.6786 13.2195 10.0913C13.612 9.504 13.8214 8.8135 13.8214 8.10714C13.8214 7.15994 13.4452 6.25153 12.7754 5.58176C12.1056 4.91199 11.1972 4.53571 10.25 4.53571ZM10.25 10.25C9.82618 10.25 9.41188 10.1243 9.05949 9.88886C8.7071 9.6534 8.43245 9.31873 8.27026 8.92718C8.10807 8.53562 8.06564 8.10476 8.14832 7.68909C8.231 7.27342 8.43509 6.8916 8.73477 6.59191C9.03446 6.29223 9.41628 6.08814 9.83195 6.00546C10.2476 5.92278 10.6785 5.96521 11.07 6.1274C11.4616 6.28959 11.7963 6.56424 12.0317 6.91663C12.2672 7.26902 12.3929 7.68332 12.3929 8.10714C12.3923 8.67529 12.1663 9.22 11.7646 9.62174C11.3629 10.0235 10.8181 10.2494 10.25 10.25Z" fill="black"/>
		<path d="M10.25 0.25C8.27219 0.25 6.33879 0.83649 4.6943 1.9353C3.04981 3.03412 1.76809 4.5959 1.01121 6.42316C0.254333 8.25042 0.0562996 10.2611 0.442152 12.2009C0.828004 14.1407 1.78041 15.9225 3.17894 17.3211C4.57746 18.7196 6.35929 19.672 8.2991 20.0578C10.2389 20.4437 12.2496 20.2457 14.0768 19.4888C15.9041 18.7319 17.4659 17.4502 18.5647 15.8057C19.6635 14.1612 20.25 12.2278 20.25 10.25C20.247 7.59876 19.1924 5.05698 17.3177 3.18227C15.443 1.30756 12.9012 0.253025 10.25 0.25ZM5.96429 17.6621V16.6786C5.96486 16.1104 6.1908 15.5657 6.59254 15.164C6.99428 14.7622 7.539 14.5363 8.10715 14.5357H12.3929C12.961 14.5363 13.5057 14.7622 13.9075 15.164C14.3092 15.5657 14.5351 16.1104 14.5357 16.6786V17.6621C13.2351 18.4216 11.7561 18.8218 10.25 18.8218C8.74392 18.8218 7.26488 18.4216 5.96429 17.6621ZM15.9586 16.6257C15.9443 15.6888 15.5626 14.795 14.8956 14.1368C14.2287 13.4787 13.3299 13.1089 12.3929 13.1071H8.10715C7.17013 13.1089 6.27132 13.4787 5.60435 14.1368C4.93739 14.795 4.55567 15.6888 4.54143 16.6257C3.24612 15.4691 2.33267 13.9463 1.92203 12.259C1.51139 10.5718 1.62293 8.79953 2.24189 7.17704C2.86084 5.55455 3.95802 4.15833 5.38813 3.17326C6.81823 2.18819 8.51382 1.66073 10.2504 1.66073C11.9869 1.66073 13.6825 2.18819 15.1126 3.17326C16.5427 4.15833 17.6399 5.55455 18.2588 7.17704C18.8778 8.79953 18.9893 10.5718 18.5787 12.259C18.168 13.9463 17.2539 15.4691 15.9586 16.6257Z" fill="black"/>
		</svg>';
	}
}

/*comment icon*/
if( !function_exists( 'radius_comment_shape' ) ) {
	function radius_comment_shape() {
	    return '<svg width="20.448" height="18.813" viewBox="0 0 20.448 18.813"><g transform="translate(-0.001 1.332)"><path data-name="Path 5661" d="M17.638-1.332H2.812A2.814,2.814,0,0,0,0,1.479v9.073a2.814,2.814,0,0,0,2.8,2.811v4.117l5.917-4.117h8.919a2.814,2.814,0,0,0,2.811-2.811V1.479a2.814,2.814,0,0,0-2.811-2.811Zm1.613,11.884a1.615,1.615,0,0,1-1.613,1.613H8.343L4,15.187V12.165H2.812A1.615,1.615,0,0,1,1.2,10.552V1.479A1.615,1.615,0,0,1,2.812-.134H17.638a1.615,1.615,0,0,1,1.613,1.613Zm0,0" fill="#061526" /><path data-name="Path 5662" d="M171.293,131.172h9.5v1.2h-9.5Zm0,0" transform="translate(-165.819 -128.271)" fill="#061526" /><path data-name="Path 5663" d="M171.293,211.172h9.5v1.2h-9.5Zm0,0" transform="translate(-165.819 -205.715)" fill="#061526" /><path data-name="Path 5664" d="M171.293,291.172h9.5v1.2h-9.5Zm0,0" transform="translate(-165.819 -283.159)" fill="#061526" /></g></svg>';
	}
}

/*category icon*/
if( !function_exists( 'radius_cat_shape' ) ) {
	function radius_cat_shape() {
	    return '<svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
		<path d="M7.36063 5.15244C7.36063 5.73809 7.12799 6.29975 6.71387 6.71387C6.29975 7.12799 5.73809 7.36063 5.15244 7.36063C4.5668 7.36063 4.00513 7.12799 3.59102 6.71387C3.1769 6.29975 2.94425 5.73809 2.94425 5.15244C2.94425 4.5668 3.1769 4.00513 3.59102 3.59102C4.00513 3.1769 4.5668 2.94425 5.15244 2.94425C5.73809 2.94425 6.29975 3.1769 6.71387 3.59102C7.12799 4.00513 7.36063 4.5668 7.36063 5.15244ZM5.88851 5.15244C5.88851 4.95723 5.81096 4.77001 5.67292 4.63197C5.53488 4.49393 5.34766 4.41638 5.15244 4.41638C4.95723 4.41638 4.77001 4.49393 4.63197 4.63197C4.49393 4.77001 4.41638 4.95723 4.41638 5.15244C4.41638 5.34766 4.49393 5.53488 4.63197 5.67292C4.77001 5.81096 4.95723 5.88851 5.15244 5.88851C5.34766 5.88851 5.53488 5.81096 5.67292 5.67292C5.81096 5.53488 5.88851 5.34766 5.88851 5.15244Z" fill="black"/>
		<path d="M1.47213 0H8.2233C8.6137 8.33774e-05 8.98808 0.155237 9.26409 0.431333L19.569 10.7362C19.845 11.0123 20 11.3867 20 11.777C20 12.1674 19.845 12.5417 19.569 12.8178L12.8178 19.569C12.5417 19.845 12.1674 20 11.777 20C11.3867 20 11.0123 19.845 10.7362 19.569L0.431333 9.26409C0.155237 8.98808 8.33774e-05 8.6137 0 8.2233V1.47213C0 1.08169 0.155099 0.707253 0.431176 0.431176C0.707253 0.155099 1.08169 0 1.47213 0ZM1.47213 8.2233L11.777 18.5282L18.5282 11.777L8.2233 1.47213H1.47213V8.2233Z" fill="black"/>
		</svg>';
	}
}

/*calender icon*/
if( !function_exists( 'radius_calender_shape' ) ) {
	function radius_calender_shape() {
	    return '<svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
		<path d="M17.5 2H14.5V0.5C14.5 0.367392 14.4473 0.240215 14.3536 0.146447C14.2598 0.0526785 14.1326 0 14 0C13.8674 0 13.7402 0.0526785 13.6464 0.146447C13.5527 0.240215 13.5 0.367392 13.5 0.5V2H6.5V0.5C6.5 0.367392 6.44732 0.240215 6.35355 0.146447C6.25979 0.0526785 6.13261 0 6 0C5.86739 0 5.74021 0.0526785 5.64645 0.146447C5.55268 0.240215 5.5 0.367392 5.5 0.5V2H2.5C1.8372 2.00079 1.20178 2.26444 0.73311 2.73311C0.264441 3.20178 0.000793929 3.8372 0 4.5V17.5C0.000793929 18.1628 0.264441 18.7982 0.73311 19.2669C1.20178 19.7356 1.8372 19.9992 2.5 20H17.5C18.1629 19.9995 18.7985 19.7359 19.2672 19.2672C19.7359 18.7985 19.9995 18.1629 20 17.5V4.5C19.9995 3.83712 19.7359 3.20154 19.2672 2.73282C18.7985 2.26409 18.1629 2.00053 17.5 2ZM19 17.5C19 17.8978 18.842 18.2794 18.5607 18.5607C18.2794 18.842 17.8978 19 17.5 19H2.5C2.10218 19 1.72064 18.842 1.43934 18.5607C1.15804 18.2794 1 17.8978 1 17.5V9H19V17.5ZM19 8H1V4.5C1 3.672 1.67 3 2.5 3H5.5V4.5C5.5 4.63261 5.55268 4.75979 5.64645 4.85355C5.74021 4.94732 5.86739 5 6 5C6.13261 5 6.25979 4.94732 6.35355 4.85355C6.44732 4.75979 6.5 4.63261 6.5 4.5V3H13.5V4.5C13.5 4.63261 13.5527 4.75979 13.6464 4.85355C13.7402 4.94732 13.8674 5 14 5C14.1326 5 14.2598 4.94732 14.3536 4.85355C14.4473 4.75979 14.5 4.63261 14.5 4.5V3H17.5C17.8978 3 18.2794 3.15804 18.5607 3.43934C18.842 3.72064 19 4.10218 19 4.5V8Z" fill="black"/>
		</svg>';
	}
}

