<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\daisy;
use radiustheme\daisy\inc\RDTheme;
use radiustheme\daisy\inc\Helper;

class Layouts {
	public $daisy = DAISY_THEME_PREFIX;
	public $cpt  = DAISY_THEME_CPT_PREFIX;

	public function __construct() {
		add_action( 'template_redirect', array( $this, 'layout_settings' ) );
	}
	public function layout_settings() {
		// Single Pages
		if( is_single() || is_page() ) {
			$post_type = get_post_type();
			$post_id   = get_the_ID();

			switch( $post_type ) {
				case 'page':
					$daisy = 'page';
					break;
				case 'post':
					$daisy = 'single_post';
					break;
				case "{$this->cpt}_service":
					$daisy = 'service';
					break;
				case "{$this->cpt}_teams":
					$daisy = 'team';
					break;
				case "{$this->cpt}_portfolio":
					$daisy = 'portfolio';
					break;
				default:
					$daisy = 'single_post';
					break;
			}

			$layout         	  = get_post_meta( $post_id, "{$this->cpt}_layout", true );
			$header_style   	  = get_post_meta( $post_id, "{$this->cpt}_header", true );
			$tr_header   	      = get_post_meta( $post_id, "{$this->cpt}_tr_header", true );
			$footer_style   	  = get_post_meta( $post_id, "{$this->cpt}_footer", true );
			$has_banner     	  = get_post_meta( $post_id, "{$this->cpt}_banner", true );
			$has_breadcrumb 	  = get_post_meta( $post_id, "{$this->cpt}_breadcrumb", true );
			$bgtype         	  = get_post_meta( $post_id, "{$this->cpt}_banner_type", true );
			$bgcolor        	  = get_post_meta( $post_id, "{$this->cpt}_banner_bgcolor", true );
			$bgimg          	  = get_post_meta( $post_id, "{$this->cpt}_banner_bgimg", true );			
			$bgimgoverlay   	  = get_post_meta( $post_id, "{$this->cpt}_banner_bgimage_overlay", true );	
			$overlayopacity 	  = get_post_meta( $post_id, "{$this->cpt}_overlay_opacity", true );
			$inner_padding_top    = get_post_meta( $post_id, "{$this->cpt}_inner_padding_top", true );	
			$inner_padding_bottom = get_post_meta( $post_id, "{$this->cpt}_inner_padding_bottom", true );

			
			RDTheme::$layout = ( empty( $layout ) || $layout == 'default' ) ? RDTheme::$options[$daisy . '_layout'] : $layout;
			RDTheme::$header_style = ( empty( $header_style ) || $header_style == 'default' ) ? RDTheme::$options['header_style'] : $header_style;
			RDTheme::$top_bar_style = ( empty( $top_bar_style ) || $top_bar_style == 'default' ) ? RDTheme::$options['top_bar_style'] : $top_bar_style;
			RDTheme::$tr_header = ( empty( $tr_header ) || $tr_header == 'default' ) ? RDTheme::$options['tr_header'] : $tr_header;
			RDTheme::$footer_style = ( empty( $footer_style ) || $footer_style == 'default' ) ? RDTheme::$options['footer_style'] : $footer_style;
			RDTheme::$has_banner = ( empty( $has_banner ) || $has_banner == 'default' ) ? RDTheme::$options[$daisy . '_banner'] : $has_banner;
			RDTheme::$has_breadcrumb = ( empty( $has_breadcrumb ) || $has_breadcrumb == 'default' ) ? RDTheme::$options[$daisy . '_breadcrumb'] : $has_breadcrumb;
			RDTheme::$bgtype = ( empty( $bgtype ) || $bgtype == 'default' ) ? RDTheme::$options[$daisy . '_banner_bg_type'] : $bgtype;
			RDTheme::$bgcolor = empty( $bgcolor ) ? RDTheme::$options[$daisy . '_banner_bgcolor'] : $bgcolor;
			RDTheme::$inner_padding_top = empty( $inner_padding_top ) ? RDTheme::$options[$daisy . '_inner_padding_top'] : $inner_padding_top;
			RDTheme::$inner_padding_bottom = empty( $inner_padding_bottom ) ? RDTheme::$options[$daisy . '_inner_padding_bottom'] : $inner_padding_bottom;


			if( !empty( $bgimg ) ) {
				$attch_url      = wp_get_attachment_image_src( $bgimg, 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}
			elseif( !empty( RDTheme::$options[$daisy . '_banner_bgimg']) ) {
				$attch_url      = wp_get_attachment_image_src( RDTheme::$options[$daisy . '_banner_bgimg'], 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}
			else {
				RDTheme::$bgimg = Helper::get_img( 'inner-banner.jpg' );
			}
			if ( !is_active_sidebar( 'sidebar' ) ){
				RDTheme::$layout = 'full-width';
			}

			RDTheme::$bgimgoverlay = empty( $bgimgoverlay ) ? RDTheme::$options[$daisy . '_banner_bgimage_overlay'] : $bgimgoverlay;
			RDTheme::$overlayopacity = empty( $overlayopacity ) ? RDTheme::$options[$daisy . '_overlay_opacity'] : $overlayopacity;

		}

		// Blog and Archive
		elseif( is_home() || is_archive() || is_search() || is_404() ) {
			$daisy = 'page';

			RDTheme::$layout               = RDTheme::$options['blog_layout'];
			RDTheme::$top_bar_style        = RDTheme::$options['top_bar_style'];
			RDTheme::$header_style         = RDTheme::$options['header_style'];
			RDTheme::$tr_header   	       = RDTheme::$options['tr_header'];
			RDTheme::$footer_style         = RDTheme::$options['footer_style'];
			RDTheme::$has_banner           = RDTheme::$options[$daisy . '_banner'];
			RDTheme::$has_breadcrumb       = RDTheme::$options[$daisy . '_breadcrumb'];
			RDTheme::$bgtype               = RDTheme::$options[$daisy . '_banner_bg_type'];
			RDTheme::$bgcolor              = RDTheme::$options[$daisy . '_banner_bgcolor'];
			RDTheme::$bgimgoverlay         = RDTheme::$options[$daisy . '_banner_bgimage_overlay'];
			RDTheme::$overlayopacity       = RDTheme::$options[$daisy . '_overlay_opacity'];
			RDTheme::$inner_padding_top    = RDTheme::$options[$daisy . '_inner_padding_top'];
			RDTheme::$inner_padding_bottom = RDTheme::$options[$daisy . '_inner_padding_bottom'];

			if( is_search() ) {
				$daisy = 'search';
			}
			elseif( is_404() ) {
				$daisy = 'error';
			}
			elseif( is_post_type_archive( "{$this->cpt}_teams" ) || is_tax( "{$this->cpt}_teams_category" ) ) {
				$daisy = 'team_archive';
			}elseif ( is_post_type_archive( "{$this->cpt}_service" ) || is_tax( "{$this->cpt}_service_category" ) ) {
				$daisy = 'service_archive';
			}elseif ( is_post_type_archive( "{$this->cpt}_portfolio" ) || is_tax( "{$this->cpt}_portfolio_category" ) ) {
				$daisy = 'portfolio_archive';
			}				
			else {
				$daisy = 'blog';
			}
		

			if( !empty( RDTheme::$options[$daisy . '_banner_bgimg']) ) {
				$attch_url      = wp_get_attachment_image_src( RDTheme::$options[$daisy . '_banner_bgimg'], 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}elseif( !empty( RDTheme::$options['page_banner_bgimg']) ){
				$attch_url      = wp_get_attachment_image_src( RDTheme::$options['page_banner_bgimg'], 'full', true );
				RDTheme::$bgimg = $attch_url[0];
			}else {
				RDTheme::$bgimg = Helper::get_img( 'inner-banner.jpg' );
			}
			if ( !is_active_sidebar( 'sidebar' ) ){
				RDTheme::$layout = 'full-width';
			}
		}
	}
}
new Layouts;



