<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\daisy;
use radiustheme\daisy\inc\RDTheme;
use radiustheme\daisy\inc\Helper;
use \WP_Query;

if( ! function_exists( 'daisy_related_portfolio' )){
	
	function daisy_related_portfolio(){
		$post_id = get_the_id();	
		$number_of_avail_post = '';
		$current_post = array( $post_id );
		
		$content 	= get_the_content();
		$content 	= apply_filters( 'the_content', $content );
		
		# Making ready to the Query ...
		$query_type = RDTheme::$options['port_related_query'];

		$args = array(
			'post_type'				 => 'daisy_portfolio',
			'post__not_in'           => $current_post,
			'posts_per_page'         => 3,
			'no_found_rows'          => true,
			'post_status'            => 'publish',
			'ignore_sticky_posts'    => true,
			'update_post_term_cache' => false,
		);

		# Checking Related Posts Order ----------
		if( RDTheme::$options['port_related_sort'] ){

			$post_order = RDTheme::$options['port_related_sort'];

			if( $post_order == 'rand' ){

				$args['orderby'] = 'rand';
			}
			elseif( $post_order == 'views' ){

				$args['orderby']  = 'meta_value_num';
				$args['meta_key'] = 'daisy_views';
			}
			elseif( $post_order == 'popular' ){

				$args['orderby'] = 'comment_count';
			}
			elseif( $post_order == 'modified' ){

				$args['orderby'] = 'modified';
				$args['order']   = 'ASC';
			}
			elseif( $post_order == 'recent' ){

				$args['orderby'] = '';
				$args['order']   = '';
			}
		}


		# Get related posts by author ----------
		if( $query_type == 'author' ){
			$args['author'] = get_the_author_meta( 'ID' );
		}

		# Get related posts by tags ----------
		elseif( $query_type == 'tag' ){
			$tags_ids  = array();
			$post_tags = get_the_terms( $post_id, 'post_tag' );

			if( ! empty( $post_tags ) ){
				foreach( $post_tags as $individual_tag ){
					$tags_ids[] = $individual_tag->term_id;
				}

				$args['tag__in'] = $tags_ids;
			}
		}

		# Get related posts by categories ----------
		else{
			
			$terms = get_the_terms( $post_id, 'daisy_portfolio_category' );
			if ( $terms && ! is_wp_error( $terms ) ) {
			 
				$port_cat_links = array();
			 
				foreach ( $terms as $term ) {
					$port_cat_links[] = $term->term_id;
				}
			}
			
			$args['tax_query'] = array (
				array (
					'taxonomy' => 'daisy_portfolio_category',
					'field'    => 'ID',
					'terms'    => $port_cat_links,
				)
			);

		}

		# Get the posts ----------
		$related_query = new wp_query( $args );

		if( $related_query->have_posts() ) { ?>
		<section class="related-portfolio-layout">
			<div class="container">
				<div class="row">
				<?php if( !empty( RDTheme::$options['port_related_title'] ) ) : ?>
				<h3 class="related-portfolio-heading mb-20"><?php echo esc_html(  RDTheme::$options['port_related_title'] ); ?></h3>
				<?php endif; ?>
				<?php
					while ( $related_query->have_posts() ) {
					$related_query->the_post();
				?>
					<div class="col-lg-4 col-md-6 col-12 pb-30">
				      <div class="portfolio portfolio--style-5 portfolio--style-6 portfolio--style-6">
				        <div class="portfolio__box">
				        <?php if( has_post_thumbnail() ) : ?>
				          <figure class="portfolio__figure m-0">
				            <?php the_post_thumbnail( 'daisy-thumb5' ); ?>
				            <figcaption class="portfolio__content">
				              <h2 class="portfolio__title"><a class="text-white" href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
				              <?php if( RDTheme::$options['port_related_excerpt'] ) : ?>
				              <p class="portfolio__text text-white"><?php echo Helper::daisy_excerpt( RDTheme::$options['port_related_length'] ); ?></p>
				          	  <?php endif; ?>
				            </figcaption>
				          </figure>
				      	<?php endif; ?>
				        </div>
				      </div>
				    </div>
				<?php } ?>
				</div>
			</div>
		</section>
		<?php }
		wp_reset_postdata();
	}
}
?>