<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\daisy;
use radiustheme\daisy\inc\RDTheme;
use \WP_Query;

if( ! function_exists( 'daisy_related_post' )){
	
	function daisy_related_post(){
			
		$post_id = get_the_id();	
		$number_of_avail_post = '';
		$current_post = array( $post_id );	
		$title_length = RDTheme::$options['show_related_post_title_limit'] ? RDTheme::$options['show_related_post_title_limit'] : '';
		$related_post_number = RDTheme::$options['show_related_post_number'];

		# Making ready to the Query ...
		$query_type = RDTheme::$options['related_post_query'];

		$args = array(
			'post__not_in'           => $current_post,
			'posts_per_page'         => $related_post_number,
			'no_found_rows'          => true,
			'post_status'            => 'publish',
			'ignore_sticky_posts'    => true,
			'update_post_term_cache' => false,
		);

		# Checking Related Posts Order ----------
		if( RDTheme::$options['related_post_sort'] ){

			$post_order = RDTheme::$options['related_post_sort'];

			if( $post_order == 'rand' ){

				$args['orderby'] = 'rand';
			}
			elseif( $post_order == 'views' ){

				$args['orderby']  = 'meta_value_num';
				$args['meta_key'] = 'daisy_views';
			}
			elseif( $post_order == 'popular' ){

				$args['orderby'] = 'comment_count';
			}
			elseif( $post_order == 'modified' ){

				$args['orderby'] = 'modified';
				$args['order']   = 'ASC';
			}
			elseif( $post_order == 'recent' ){

				$args['orderby'] = '';
				$args['order']   = '';
			}
		}


		# Get related posts by author ----------
		if( $query_type == 'author' ){
			$args['author'] = get_the_author_meta( 'ID' );
		}

		# Get related posts by tags ----------
		elseif( $query_type == 'tag' ){
			$tags_ids  = array();
			$post_tags = get_the_terms( $post_id, 'post_tag' );

			if( ! empty( $post_tags ) ){
				foreach( $post_tags as $individual_tag ){
					$tags_ids[] = $individual_tag->term_id;
				}

				$args['tag__in'] = $tags_ids;
			}
		}

		# Get related posts by categories ----------
		else{
			$category_ids = array();
			$categories   = get_the_category( $post_id );

			foreach( $categories as $individual_category ){
				$category_ids[] = $individual_category->term_id;
			}

			$args['category__in'] = $category_ids;
		}

		# Get the posts ----------
		$related_query = new wp_query( $args );

		$slick_content = array( 
		    'slidesToShow'        => 3,
		    'slidesToShowTab'     => 2,
		    'slidesToShowMobile'  => 2,
		    'slidesToShowMobiles' => 1,
		    'autoplaySpeed'       => 2000,
		    'dots'                => false,
		    'arrows'              => false,
		    'autoplay'            => true,
		    'rtl'                 => false,
		);
		$slick_content = htmlspecialchars(wp_json_encode($slick_content), ENT_QUOTES, 'UTF-8');
		
		if( $related_query->have_posts() ) { ?>
		<div class="mb-5">
	        <h3 class="inner-title mb-4"><?php esc_html_e ( 'Related Posts', 'daisy' ); ?></h3>
			<div class="related-post-carousel1" data-slick='<?php echo esc_attr( $slick_content ); ?>'>
				<?php
					while ( $related_query->have_posts() ) {
					$related_query->the_post();
					$trimmed_title = wp_trim_words( get_the_title(), $title_length, '' );
				?>
				<div class="blog-box-layout1 style-3">
					<?php if ( has_post_thumbnail()  ) { ?>
					<div class="item-img">
						<a href="<?php the_permalink(); ?>">
							<?php
								$id = get_the_ID();
								$thumbnail = false;
								if ( has_post_thumbnail() ){
									$post_thumbnail_id = get_post_thumbnail_id( $id );
									$image_attributes = wp_get_attachment_image( $post_thumbnail_id , 'daisy-size3'  );
									if ( $image_attributes ) : ?>
										<?php echo wp_kses_post( $image_attributes ); ?>
									<?php endif; 
								}
								echo wp_kses( $thumbnail , 'alltext_allow' );
							?>
						</a>
						<?php if( RDTheme::$options['show_related_post_cat'] && has_category() ) : ?>
							<div class="meta-category"><?php the_category( ' ' );?></div>
						<?php endif; ?>
					</div>
					<?php } ?>
					<div class="item-content">
						<?php if( RDTheme::$options['show_related_post_date'] ) : ?>
						<ul class="entry-meta">
							<li class="entry-date"><i class="far fa-calendar-alt"></i><?php the_time( get_option( 'date_format' ) );?></li>
						</ul>
						<?php endif; ?>
						<h3 class="entry-title"><a href="<?php the_permalink(); ?>"><?php echo esc_html( $trimmed_title ); ?></a></h3>
					</div>
				</div>
				<?php } ?>
			</div>
		</div>
		<?php }

		wp_reset_postdata();
	}
}
?>