<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\daisy;
use radiustheme\daisy\inc\RDTheme;
use radiustheme\daisy\inc\Helper;
use \WP_Query;

if( ! function_exists( 'daisy_related_team' )){
	
	function daisy_related_team(){
		$post_id = get_the_id();	
		$number_of_avail_post = '';
		$current_post = array( $post_id );
		
		$content 	= get_the_content();
		$content 	= apply_filters( 'the_content', $content );
		
		# Making ready to the Query ...
		$query_type = RDTheme::$options['team_related_query'];

		$args = array(
			'post_type'				 => 'daisy_team',
			'post__not_in'           => $current_post,
			'posts_per_page'         => 3,
			'no_found_rows'          => true,
			'post_status'            => 'publish',
			'ignore_sticky_posts'    => true,
			'update_post_term_cache' => false,
		);

		# Checking Related Posts Order ----------
		if( RDTheme::$options['team_related_sort'] ){

			$post_order = RDTheme::$options['team_related_sort'];

			if( $post_order == 'rand' ){

				$args['orderby'] = 'rand';
			}
			elseif( $post_order == 'views' ){

				$args['orderby']  = 'meta_value_num';
				$args['meta_key'] = 'daisy_views';
			}
			elseif( $post_order == 'popular' ){

				$args['orderby'] = 'comment_count';
			}
			elseif( $post_order == 'modified' ){

				$args['orderby'] = 'modified';
				$args['order']   = 'ASC';
			}
			elseif( $post_order == 'recent' ){

				$args['orderby'] = '';
				$args['order']   = '';
			}
		}


		# Get related posts by author ----------
		if( $query_type == 'author' ){
			$args['author'] = get_the_author_meta( 'ID' );
		}

		# Get related posts by tags ----------
		elseif( $query_type == 'tag' ){
			$tags_ids  = array();
			$post_tags = get_the_terms( $post_id, 'post_tag' );

			if( ! empty( $post_tags ) ){
				foreach( $post_tags as $individual_tag ){
					$tags_ids[] = $individual_tag->term_id;
				}

				$args['tag__in'] = $tags_ids;
			}
		}

		# Get related posts by categories ----------
		else{
			
			$terms = get_the_terms( $post_id, 'daisy_team_category' );
			if ( $terms && ! is_wp_error( $terms ) ) {
			 
				$port_cat_links = array();
			 
				foreach ( $terms as $term ) {
					$port_cat_links[] = $term->term_id;
				}
			}
			
			$args['tax_query'] = array (
				array (
					'taxonomy' => 'daisy_team_category',
					'field'    => 'ID',
					'terms'    => $port_cat_links,
				)
			);

		}

		# Get the posts ----------
		$related_query = new wp_query( $args );

		if( $related_query->have_posts() ) { ?>
		<section class="related-team-layout">
			<?php if ( $related_query->have_posts() ) { ?>
			<div class="row">
				<?php if( !empty( RDTheme::$options['team_related_title'] ) ) : ?>
				<h3 class="related-team-heading mb-30"><?php echo esc_html(  RDTheme::$options['team_related_title'] ); ?></h3>
				<?php endif; ?>
				<?php 
		         while ( $related_query->have_posts() ) : $related_query->the_post(); 
		         	$team_desigantion = get_post_meta( get_the_ID(), 'daisy_team_desigantion', true );
	        		$socials = get_post_meta( get_the_ID(), "daisy_team_socials", true );
		      	?>
				<div class="col-md-4 col-12">
			      <div class="single-item">
			          <div class="team team--style-5">
			            <div class="team__img">
			              <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'daisy-thumb5' ); ?></a>
			              <?php if ( !empty( $socials ) && RDTheme::$options['team_archive_social'] == 1 ){ ?>
			              <div class="team__social team-social-area">
			                <ul class="social social--style-1">
			                  <?php foreach ( $socials as $key => $value ) { 
			                    if (!empty( $value )) {
			                      switch ($key) {
			                        case 'facebook':
			                        $icon = 'fab fa-facebook-f';
			                        break;
			                        case 'twitter':
			                        $icon = 'fab fa-twitter';
			                        break;
			                        case 'linkedin':
			                        $icon = 'fab fa-linkedin-in';
			                        break;
			                        case 'behance':
			                        $icon = 'fab fa-behance';
			                        break;
			                        case 'dribbble':
			                        $icon = 'fab fa-dribbble';
			                        break; 
			                        case 'skype':
			                        $icon = 'fab fa-skype';
			                        break;
			                        case 'youtube':
			                        $icon = 'fab fa-youtube';
			                        break;
			                        case 'pinterest':
			                        $icon = 'fab fa-pinterest-p';
			                        break;
			                        case 'instagram':
			                        $icon = 'fab fa-instagram';
			                        break;
			                        case 'github':
			                        $icon = 'fab fa-github-alt';
			                        break;
			                        case 'stackoverflow':
			                        $icon = 'fab fa-stack-overflow';
			                        break;
			                        default:
			                        $icon = '';
			                        break;
			                      }
			                  ?>
			                  <li class="social__item">
			                    <a href="<?php echo esc_url( $value ); ?>" class="social__link"><i class="<?php echo esc_attr( $icon ); ?>"></i></a>
			                  </li>
			                  <?php } } ?>
			                </ul>
			              </div>
			              <?php } ?>
			            </div>
			            <div class="team__content">
			              <h3 class="team__author-name"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
			              <?php if ( !empty( $team_desigantion ) && RDTheme::$options['team_archive_desig'] == 1 ) : ?>
			              <span class="team__author-designation"><?php echo esc_html( $team_desigantion ); ?></span>
			              <?php endif; ?>
			            </div>
			          </div>
			        </div>
			    </div>
				<?php endwhile; ?>
			</div>
			<?php }else{ 
		      get_template_part( 'template-parts/content', 'none' );
		    } ?>
		</section>
		<?php }
		wp_reset_postdata();
	}
}
?>