<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;


if ( ! defined( 'ABSPATH' ) ) exit;

class Address extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Address', 'daisy-core' );
		$this->rt_base = 'rt-address';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_invitation',
				'mode'    => 'section_start',
				'label'   => __( 'General', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => __( 'Title', 'daisy-core' ),
				'default' => __( 'Melborne', 'daisy-core' ),
				'label_block' => true,
			),
			array(	
				'id'      => 'icontype',				 
			   	'type'    => Controls_Manager::CHOOSE,
			   	'label'   => esc_html__( 'Media Type', 'daisy-core' ),
			   	'options' => [
				    'icon' => [
				       'title' => esc_html__( 'Icon', 'daisy-core' ),
				       'icon' => 'far fa-smile',
				    ],
				    'image' => [
				       'title' => esc_html__( 'Image', 'daisy-core' ),
				       'icon' => 'fa fa-image',
				    ],		     
			   	],
			   	'default' => 'icon',
			   	'label_block' => false,
			   	'toggle' => false,
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'icon_class',
				'label'   => esc_html__( 'Icon', 'daisy-core' ),
				'default' => [
			      'value' => 'fas fa-map-marker-alt',
			      'library' => 'fa-solid',
			  ],	
			  	'condition'   => array( 'icontype' => 'icon' ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'icon_image',
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'condition'   => array( 'icontype' => 'image' ),
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'address',
				'label'   => __( 'Address', 'daisy-core' ),
				'default' => __( 'Cecilia Chapman <br>711-2880 Nulla St.<br> Mankato Mississippi 96522', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title2',
				'label'   => __( 'Title 2', 'daisy-core' ),
				'default' => __( 'Sydne', 'daisy-core' ),
				'label_block' => true,
			),
			array(	
				'id'      => 'icontype2',				 
			   	'type'    => Controls_Manager::CHOOSE,
			   	'label'   => esc_html__( 'Media Type', 'daisy-core' ),
			   	'options' => [
				    'icon' => [
				       'title' => esc_html__( 'Icon', 'daisy-core' ),
				       'icon' => 'far fa-smile',
				    ],
				    'image' => [
				       'title' => esc_html__( 'Image', 'daisy-core' ),
				       'icon' => 'fa fa-image',
				    ],		     
			   	],
			   	'default' => 'icon',
			   	'label_block' => false,
			   	'toggle' => false,
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'icon_class2',
				'label'   => esc_html__( 'Icon', 'daisy-core' ),
				'default' => [
			      'value' => 'fas fa-map-marker-alt',
			      'library' => 'fa-solid',
			  ],	
			  	'condition'   => array( 'icontype2' => 'icon' ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'icon_image2',
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'condition'   => array( 'icontype2' => 'image' ),
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'address2',
				'label'   => __( 'Address 2', 'daisy-core' ),
				'default' => __( 'Iris Watson <br/>P.O. Box 283 8562 Fusce Rd. <br>Frederick Nebraska 20620', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .text' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .text',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'address_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Address', 'daisy-core' ),
			),
			array(
				'id'      => 'address_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .contact-widget__list p' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'address_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .contact-widget__list p',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'phone_email_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Icon', 'daisy-core' ),
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .contact-widget--style-2 .icon' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'icon_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .contact-widget--style-2 .icon',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}