<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;


if ( ! defined( 'ABSPATH' ) ) exit;

class Banner extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Banner', 'daisy-core' );
		$this->rt_base = 'rt-banner';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_banner',
				'mode'    => 'section_start',
				'label'   => __( 'Banner', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'image',
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => __( 'Title', 'daisy-core' ),
				'default' => __( 'Hey, I\'m a digital <span class="text-ex">product designer.</span>', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'content',
				'label'   => __( 'Contet', 'daisy-core' ),
				'default' => __('Hi, I\'m Jason a freelance web designer from San-Francisco. I help brands turn', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'btn1_text',
				'label'   => __( 'Button Text', 'daisy-core' ),
				'default' => __( 'Hire Me', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'btn1_icon',
				'label'   => esc_html__( 'Button Icon', 'daisy-core' ),
				'default' => array(
			      'value' => 'far fa-envelope',
			      'library' => 'far fa-envelope',
				),
			),
			array(
				'type'    => Controls_Manager::URL,
				'id'      => 'btn1_url',
				'label'   => esc_html__( 'Button URL', 'daisy-core' ),
				'placeholder' => esc_url('https://your-link.com' ),
                'label_block' => true, 
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'btn2_text',
				'label'   => __( 'Button 2 Text', 'daisy-core' ),
				'default' => __( 'Download Resume', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'btn2_icon',
				'label'   => esc_html__( 'Button 2 Icon', 'daisy-core' ),
				'default' => array(
			      'value' => 'fas fa-cloud-download-alt',
			      'library' => 'fas fa-cloud-download-alt',
				),
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::URL,
				'id'      => 'btn2_url',
				'label'   => esc_html__( 'Button 2 URL', 'daisy-core' ),
				'placeholder' => esc_url('https://your-link.com' ),
                'label_block' => true,
                'condition'   => array( 'style' => array( 'style1' ) ), 
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'showhide',
				'label'   => esc_html__( 'Scroll', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'scroll_id',
				'label'   => __( 'Scroll Id', 'daisy-core' ),
				'default' => __( 'aboutSection1', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'showhide' =>'yes', 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'scroll_txt',
				'label'   => __( 'Scroll Text', 'daisy-core' ),
				'default' => __( 'Explore', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'showhide' =>'yes', 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .banner--style-1::after' => 'background-color: {{VALUE}} !important' ),
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .banner-content__title' => 'color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'title_color2',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color 2', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .banner-content__title .text-ex' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .banner-content__title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .banner-content__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .banner-content__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
	        array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'    => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
	        array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Content', 'daisy-core' ),
			),
			array(
				'id'      => 'content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .banner-content p' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'content_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .banner-content p',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'btn1_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button', 'daisy-core' ),
			),
			array(
				'id'      => 'btn1_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-btn--1' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .rt-btn--14' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'btn1_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-btn--1' => 'background-color: {{VALUE}} !important', 
					'{{WRAPPER}} .rt-btn--14' => 'background-color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'btn1_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .rt-btn--1,
					{{WRAPPER}} .rt-btn--14
				',
			),
			array(
				'name'     => 'btn1_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .rt-btn--1,
					{{WRAPPER}} .rt-btn--14
				',
			),
			array(
				'id'      => 'btn1_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'btn1_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-btn--1:hover' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .rt-btn--14:hover' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'id'      => 'btn1_hbg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-btn--1::before' => 'background-color: {{VALUE}} !important', 
					'{{WRAPPER}} .rt-btn--14:hover' => 'background-color: {{VALUE}} !important', 
				),
			),
			array(
				'name'     => 'btn1_h_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .rt-btn--1:hover,
					{{WRAPPER}} .rt-btn--14:hover
				',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'btn2_style',  
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button 2', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'btn2_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-btn--2' => 'color: {{VALUE}} !important' ),
			),
			array(
				'id'      => 'btn2_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-btn--2 .icon--2' => 'background-color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'btn2_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .rt-btn--2',
			),
			array(
				'id'      => 'btn2_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'btn2_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-btn--2:hover' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'explore_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Explore', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'explore_txt_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Text Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-scroll-spy-btn .spy-text' => 'color: {{VALUE}} !important' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'explore_txt_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .rt-scroll-spy-btn .spy-text',
			),
			array(
				'id'      => 'explore_btn_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Button Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-scroll-spy-btn .spy-dot' => 'background-color: {{VALUE}} !important', 
					'{{WRAPPER}} .rt-scroll-spy-btn' => 'border-color: {{VALUE}} !important', 
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ( $data['style'] ) {
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}