<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Button extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Button', 'daisy-core' );
		$this->rt_base = 'rt-button';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'General', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
					'style3' => esc_html__( 'Style 3', 'daisy-core' ),
					'style4' => esc_html__( 'Style 4', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			array(
				'type' => Controls_Manager::CHOOSE,
				'id'      => 'content_align',
				'mode'	  => 'responsive',
				'label'   => esc_html__( 'Alignment', 'daisy-core' ),
				'options' => array(
					'left' => array(
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					),
					'center' => array(
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					),
					'right' => array(
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					),
					'justify' => array(
						'title' => __( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					),
				),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}}' => 'text-align: {{VALUE}};',
				),
			),
			array(
				'type'    	  => Controls_Manager::TEXT,
				'id'      	  => 'buttontext',
				'label'   	  => esc_html__( 'Button Text', 'daisy-core' ),
				'default' 	  => esc_html__( 'CONTACT US', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::URL,
				'id'      => 'buttonurl',
				'label'   => esc_html__( 'Button URL', 'daisy-core' ),
				'placeholder' => 'https://your-link.com',
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'btn_icon',
				'label'   => esc_html__( 'Button Icon', 'daisy-core' ),
				'default' => array(
			      'value' => 'far fa-envelope',
			      'library' => 'far fa-envelope',
				),
			),
			array(
				'mode' => 'section_end',
			),
			// Button style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_button_style',
				'label'   => esc_html__( 'Button Style', 'daisy-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'button_typo',
				'label'   => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .rt-btn--1, 
					{{WRAPPER}} .rt-btn--7,
					{{WRAPPER}} .rt-btn--14
				',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button_text_color',
				'label'   => esc_html__( 'Text Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-btn--1' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--7' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--14' => 'color: {{VALUE}}',
				),
			),
			array(
				'name'     => 'btn_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .rt-btn--1,
					{{WRAPPER}} .rt-btn--7,
					{{WRAPPER}} .rt-btn--14
				',
			),
			array(
				'name'      => 'btn_bgc',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Background', 'daisy-core' ),
				'selector'  => '
					{{WRAPPER}} .rt-btn--1,
					{{WRAPPER}} .rt-btn--7,
					{{WRAPPER}} .rt-btn--14
				',
			),
			array(
				'id'      => 'btn_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'btn_text_hover_color',
				'label'   => esc_html__( 'Text Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-btn--1:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--7:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--14:hover' => 'color: {{VALUE}}',
				),
			),
			array(
				'name'     => 'btn_h_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .rt-btn--1::before,
					{{WRAPPER}} .rt-btn--7:hover,
					{{WRAPPER}} .rt-btn--14:hover
				',
			),
			array(
				'name'      => 'btn_h_bgc',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Background', 'daisy-core' ),
				'selector'  => '
					{{WRAPPER}} .rt-btn--1::before,
					{{WRAPPER}} .rt-btn--7:hover,
					{{WRAPPER}} .rt-btn--14:hover
				',
			),	
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}