<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/contact-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Contact_Box extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Contact Box', 'daisy-core' );
		$this->rt_base = 'rt-contact-box';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_text', [
				'label' => __( 'Contact Info', 'daisy-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'show_label' => false,
			]
		);
		$repeater->add_control(
			'licon_type', [
				'type'    => Controls_Manager::CHOOSE,
			   	'label'   => esc_html__( 'Media Type', 'daisy-core' ),
			   	'options' => [
				    'icon' => [
				       'title' => esc_html__( 'Icon', 'daisy-core' ),
				       'icon' => 'far fa-smile',
				    ],
				    'image' => [
				       'title' => esc_html__( 'Image', 'daisy-core' ),
				       'icon' => 'fa fa-image',
				    ],		     
			   	],
			   	'default' => 'icon',
			   	'label_block' => false,
			   	'toggle' => false,
			]
		);
		$repeater->add_control(
			'licon_class', [
				'label' => __( 'Icon', 'daisy-core' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'far fa-smile',
					'library' => 'solid',
				],
				'label_block' => true,
				'condition'   => [ 'licon_type' => [ 'icon' ] ],
			],
		);
		$repeater->add_control(
			'licon_img', [
				'label' => __( 'Image', 'daisy-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'label_block' => true,
				'condition'   => [ 'licon_type' => [ 'image' ] ],
			],
		);

		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => __( 'Contact', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
					'style3' => esc_html__( 'Style 3', 'daisy-core' ),
					'style4' => esc_html__( 'Style 4', 'daisy-core' ),
					'style5' => esc_html__( 'Style 5', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			//Icon Start
			array(	
				'id'      => 'icontype',				 
			   	'type'    => Controls_Manager::CHOOSE,
			   	'label'   => esc_html__( 'Media Type', 'daisy-core' ),
			   	'options' => [
				    'icon' => [
				       'title' => esc_html__( 'Icon', 'daisy-core' ),
				       'icon' => 'far fa-smile',
				    ],
				    'image' => [
				       'title' => esc_html__( 'Image', 'daisy-core' ),
				       'icon' => 'fa fa-image',
				    ],		     
			   	],
			   	'default' => 'icon',
			   	'label_block' => false,
			   	'toggle' => false,
			   	'condition'   => array( 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'icon_class',
				'label'   => esc_html__( 'Icon', 'daisy-core' ),
				'default' => [
			      'value' => 'fas fa-map-marker-alt',
			      'library' => 'fa-solid',
			  ],	
			  	'condition'   => array( 'icontype' => 'icon', 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'icon_image',
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'condition'   => array( 'icontype' => 'image', 'style' => array( 'style1', 'style3' ) ),
			),
			//Icon end
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => __( 'Title', 'daisy-core' ),
				'default' => 'Contact Box Title',
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'contact_repeat',
				'label'   => esc_html__( 'Contact Information', 'daisy-core' ),
				'prevent_empty' => false,
				'title_field' => '{{{ list_text }}}',
				'fields' => $repeater->get_controls(),
			),
			array(
				'mode' => 'section_end',
			),
			// Title Styles
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'daisy-core' ),
			),
			array(
				'id'      => 'full_box_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Full Box', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'name'      => 'full_box_bg_color',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .contact-list__item,
						{{WRAPPER}} .contact-widget--style-1,
						{{WRAPPER}} .contact-address__content
					',
			),
			// Icon Color
			array(
				'id'      => 'icon_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon', 'daisy-core' ),
				'separator' => 'before',
				'condition'   => array( 'style' => array( 'style1', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .contact-list__icon' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .contact-address__header > h3 i' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .contact-address__content > ul > li i' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .contact-address__content4 > ul > li i' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .serviceDetails-callCenter__call i' => 'color: {{VALUE}}', 
				),
				'condition'   => array( 'style' => array( 'style1', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'name'     => 'Icon_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .contact-list__icon,
						{{WRAPPER}} .contact-address__header i,
						{{WRAPPER}} .contact-address__content i,
						{{WRAPPER}} .contact-address__content4 i,
						{{WRAPPER}} .serviceDetails-callCenter__call i
					',
				'condition'   => array( 'style' => array( 'style1', 'style3', 'style4', 'style5' ) ),
			),
			// Title
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Style', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .contact-list__title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .contact-address__header > h3' => 'color: {{VALUE}}', 
				),
			),
			array(
				'id'      => 'title_b_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .contact-widget__title::after' => 'background: {{VALUE}}' 
				),
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'name'     => 'title_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .contact-list__title,
						{{WRAPPER}} .contact-widget__title,
						{{WRAPPER}} .contact-address__header > h3
					',
			),
			array(
				'mode' => 'section_end',
			),
			// List Styles
			array(
				'id'      => 'list_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Address Information', 'daisy-core' ),
			),
			array(
				'id'        => 'list_info_heading',
				'type' 	    => Controls_Manager::HEADING,
				'label'     => __( 'Information Style', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'        => 'list_info_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .contact-list__content span' => 'color: {{VALUE}}',
						'{{WRAPPER}} .contact-widget__list li' => 'color: {{VALUE}}',
						'{{WRAPPER}} .contact-address__content > ul > li a' => 'color: {{VALUE}}',
						'{{WRAPPER}} .contact-address__content > ul > li span' => 'color: {{VALUE}}',
						'{{WRAPPER}} .contact-address__content4 > ul > li span a' => 'color: {{VALUE}}',
						'{{WRAPPER}} .contact-address__content4 > ul > li span' => 'color: {{VALUE}}',
						'{{WRAPPER}} .serviceDetails-callCenter__call span a' => 'color: {{VALUE}}',
					),
			),
			array(
				'id'        => 'list_info_i_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Icon Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .contact-address__content > ul > li i' => 'color: {{VALUE}}',
						'{{WRAPPER}} .contact-address__content4 > ul > li i' => 'color: {{VALUE}}',
						'{{WRAPPER}} .serviceDetails-callCenter__call i' => 'color: {{VALUE}}',
					),
				'condition'   => array( 'style' => array( 'style3', 'style4', 'style5' ) ),
			),
			array(
				'name'     => 'list_info_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .contact-list__content span,
						{{WRAPPER}} .contact-widget__list li,
						{{WRAPPER}} .contact-address__content > ul > li a,
						{{WRAPPER}} .contact-address__content > ul > li span,
						{{WRAPPER}} .contact-address__content4 > ul > li span a,
						{{WRAPPER}} .contact-address__content4 > ul > li span,
						{{WRAPPER}} .serviceDetails-callCenter__call span a
					',
			),
			array(
				'id'        => 'link_heading',
				'type' 	    => Controls_Manager::HEADING,
				'label'     => __( 'Link Style', 'daisy-core' ),
				'separator' => 'before',
				'condition'   => array( 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'id'        => 'link_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Link Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .contact-list__content span a' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .contact-address__content > ul > li a' => 'color: {{VALUE}}', 
					),
				'condition'   => array( 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'id'        => 'link_h_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Link Hover Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .contact-list__content span a:hover' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .contact-address__content > ul > li a:hover' => 'color: {{VALUE}}', 
					),
				'condition'   => array( 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style5':
			$template = 'view-5';
			break;
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}
		
		return $this->rt_template( $template, $data );
	}
}