<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/counter/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Counter extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Counter', 'daisy-core' );
		$this->rt_base = 'rt-counter';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'General', 'daisy-core' ),
			),			
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
					'style3' => esc_html__( 'Style 3', 'daisy-core' ),
					'style4' => esc_html__( 'Style 4', 'daisy-core' ),
					'style5' => esc_html__( 'Style 5', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'showhide',
				'label'   => esc_html__( 'Icon/image', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
				'condition'   => array( 'style' => array( 'style1', 'style2', 'style4', 'style5' ) ),
			),
			/*Icon Start*/
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'icon_class',
				'label'   => esc_html__( 'Icon', 'daisy-core' ),
				'default' => array(
			      'value' => 'fas fa-users',
			      'library' => 'fas fa-users',
				),
				'condition'   => array( 'showhide' =>'yes', 'style' => array( 'style1', 'style2', 'style4', 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => esc_html__( 'Active Clients', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'number',
				'label'   => esc_html__( 'Counter Number', 'daisy-core' ),
				'default' => 325,
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'description',
				'label'   => esc_html__( 'Description', 'daisy-core' ),
				'default' => esc_html__( 'Daisy started its operation in the year 1999. We are', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style3' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_colors',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'title_color',
				'label'   => esc_html__( 'Title Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .counter--style-1 .counter__desc' => 'color: {{VALUE}}',
					'{{WRAPPER}} .counter--style-2 .counter__desc' => 'color: {{VALUE}}',
					'{{WRAPPER}} .about-block__title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-list--style-1 .rt-list__item' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'counter_color',
				'label'   => esc_html__( 'Counter Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .counter--style-1 .counter__title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .counter--style-2 .counter__title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .about-block__count' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-list--style-1 .rt-list__count' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'icon_color',
				'label'   => esc_html__( 'Icon Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .counter--style-1 .counter__icon .icon' => 'color: {{VALUE}}',
					'{{WRAPPER}} .counter--style-2 .counter__icon .icon' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-list--style-1 .rt-list__icon' => 'color: {{VALUE}}',
				),
				'condition'   => array( 'style' => array( 'style1', 'style2', 'style4', 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'item_border_color',
				'label'   => esc_html__( 'Border Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .counter--style-1 .counter__icon' => 'border-color: {{VALUE}}',
				),
				'condition'   => array('style' => array( 'style1', 'style4'  ) ),
			),

			array(
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'title_typo',
				'label'   => esc_html__( 'Title Style', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .counter--style-1 .counter__desc, {{WRAPPER}} .counter--style-2 .counter__desc, {{WRAPPER}} .about-block__title, {{WRAPPER}} .rt-list--style-1 .rt-list__item',
			),
			array(
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'counter_size',
				'label'   => esc_html__( 'Counter Font Size', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .counter--style-1 .counter__title, {{WRAPPER}} .counter--style-2 .counter__title, {{WRAPPER}} .about-block__count, {{WRAPPER}} .rt-list--style-1 .rt-list__count',
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'icon_size',
				'mode'    => 'responsive',
				'label'   => esc_html__( 'Icon Font Size', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .counter--style-1 .counter__icon .icon' => 'font-size: {{VALUE}}px',
					'{{WRAPPER}} .counter--style-2 .counter__icon .icon' => 'font-size: {{VALUE}}px',
					'{{WRAPPER}} .rt-list--style-1 .rt-list__icon' => 'font-size: {{VALUE}}px',
				),
				'condition'   => array( 'style' => array( 'style1', 'style2', 'style4', 'style5' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}


	protected function render() {
		$data = $this->get_settings();

		switch ( $data['style'] ) {
			case 'style5':
			$template = 'view-5';
			break;
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}