<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Utils;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class CTA extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Call to Action', 'daisy-core' );
		$this->rt_base = 'rt-cta';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_cta',
				'mode'    => 'section_start',
				'label'   => __( 'Call To Action', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
					'style3' => esc_html__( 'Style 3', 'daisy-core' ),
					'style4' => esc_html__( 'Style 4', 'daisy-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
			),
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => esc_html__( 'Any Project On Your Mind?', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'desc',
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Description', 'daisy-core' ),
				'default' => esc_html__( 'Take advantage of the experiential-learning opportunities built into many programs.', 'daisy-core' ),
				'label_block' => true,
				'condition' => array( 'style' => array( 'style4' ) ),
			),
			array(
				'id'      => 'phone',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Phone', 'daisy-core' ),
				'default' => esc_html__( '+11 05698 236 2658', 'daisy-core' ),
				'label_block' => true,
				'condition' => array( 'style' => array( 'style4' ) ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'image',
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'daisy-core' ),
				'condition' => array( 'style' => array( 'style2', 'style3', 'style4' ) ),
			),
			array(
				'id'        => 'img_link',
				'type'        => Controls_Manager::URL,
				'label'       => __( 'Image Link', 'daisy-core' ),
				'placeholder' => 'https://your-link.com',
				'condition' => array( 'style' => array( 'style2' ) ),
			),
			//Button 1
			array(
				'id'      => 'btn_txt',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Button Text', 'daisy-core' ),
				'default' => esc_html__( 'Hire Me', 'daisy-core' ),
				'label_block' => true,
				'condition' => array( 'style' => array( 'style1', 'style2', 'style3' ) ),
			),
			array(
				'id'        => 'btn_link',
				'type'        => Controls_Manager::URL,
				'label'       => __( 'Link', 'daisy-core' ),
				'placeholder' => 'https://your-link.com',
				'condition' => array( 'style' => array( 'style1', 'style2', 'style3' ) ),
			),
			//Button 2
			array(
				'id'      => 'btn2_txt',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Button 2 Text', 'daisy-core' ),
				'default' => esc_html__( 'Get A Quote', 'daisy-core' ),
				'label_block' => true,
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'        => 'btn2_link',
				'type'        => Controls_Manager::URL,
				'label'       => __( 'Button 2 Link', 'daisy-core' ),
				'placeholder' => 'https://your-link.com',
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .cta-content__title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .serviceDetails-callCenter__heading' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .cta-content__title,
					{{WRAPPER}} .serviceDetails-callCenter__heading
				',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .cta-content__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	                '{{WRAPPER}} .serviceDetails-callCenter__heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .cta-content__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .serviceDetails-callCenter__heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'btn_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button', 'daisy-core' ),
				'condition' => array( 'style' => array( 'style1', 'style2', 'style3' ) ),
			),
			array(
				'id'      => 'btn_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .rt-btn--1' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--9' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--14' => 'color: {{VALUE}}', 
					),
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .icon--1 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .icon--4 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .icon--4 rect' => 'fill: {{VALUE}}', 
					),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'btn_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .rt-btn--1, 
						{{WRAPPER}} .rt-btn--9,
						{{WRAPPER}} .rt-btn--14
					',
			),
			array(
				'id'      => 'btn_bgcolor',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .rt-btn--1' => 'background-color: {{VALUE}}',
						'{{WRAPPER}} .rt-btn--9' => 'background-color: {{VALUE}}',
						'{{WRAPPER}} .rt-btn--14' => 'background-color: {{VALUE}}',
					),
			),
			array(
				'id'      => 'btn_border_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .rt-btn--9' => 'border-color: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--14' => 'border-color: {{VALUE}}', 
					),
				'condition' => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'id'      => 'btn_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'btn_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .rt-btn--1:hover' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--9:hover' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--14:hover' => 'color: {{VALUE}}', 
					),
			),
			array(
				'id'      => 'icon_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .rt-btn--1:hover .icon--1 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--9:hover .icon--4 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--14:hover .icon--4 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--14:hover .icon--4 rect' => 'fill: {{VALUE}}', 
					),
			),
			array(
				'id'      => 'btn_h_bgcolor',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .rt-btn--1::before' => 'background-color: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--9:hover' => 'background-color: {{VALUE}}', 
						'{{WRAPPER}} .rt-btn--14:hover' => 'background-color: {{VALUE}}', 
					),
			),
			array(
				'id'      => 'btn_h_border_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .rt-btn--9:hover' => 'border-color: {{VALUE}}',
						'{{WRAPPER}} .rt-btn--14:hover' => 'border-color: {{VALUE}}',
					),
				'condition' => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'btn2_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button 2', 'daisy-core' ),
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'btn2_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-btn--3' => 'color: {{VALUE}}' ),
			),
			array(
				'id'      => 'icon2_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .icon--3 path' => 'fill: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'btn2_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .rt-btn--3',
			),
			array(
				'id'      => 'btn2_bgcolor',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-btn--3' => 'background-color: {{VALUE}}' ),
			),
			array(
				'id'      => 'btn2_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'btn2_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-btn--3:hover' => 'color: {{VALUE}}' ),
			),
			array(
				'id'      => 'icon2_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-btn--3:hover .icon--3 path' => 'fill: {{VALUE}}' ),
			),
			array(
				'id'      => 'btn2_h_bgcolor',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rt-btn--3::before' => 'background-color: {{VALUE}}' ),
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}