<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Utils;


if ( ! defined( 'ABSPATH' ) ) exit;

class Elements extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Elements', 'daisy-core' );
		$this->rt_base = 'rt-elements';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
	        'element_image', [
	            'label' => __( 'Image', 'daisy-core' ),
	            'type' => Controls_Manager::MEDIA,
	            'default' => [
	                'url' => Utils::get_placeholder_image_src(),
	            ],
	        ]
	    );

	    $repeater->add_control(
	        'element_animation',
	        [
	            'label' => __( 'Select Animation', 'daisy-core' ),
	            'type' => Controls_Manager::SELECT,
	            'default' => 'none',
	            'options' => [
	                'none'  => __( 'None', 'daisy-core' ),
	                'animation-topBottom'            => __( 'Top Bottom', 'daisy-core' ),
	                'animation-topBottom50'          => __( 'Top Bottom 50', 'daisy-core' ),
	                'animate-left50'                 => __( 'Left 50', 'daisy-core' ),
	                'animation-left100'              => __( 'Left 100', 'daisy-core' ),
	                'animation-zoomeffect'           => __( 'Zoom Effect', 'daisy-core' ),
	                'animation-zoomeffect2'          => __( 'Zoom Effect 2', 'daisy-core' ),
	                'animation-spin'                 => __( 'Spin', 'daisy-core' ),
	                'animation-animationFramesOne'   => __( 'Animation Frames One', 'daisy-core' ),
	                'animation-animationFramesTwo'   => __( 'Animation Frames Two', 'daisy-core' ),
	                'animation-animationFramesThree' => __( 'Animation Frames Three', 'daisy-core' ),
	                'animation-leftRight50'          => __( 'Left Right 50', 'daisy-core' ),
	                'animation-toBottomFromTop'      => __( 'To Bottom From Top', 'daisy-core' ),
	                'animation-totopFrombottom'      => __( 'To Top From Bottom', 'daisy-core' ),
	                'animation-zoomIn'               => __( 'Zoom In', 'daisy-core' ),
	                'animation-loaderAnimation'      => __( 'Loader Animation', 'daisy-core' ),
	                'animation-pulseShadow1'         => __( 'Pulse Shadow', 'daisy-core' ),
	                'animation-pulseShadow2'         => __( 'Pulse Shadow 2', 'daisy-core' ),
	                'animation-pulseShadow3'         => __( 'Pulse Shadow 3', 'daisy-core' ),
	            ],
	        ]
	    );

	    $repeater->add_control(
	        'element_position',
	        [
	            'label' => __( 'Element Position', 'daisy-core' ),
	            'type' => Controls_Manager::HEADING,
	            'separator' => 'before',
	        ]
	    );
	    $repeater->add_responsive_control(
	        'element_horizontal_position',
	        [
	            'label' => __( 'Horizontal Position Base', 'daisy-core' ),
	            'type' => Controls_Manager::SELECT,
	            'default' => 'left',
	            'options' => [
	                'left'  => __( 'Left', 'daisy-core' ),
	                'right'  => __( 'Right', 'daisy-core' ),
	            ],
	        ]
	    );
	    $repeater->add_responsive_control(
	        'element_position_horizontal_left',
	        [
	            'label' => __( 'Horizontal Position', 'daisy-core' ),
	            'type' => Controls_Manager::SLIDER,
	            'size_units' => [ 'px', '%', 'vh' ],
	            'range' => [
	                'px' => [
	                    'min' => -5000,
	                    'max' => 5000,
	                    'step' => 1,
	                ],
	                '%' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	                'vh' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	            ],
	            'default' => [
	                'unit' => 'px',
	                'size' => 0,
	            ],
	            'selectors' => [
	                '{{WRAPPER}} {{CURRENT_ITEM}}' => 'left: {{size}}{{unit}}',
	            ],
	            'condition' => [
	                'element_horizontal_position' => 'left',
	            ],
	             
	        ]
	    );
	    $repeater->add_responsive_control(
	        'element_position_horizontal_right',
	        [
	            'label' => __( 'Horizontal Position', 'daisy-core' ),
	            'type' => Controls_Manager::SLIDER,
	            'size_units' => [ 'px', '%', 'vh' ],
	            'range' => [
	                'px' => [
	                    'min' => -5000,
	                    'max' => 5000,
	                    'step' => 1,
	                ],
	                '%' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	                'vh' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	            ],
	            'default' => [
	                'unit' => 'px',
	                'size' => 0,
	            ],
	            'selectors' => [
	                '{{WRAPPER}} {{CURRENT_ITEM}}' => 'right: {{size}}{{unit}}',
	            ],
	            'condition' => [
	                'element_horizontal_position' => 'right',
	            ],
	             
	        ]
	    );
	     $repeater->add_responsive_control(
	        'element_vertical_position',
	        [
	            'label' => __( 'Vertical Position Base', 'daisy-core' ),
	            'type' => Controls_Manager::SELECT,
	            'default' => 'top',
	            'options' => [
	                'top'  => __( 'Top', 'daisy-core' ),
	                'bottom'  => __( 'Bottom', 'daisy-core' ),
	            ],
	        ]
	    );
	    $repeater->add_responsive_control(
	        'element_position_vartical_top',
	        [
	            'label' => __( 'Vertical Position', 'daisy-core' ),
	            'type' => Controls_Manager::SLIDER,
	            'size_units' => [ 'px', '%', 'vh' ],
	            'range' => [
	                'px' => [
	                    'min' => -5000,
	                    'max' => 5000,
	                    'step' => 1,
	                ],
	                '%' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	                'vh' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	            ],
	            'default' => [
	                'unit' => 'px',
	                'size' => 0,
	            ],
	            'selectors' => [
	                '{{WRAPPER}} {{CURRENT_ITEM}}' => 'top: {{size}}{{unit}}',
	            ],
	            'condition' => [
	                'element_vertical_position' => 'top',
	            ],
	            
	        ]
	    );
	    $repeater->add_responsive_control(
	        'element_position_vartical_bottom',
	        [
	            'label' => __( 'Vertical Position', 'daisy-core' ),
	            'type' => Controls_Manager::SLIDER,
	            'size_units' => [ 'px', '%', 'vh' ],
	            'range' => [
	                'px' => [
	                    'min' => -5000,
	                    'max' => 5000,
	                    'step' => 1,
	                ],
	                '%' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	                'vh' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	            ],
	            'default' => [
	                'unit' => 'px',
	                'size' => 0,
	            ],
	            'selectors' => [
	                '{{WRAPPER}} {{CURRENT_ITEM}}' => 'bottom: {{size}}{{unit}}',
	            ],
	            'condition' => [
	                'element_vertical_position' => 'bottom',
	            ],
	            
	        ]
	    );
	    $repeater->add_responsive_control(
        'elements_z-index',
        [
            'label' => __( 'Z-Index', 'daisy-core' ),
            'type' => Controls_Manager::NUMBER,
            'min' => -500,
            'max' => 500,
            'step' => 1,
            'default' => 0,
            'selectors' => [
                '{{WRAPPER}} {{CURRENT_ITEM}}' => 'z-index: {{VALUE}}',
            ],
        ]
    );

		$fields = array(
			array(
				'id'      => 'sec_elements',
				'mode'    => 'section_start',
				'label'   => __( 'Elements', 'daisy-core' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'elements',
				'label'   => esc_html__( 'Add Elements', 'daisy-core' ),
				'fields' => $repeater->get_controls(),
				'default' => array(
					['element_image' => Utils::get_placeholder_image_src() ],
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}