<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/info-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Info_Box extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Info Box', 'daisy-core' );
		$this->rt_base = 'rt-info-box';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => __( 'Info Box', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
					'style3' => esc_html__( 'Style 3', 'daisy-core' ),
					'style4' => esc_html__( 'Style 4', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			//Icon Start
			array(	
				'id'      => 'icontype',				 
			   	'type'    => Controls_Manager::CHOOSE,
			   	'label'   => esc_html__( 'Media Type', 'daisy-core' ),
			   	'options' => [
				    'icon' => [
				       'title' => esc_html__( 'Left', 'daisy-core' ),
				       'icon' => 'fa fa-smile',
				    ],
				    'image' => [
				       'title' => esc_html__( 'Center', 'daisy-core' ),
				       'icon' => 'fa fa-image',
				    ],		     
			   	],
			   	'default' => 'icon',
			   	'label_block' => false,
			   	'toggle' => false,
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'icon_class',
				'label'   => esc_html__( 'Icon', 'daisy-core' ),
				'default' => [
			      'value' => 'fas fa-user-check',
			      'library' => 'fa-solid',
			  	],
			  	'condition'    => array(
					'icontype' => array( 'icon' ),
				),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'icon_image',
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'daisy-core' ),
				'condition'    => array(
					'icontype' => array( 'image' ),
				),
			),
			array (
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'shape_display',
				'label'       => esc_html__( 'Shape', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
				'condition'   => array( 'style' => array( 'style2', 'style4' ) ),
			),
			//Icon end
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => __( 'Info Box Title', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'description',
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => esc_html__( 'Description', 'daisy-core' ),
				'default' => __( 'There are many variations of passages of Lorem Ipsum', 'daisy-core' ),
			),
			array(
				'id'      => 'align',
				'mode'    => 'responsive',
				'type'    => Controls_Manager::CHOOSE,
				'label'   => __( 'Alignment', 'daisy-core' ),
				'options' => $this->rt_alignment_options(),
				'prefix_class' => 'elementor-align-',
				'default' => 'left',
				'selectors' => [
					'{{WRAPPER}} .single-feature' => 'text-align: {{VALUE}};',
				],
				'condition'   => array( 'style' => array( 'style1', 'style2' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Full Item Style
			array(
				'id'      => 'full_item_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Full Item', 'daisy-core' ),
			),
			array(
				'name'     => 'full_item_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => esc_html__( 'Background', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .why-choose--style-1,
						{{WRAPPER}} .feature--style-1,
						{{WRAPPER}}  .why-choose--style-2,
						{{WRAPPER}}  .why-choose--style-3
					',
			),
			array(
				'mode' => 'section_end',
			),

			// Icon Styles
			array(
				'id'      => 'icon_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Icon', 'daisy-core' ),
			),			
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rtin-icon' => 'color: {{VALUE}}' ),
			),
			array(
				'name'       => 'icon_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .rtin-icon',
			),
			array(
				'name'     => 'icon_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .rtin-icon,
						{{WRAPPER}} .why-choose__icon
					',
				'condition'   => array( 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'id'      => 'icon_bgh_size',
				'label'   => esc_html__( 'Icon Box Height', 'daisy-core' ),
				'type'    => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .rtin-icon' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .why-choose__icon' => 'height: {{SIZE}}{{UNIT}};',
				],
				'label_block' => true,
				'condition'   => array( 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'id'      => 'icon_bgw_size',
				'label'   => esc_html__( 'Icon Box Width', 'daisy-core' ),
				'type'    => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .rtin-icon' => 'width: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .why-choose__icon' => 'width: {{SIZE}}{{UNIT}};',
				],
				'label_block' => true,
				'condition'   => array( 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'id'      => 'icon_border_radius',
				'label'   => esc_html__( 'Border Radius', 'daisy-core' ),
				'type'    => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .rtin-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .why-choose__icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'label_block' => true,
				'condition'   => array( 'style' => array( 'style1', 'style3' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Title Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .why-choose__title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .feature__title' => 'color: {{VALUE}}',
				),
			),
			array(
				'name'       => 'title_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .why-choose__title,
						{{WRAPPER}} .feature__title
					',
			),
			array(
				'mode' => 'section_end',
			),
			// Description Style
			array(
				'id'      => 'desc_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Description', 'daisy-core' ),
			),
			array(
				'id'        => 'desc_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .why-choose p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .feature--style-1 p' => 'color: {{VALUE}}', 
				),
			),
			array(
				'name'       => 'desc_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .why-choose p, {{WRAPPER}} .feature--style-1 p',
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}