<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\Daisy_Core;

use radiustheme\daisy\inc\Helper;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once DAISY_CORE_BASE_DIR. '/elementor/controls/traits-icons.php';

class Custom_Widget_Init {

	public function __construct() {
		add_action( 'elementor/widgets/widgets_registered', array( $this, 'init' ) );
		add_action( 'elementor/elements/categories_registered', array( $this, 'widget_categoty' ) );
		add_action( 'elementor/editor/after_enqueue_styles', array( $this, 'editor_style' ) );
	}

	public function editor_style() {
		$img = plugins_url( 'icon.png', __FILE__ );
		wp_add_inline_style( 'elementor-editor', '.elementor-element .icon .rdtheme-el-custom{content: url( '.$img.');width: 28px;}' );
		wp_add_inline_style( 'elementor-editor', '.select2-container--default .select2-selection--single {min-width: 126px !important; min-height: 30px !important;}' );
	}


	public function set_elementor_default_options() {
		$data = array(
			'elementor_disable_typography_schemes' => 'yes',
			'elementor_disable_color_schemes'      => 'yes',
			'elementor_css_print_method'           => 'internal',
			'elementor_cpt_support'                => array( "page" ),
			'elementor_container_width'            => '1200',
			'elementor_viewport_lg'                => '992',
			'_elementor_general_settings'          => array(
				'default_generic_fonts' => 'Sans-serif',
				'global_image_lightbox' => 'yes',
				'container_width'       => '1200',
			),
			'_elementor_global_css' 	=> array(
				'time'   => '1534145031',
				'fonts'  => array(),
				'status' => 'inline',
				'0'      => false,
				'css'    => '.elementor-section.elementor-section-boxed > .elementor-container { max-width:1200px; }',
			),
		);

		foreach ( $data as $key => $value ) {
			update_option( $key, $value );
		}
	}

	public function init() {
		require_once __DIR__ . '/base.php';

		$widgets = array(
			'title'             => 'Title',
			'title-text-button' => 'Title_Text_Button',
			'watermark-title' 	=> 'Watermark_Title',
			'banner'    	    => 'Banner',
			'slider1'    	    => 'Slider1',
			'slider2'    	    => 'Slider2',
			'elements'    	    => 'Elements',
			'button'    	    => 'Button',
			'progress-bar'    	=> 'Progress_Bar',
			'qualification'    	=> 'Qualification',
			'services'          => 'Services',
			'service-slider'    => 'Service_Slider',
			'counter'           => 'Counter',
			'portfolio'    	    => 'Portfolio',
			'image-box'    	    => 'Image_Box',
			'testimonial'       => 'Testimonial',
			'cta'    	        => 'CTA',
			'price'    	        => 'Price',
			'pricing-tab'    	=> 'Pricing_Tab',
			'post'              => 'Post',
			'post-slider'       => 'Post_Slider',
			'info-box'          => 'Info_Box',
			'contact-box'       => 'Contact_Box',
			'social-box'        => 'Social_Box',
			'team'    	        => 'Team',
			'video'  	        => 'Video_Button',
			'lists'  	        => 'Lists',
			'logo-slider'  	    => 'Logo_Slider',
			'address'    	    => 'Address',
		);

		foreach ( $widgets as $dirname => $class ) {
			$template_name = '/elementor-custom/' . $dirname . '/class.php';
			if ( file_exists( STYLESHEETPATH . $template_name ) ) {
				$file = STYLESHEETPATH . $template_name;
			}
			elseif ( file_exists( TEMPLATEPATH . $template_name ) ) {
				$file = TEMPLATEPATH . $template_name;
			}
			else {
				$file = __DIR__ . '/' . $dirname . '/class.php';
			}

			require_once $file;
			
			$classname = __NAMESPACE__ . '\\' . $class;
			Plugin::instance()->widgets_manager->register_widget_type( new $classname );
		}
	}

	public function widget_categoty( $class ) {
		$id         = DAISY_CORE_THEME_PREFIX . '-widgets'; // Category /@dev
		$properties = array(
			'title' => __( 'RadiusTheme Elements', 'daisy-core' ),
		);
		Plugin::$instance->elements_manager->add_category( $id, $properties );
	}
}

new Custom_Widget_Init();