<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/lists/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Lists extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Lists', 'daisy-core' );
		$this->rt_base = 'rt-lists';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_type', [
				'type'    	  => Controls_Manager::SELECT2,
				'label'   	  => esc_html__( 'List Type', 'daisy-core' ),
				'options' 	  => array(
					'default'    => esc_html__( 'Default List', 'daisy-core' ),
					'icon_list'  => esc_html__( 'Icon List', 'daisy-core' ),
				),
				'default' 	  => 'icon_list',
				'description' => esc_html__( '2 list type available here. (default list is normal text list)', 'daisy-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'list_icon', [
				'label' => __( 'Icon', 'daisy-core' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-check icon',
					'library' => 'solid',
				],
				'label_block' => true,
				'condition' => [
					'list_type' => 'icon_list',
				],
			]
		);
		$repeater->add_control(
			'list_text', [
				'label' => __( 'Lists Text', 'daisy-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Lists text put here', 'daisy-core' ),
				'label_block' => true,
			]
		);

		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_lists',
				'label'   => esc_html__( 'Lists', 'daisy-core' ),
			),
			array(
				'id'      	  => 'layout',
				'type'    	  => Controls_Manager::SELECT2,
				'label'   	  => esc_html__( 'Layout', 'daisy-core' ),
				'options' 	  => array(
					'layout1' 	  => esc_html__( 'Layout 1', 'daisy-core' ),
					'layout2' 	  => esc_html__( 'Layout 2', 'daisy-core' ),
				),
				'default' 	  => 'layout1',
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'rt_lists',
				'label'   => esc_html__( 'Add many list as you want', 'daisy-core' ),
				'prevent_empty' => false,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_text }}}',
				'default' => array(
					array( 'list_text' => 'Lists text put here' ),
					array( 'list_text' => 'Lists text put here' ),
					array( 'list_text' => 'Lists text put here' ),
				),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'd_block',
				'label'       => esc_html__( 'Display Block', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable Display Block. Default: Off', 'daisy-core' ),
				'default'     => 'no',
				'condition' => array( 'layout' => array( 'layout1' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'list_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'daisy-core' ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title/Icon', 'daisy-core' ),
				'separator' => 'before',
				'condition' => array( 'layout' => array( 'layout1' ) ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .theme-list--style-1 li i' => 'color: {{VALUE}}',
				),
				'condition' => array( 'layout' => array( 'layout1' ) ),
			),
			array(
				'id'      => 'title_b_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .theme-list--style-1 li i' => 'border-color: {{VALUE}}',
				),
				'condition' => array( 'layout' => array( 'layout1' ) ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .theme-list--style-1 li i',
				'condition' => array( 'layout' => array( 'layout1' ) ),
			),
			array(
				'id'      => 'text_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Text', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'text_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .theme-list li' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'text_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .theme-list li',
			),
			array(
			    'id'      => 'list_margin',
			    'type'    => Controls_Manager::DIMENSIONS,
			    'size_units' => [ 'px', '%', 'em' ],
			    'label'   => __( 'List Margin', 'daisy-core' ),                 
			    'selectors' => array(
			        '{{WRAPPER}} .theme-list li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			    ),
			),
			array(
			    'id'      => 'list_padding',
			    'type'    => Controls_Manager::DIMENSIONS,
			    'size_units' => [ 'px', '%', 'em' ],
			    'label'   => __( 'List Padding', 'daisy-core' ),                 
			    'selectors' => array(
			        '{{WRAPPER}} .theme-list li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			    ),
			),
			array(
				'id'      => 'dot_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Dot', 'daisy-core' ),
				'separator' => 'before',
				'condition' => array( 'layout' => array( 'layout2' ) ),
			),
			array(
				'id'      => 'dot_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .square-icon::after' => 'background-color: {{VALUE}}',
				),
				'condition' => array( 'layout' => array( 'layout2' ) ),
			),
			array(
				'id'      => 'dot_b_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .square-icon' => 'border-color: {{VALUE}}',
				),
				'condition' => array( 'layout' => array( 'layout2' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ( $data['layout'] ) {
			case 'layout2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}