<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;
use radiustheme\daisy\inc\Helper;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Portfolio extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Portfolio', 'daisy-core' );
		$this->rt_base = 'rt-portfolio';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_rt_portfolio',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Portfolio Post', 'daisy-core' ),
			),
			// Layout
			array(
				'id'      => 'style',
				'type'    => Controls_Manager::SELECT2,
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'layout 1 (Filter)', 'daisy-core' ),
					'style2' => esc_html__( 'layout 2 (Slider)', 'daisy-core' ),
					'style3' => esc_html__( 'layout 3 (Slider)', 'daisy-core' ),
					'style4' => esc_html__( 'layout 4 (Slider)', 'daisy-core' ),
					'style5' => esc_html__( 'layout 5 (Slider)', 'daisy-core' ),
					'style6' => esc_html__( 'layout 6 (Filter)', 'daisy-core' ),
					'style7' => esc_html__( 'layout 7 (Grid)', 'daisy-core' ),
					'style8' => esc_html__( 'layout 8 (Masonry Grid)', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => esc_html__( 'Latest Project', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'style' => array( 'style1', 'style2' ) ),
			),
			array(
				'id'      => 'sub_title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Sub Title', 'daisy-core' ),
				'default' => esc_html__( 'Portfolio', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'style' => array( 'style1', 'style2' ) ),
			),
			// Post per page
			array(
				'id'      => 'number',
				'label'   =>esc_html__( 'Total number of portfolio post', 'daisy-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 6,
				'description' =>esc_html__( 'Write -1 to show all', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'excerpt',
				'label'   =>esc_html__( 'Post excerpt length', 'daisy-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 11,
				'description' =>esc_html__( 'This is a portfolio post excerpt length', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'style' => array( 'style1', 'style2',  'style3',  'style5',  'style6',  'style7' ) ),
			),
			array(
				'id'      => 'cols',
				'label'   => esc_html__( 'Grid Columns', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_grid_options(),
				'default' => '4',
				'label_block' => true,
				'condition'   => array( 'style' => array( 'style1', 'style6' ) ),
			),
			array(
				'id'      => 'orderby',
				'label'   => esc_html__( 'Order By', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_post_orderby(),
				'default' => 'date',
				'label_block' => true,
			),
			//Query Type
			array(
				'id'      => 'query_type',
				'type'    => Controls_Manager::SELECT2,
				'label'   => esc_html__( 'Get Posts by cats or title', 'daisy-core' ),
				'options' => array(
					'cats' => esc_html__( 'Posts by Categories', 'daisy-core' ),
					'titles' => esc_html__( 'Posts by Titles', 'daisy-core' ),
				),
				'label_block' => true,
			),
			// Terms
			array(
				'id'      => 'terms',
				'label' => __( 'Select Terms', 'daisy-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => Helper::portfolio_categories_slug(),              
                'multiple' => true,
                'label_block' => true,
                'conditions' => [
					'terms' => [
						['name' => 'query_type', 'operator' => '==', 'value' => 'cats'],
					],
				],
			),
			array(
				'id'      => 'postbytitle',
				'label'   => esc_html__( 'Posts By Title', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_portfolio_posts_title(),
				'default' => '',
				'multiple' => true,
				'label_block' => true,
				'conditions' => [
					'terms' => [
						['name' => 'query_type', 'operator' => '==', 'value' => 'titles'],
					],
				],
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'filter_enable',
				'label'       => esc_html__( 'Filter', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable filters. Default: off', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1', 'style6' ) ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'gutters',
				'label'       => esc_html__( 'Gutters', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable grid gutter. Default: off', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style6' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			
			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider',
				'label'       => esc_html__( 'Slider Options', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style4' ) ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_autoplay',
				'label'       => esc_html__( 'Autoplay', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style4' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slider_autoplay_speed',
				'label'   => esc_html__( 'Autoplay Speed', 'daisy-core' ),
				'options' => $this->rt_autoplay_speed(),
				'default' => '2000',
				'description' => esc_html__( 'Select any value for autopaly speed. Default: 2000', 'daisy-core' ),
				'condition'   => array( 
					'style' => array( 'style2', 'style4'), 
					'slider_autoplay' => 'yes', 
				),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_dots',
				'label'       => esc_html__( 'Dots', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'default'     => 'on',
				'description' => esc_html__( 'Enable or disable nav dots. Default: off', 'daisy-core' ),
				'condition'   => array( 'style!' => array( 'style2', 'style4' , 'style6') ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_arrow',
				'label'       => esc_html__( 'Arrow', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable nav dots. Default: off', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style4' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show',
				'label'   => esc_html__( 'Slide To Show', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '3',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 6', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style4' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_lg',
				'label'   => esc_html__( 'Desktops: > 1199px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 4', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style4' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_md',
				'label'   => esc_html__( 'Desktops: > 991px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'This is mostly tab view.  Default: 3', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style4' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_sm',
				'label'   => esc_html__( 'Mobile View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for mobile device show. Default: 2', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style4' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_xs',
				'label'   => esc_html__( 'Mobile Small View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for small mobile device show. Default: 1', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style4' ) ),
			),
			array(
				'mode' => 'section_end',
				'condition'   => array( 'style' => array( 'style2','style3' ) ),
			),
			// Title
			array(
				'id'      => 'portfolio_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1', 'style2' ) ),
			),
			array(
				'id'      => 'sec_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading__title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .section-headingTwo__title' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-heading__title, {{WRAPPER}} .section-headingTwo__title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                               
	                '{{WRAPPER}} .section-headingTwo__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                               
	            ),
	            'separator' => 'before',
	        ),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'mode'          => 'responsive',
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_margin',
	            'label'   => __( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-headingTwo__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Sub Title', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1', 'style2' ) ),
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading__sub-title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-headingTwo__sub-title' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-heading__sub-title, {{WRAPPER}} .section-headingTwo__sub-title',
			),
	        array(
				'id'      => 'sub_title_b_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Border Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading--style-3 .section-heading__sub-title::after' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .section-headingTwo__sub-title__bar' => 'background-color: {{VALUE}}',
				),
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_sub_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                               
	                '{{WRAPPER}} .section-headingTwo__sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                               
	            ),
	            'separator' => 'before',
	        ),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'mode'          => 'responsive',
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_sub_margin',
	            'label'   => __( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-headingTwo__sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			// Filter Button
			array(
				'id'      => 'portfolio_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Filter Button', 'daisy-core' ),
				'condition'   => array( 
					'style' => array( 'style1', 'style6' ), 
					'filter_enable' => 'yes', 
				),
			),
			array(
				'id'      => 'fbtn_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .isotope-menu--style-1 .isotope-menu__item' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .portfolio__menu > button' => 'color: {{VALUE}}', 
				),
			),
			array(
				'name'     => 'fbtn_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .isotope-menu--style-1 .isotope-menu__item,
						{{WRAPPER}} .portfolio__menu > button
					',
			),
			array(
				'id'      => 'fbtn_border_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .isotope-menu--style-1::after' => 'background-color: {{VALUE}}' ),
			),
			array(
				'id'      => 'fbtn_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover/Active', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'fbtn_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .isotope-menu--style-1 .isotope-menu__item--current' => 'color: {{VALUE}}',
					'{{WRAPPER}} .isotope-menu--style-1 .isotope-menu__item--current::after' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .portfolio__menu > button.active' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode' => 'section_end',
			),
			// Content
			array(
				'id'      => 'portfolio_text_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Content', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1', 'style2', 'style3', 'style5', 'style6', 'style7' ) ),
			),
			// Title
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .portfolio--style-1 .portfolio__title a' => 'color: {{VALUE}}',
				 		'{{WRAPPER}} .project--style-1 .project__title' => 'color: {{VALUE}}', 
				 		'{{WRAPPER}} .project-over-box--style-1 .project-over-box__title' => 'color: {{VALUE}}', 
				 		'{{WRAPPER}} .portfolio--style-4 .portfolio__title > a' => 'color: {{VALUE}}', 
				 		'{{WRAPPER}} .portfolio--style-6 .portfolio__title' => 'color: {{VALUE}}', 
				 		'{{WRAPPER}} .portfolio--style-3 .portfolio__title' => 'color: {{VALUE}}', 
				 	),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'name_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .portfolio--style-1 .portfolio__title a, 
					{{WRAPPER}} .project--style-1 .project__title, 
					{{WRAPPER}} .project-over-box--style-1 .project-over-box__title,
					{{WRAPPER}} .portfolio--style-4 .portfolio__title > a,
					{{WRAPPER}} .portfolio--style-6 .portfolio__title,
					{{WRAPPER}} .portfolio--style-3 .portfolio__title
					',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Title Hover Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .portfolio--style-1 .portfolio__title a:hover' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .project--style-1 .project__title a:hover' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .swiper-slide-thumb-active .project-over-box__title' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .portfolio--style-4 .portfolio__title > a:hover' => 'color: {{VALUE}}', 
					),
			),
			// Description
			array(
				'id'      => 'desc_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Description', 'daisy-core' ),
				'separator' => 'before',
				'condition'   => array( 'style' => array( 'style1', 'style2', 'style3', 'style5', 'style6', 'style7' ) ),
			),
			array(
				'id'      => 'desc_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .portfolio--style-1 .portfolio__desc' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .project--style-1 p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .project-over-box--style-1 p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .portfolio--style-4 .portfolio__figure:hover .portfolio__text' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .portfolio__text.text-white' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .portfolio__text' => 'color: {{VALUE}} !important', 
				),
				'condition'   => array( 'style' => array( 'style1', 'style2', 'style3', 'style5', 'style6', 'style7' ) ),
			),
			array(
				'id'      => 'desc_acolor',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Active Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .swiper-slide-thumb-active .project-over-box--style-1 p' => 'color: {{VALUE}}',
				),
				'condition'   => array( 'style' => array( 'style3' ) ),
			),
			array(
				'name'     => 'desc_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .portfolio--style-1 .portfolio__desc, 
					{{WRAPPER}} .project--style-1 p,
					{{WRAPPER}} .project-over-box--style-1 p,
					{{WRAPPER}} .portfolio--style-4 .portfolio__figure:hover .portfolio__text,
					{{WRAPPER}} .portfolio__text.text-white,
					{{WRAPPER}} .portfolio__text
					',
				'condition'   => array( 'style' => array( 'style1', 'style2', 'style3', 'style5' ) ),
			),
			// Content background
			array(
				'id'        => 'text_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Content Background Color', 'daisy-core' ),
				'separator' => 'before',
				'condition' => array( 'style' => array( 'style1', 'style2', 'style3', 'style6', 'style7' ) ),
			),
			array(
				'name'      => 'text_bgc',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Background', 'daisy-core' ),
				'selector'  => '
						{{WRAPPER}} .portfolio--style-1 .portfolio__content,
						{{WRAPPER}} .project-over-box--style-1,
						{{WRAPPER}} .portfolio__content::before,
						{{WRAPPER}} .portfolio--style-6:hover .portfolio__content::before, 
						{{WRAPPER}} .portfolio--style-6:hover .portfolio__content::after,
						{{WRAPPER}} .portfolio--style-3 .portfolio__content::before
					',
				'condition' => array( 'style' => array( 'style1', 'style3', 'style6' ) ),
			),
			array(
				'name'      => 'text_active_bgc',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Active Background', 'daisy-core' ),
				'selector'  => '
						{{WRAPPER}} .swiper-slide-thumb-active .project-over-box--style-1
					',
				'condition' => array( 'style' => array( 'style3' ) ),
			),
			array(
				'id'      => 'content_b_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .project--style-1::after' => 'border-color: {{VALUE}}' ),
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Slider Dot
			array(
				'id'      => 's_dot_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Dots', 'daisy-core' ),
				'condition'   => array( 
					'style' => array( 'style3', 'style5', 'style8' ),  
				),
			),
			array(
				'name'     => 'sdot_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .swiper-pagination-bullet
				',
			),
			array(
				'id'      => 'sdot_bgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .swiper-pagination-bullet::after' => 'background-color: {{VALUE}}' ),
			),
			// Active
			array(
				'id'        => 'dot_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Active Color', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'sdot_hbgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active::after' => 'background-color: {{VALUE}}' 
				),
			),
			array(
				'id'      => 'sdot_hbbgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-color: {{VALUE}}' 
				),
			),
			array(
				'mode' => 'section_end',
			),
			// Slider Arrow
			array(
				'id'      => 's_arrow_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Arrow', 'daisy-core' ),
				'condition'   => array( 
					'style' => array( 'style2' ), 
					'slider_arrow' => 'yes', 
				),
			),
			array(
				'id'      => 'sarrow_ic',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .slider-nav .slider-btn' => 'color: {{VALUE}}', 
				),
			),
			array(
				'id'      => 'sa_border',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .slider-nav .slider-btn' => 'border-color: {{VALUE}}', 
				),
			),
			array(
				'id'        => 'arrow_h_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Hover', 'daisy-core' ),
				'separator' => 'before'
			),
			array(
				'id'      => 'sarrow_hic',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .slider-nav .slider-btn:hover' => 'color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'sarrow_bhic',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .slider-nav .slider-btn:hover' => 'border-color: {{VALUE}}',
				),
			),
			array(
				'name'      => 'sarrow_hbgc',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Background', 'daisy-core' ),
				'selector'  => '{{WRAPPER}} .slider-nav .slider-btn:hover::after',
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	            'condition'   => array( 
					'style' => array( 'style2', 'style4', 'style5', 'style8' ),
				),	            
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),	
		);
		return $fields;
	}

	public function isotope(){
		wp_enqueue_script( 'isotope-pkgd' );
		wp_enqueue_script( 'isotope-func' );
	}

	public function swiper(){
		wp_enqueue_style( 'swiper' );
		wp_enqueue_script( 'swiper' );
		wp_enqueue_script( 'swiper-func' );
	}

	protected function render() {
		$data = $this->get_settings();


		if ( ( $data['style'] == 'style1' || $data['style'] == 'style6') && ( $data['filter_enable'] == true ) ) {
			$this->isotope();
		}

		if ( $data['style'] == 'style2' || $data['style'] == 'style4' || $data['style'] == 'style5' || $data['style'] == 'style8' ) {
			$this->swiper();
		}

		$this->isotope();

		switch ($data['style']) {
			case 'style8':
				$template = 'view-8';
			break;
			case 'style7':
				$template = 'view-7';
			break;
			case 'style6':
				$template = 'view-6';
			break;
			case 'style5':
				$template = 'view-5';
			break;
			case 'style4':
				$template = 'view-4';
			break;
			case 'style3':
				$template = 'view-3';
			break;
			case 'style2':
				$template = 'view-2';
			break;
			default:
				$template = 'view-1';
			break;
		}

		if ( $data['style'] == 'style2' || $data['style'] == 'style4' ) {
			$swiper_data = array(
				'col_xl'   => $data['slide_to_show'],
				'autoplay' => $data['slider_autoplay'] == 'yes' ? true : false,
				'speed'    => $data['slider_autoplay_speed'],
				'allowSlideNext' => $data['slider_arrow'] == 'yes' ? true : false,
				'allowSlidePrev' => $data['slider_arrow'] == 'yes' ? true : false,
				'col_lg'  => $data['col_lg'],
				'col_md'  => $data['col_md'],
				'col_sm'  => $data['col_sm'],
				'col_xs'  => $data['col_xs'],
			);
			$data['swiper_data'] = json_encode( $swiper_data );
		}

		return $this->rt_template( $template, $data );
	}
}