<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use radiustheme\daisy\inc\RDTheme;
use radiustheme\daisy\inc\Helper;

if ( ! defined( 'ABSPATH' ) ) exit;

class Post_Slider extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Post Slider', 'daisy-core' );
		$this->rt_base = 'rt-post-slider';
		$this->rt_translate = array(
			'cols'  => array(
				'12' => esc_html__( '1 Col', 'daisy-core' ),
				'6'  => esc_html__( '2 Col', 'daisy-core' ),
				'4'  => esc_html__( '3 Col', 'daisy-core' ),
				'3'  => esc_html__( '4 Col', 'daisy-core' ),
				'2'  => esc_html__( '6 Col', 'daisy-core' ),
			),
		);
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$categories = get_categories();
		$category_dropdown = array( '0' => esc_html__( 'All Categories', 'daisy-core' ) );

		foreach ( $categories as $category ) {
			$category_dropdown[$category->term_id] = $category->name;
		}

		$fields = array(

			array(
				'id'      => 'sec_rt_post',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Posts', 'daisy-core' ),
			),
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => esc_html__( 'Latest News From Blog', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'sub_title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Sub Title', 'daisy-core' ),
				'default' => esc_html__( 'LAYEST NEWS', 'daisy-core' ),
				'label_block' => true,
			),
			//Post Order
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'post_ordering',
				'label'   => esc_html__( 'Post Ordering', 'daisy-core' ),
				'options' => array(
					'DESC'	=> esc_html__( 'Desecending', 'daisy-core' ),
					'ASC'	=> esc_html__( 'Ascending', 'daisy-core' ),
				),
				'default' => 'DESC',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'post_orderby',
				'label'   => esc_html__( 'Post Sorting', 'daisy-core' ),				
				'options' => array(
					'recent' 		=> esc_html__( 'Recent Post', 'daisy-core' ),
					'rand' 			=> esc_html__( 'Random Post', 'daisy-core' ),
					'menu_order' 	=> esc_html__( 'Custom Order', 'daisy-core' ),
					'title' 		=> esc_html__( 'By Name', 'daisy-core' ),
				),
				'default' => 'recent',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'cat',
				'label'   => esc_html__( 'Categories', 'daisy-core' ),
				'options' => $category_dropdown,
				'default' => '0',
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'count',
				'label'   => esc_html__( 'Word count', 'daisy-core' ),
				'default' => 20,
				'description' => esc_html__( 'Maximum number of words', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'itemlimit',
				'label'   => esc_html__( 'Item Limit', 'daisy-core' ),
				'default' => 3,
				'description' => esc_html__( 'Maximum number of words', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'title_count',
				'label'   => esc_html__( 'Title count', 'daisy-core' ),
				'default' => 8,
				'description' => esc_html__( 'Maximum number of words', 'daisy-core' ),
			),
			array (
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'content_display',
				'label'       => esc_html__( 'Content Display', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
			),
			array (
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'date_display',
				'label'       => esc_html__( 'Show Date', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
			),
			array (
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'category_display',
				'label'       => esc_html__( 'Show Categories', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
			),
			array (
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'read_display',
				'label'       => esc_html__( 'Read More Display', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'buttontext',
				'label'   => esc_html__( 'Button Text', 'daisy-core' ),
				'default' => esc_html__( 'Read more', 'daisy-core' ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider',
				'label'       => esc_html__( 'Slider Options', 'daisy-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_autoplay',
				'label'       => esc_html__( 'Autoplay', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slider_autoplay_speed',
				'label'   => esc_html__( 'Autoplay Speed', 'daisy-core' ),
				'options' => $this->rt_autoplay_speed(),
				'default' => '2000',
				'description' => esc_html__( 'Select any value for autopaly speed. Default: 2000', 'daisy-core' ),
				'condition'   => array( 
					'slider_autoplay' => 'yes', 
				),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_arrow',
				'label'       => esc_html__( 'Arrow', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable nav dots. Default: off', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show',
				'label'   => esc_html__( 'Slide To Show', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '3',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 6', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_lg',
				'label'   => esc_html__( 'Desktops: > 1199px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 4', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_md',
				'label'   => esc_html__( 'Desktops: > 991px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'This is mostly tab view.  Default: 3', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_sm',
				'label'   => esc_html__( 'Mobile View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for mobile device show. Default: 2', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_xs',
				'label'   => esc_html__( 'Mobile Small View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for small mobile device show. Default: 1', 'daisy-core' ),
			),
			array(
				'mode' => 'section_end',
			),
			// Section Title Style
			array(
				'id'      => 'sec_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Section Title', 'daisy-core' ),
			),
			array(
				'id'      => 'sec_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-headingFour__title' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sec_title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-headingFour__title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'sec_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-headingFour__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'sec_title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-headingFour__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                        
	            ),
	            'separator' => 'before',
	        ),
	        // Sub Title
	        array(
				'id'      => 'subtitle_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Sub Title', 'daisy-core' ),
				'separator' => 'before',
			),
	        array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-headingFour__sub-title' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-headingFour__sub-title',
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .blog__title a' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .blog__title a',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .blog__title a:hover' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	public function swiper(){
		wp_enqueue_style( 'swiper' );
		wp_enqueue_script( 'swiper' );
		wp_enqueue_script( 'swiper-func' );
	}

	protected function render() {
		$data = $this->get_settings();

		$this->swiper();

		$template = 'view';

		$swiper_data = array(
			'col_xl'   => $data['slide_to_show'],
			'autoplay' => $data['slider_autoplay'] == 'yes' ? true : false,
			'speed'    => $data['slider_autoplay_speed'],
			'allowSlideNext' => $data['slider_arrow'] == 'yes' ? true : false,
			'allowSlidePrev' => $data['slider_arrow'] == 'yes' ? true : false,
			'col_lg'  => $data['col_lg'],
			'col_md'  => $data['col_md'],
			'col_sm'  => $data['col_sm'],
			'col_xs'  => $data['col_xs'],
		);
		$data['swiper_data'] = json_encode( $swiper_data );

		return $this->rt_template( $template, $data );
	}
}
