<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Price extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Price', 'daisy-core' );
		$this->rt_base = 'rt-price';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'icon', [
				'label' => __( 'Icon', 'daisy-core' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
			      'value' => 'fas fa-check icon',
			      'library' => 'fa-solid',
			    ],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'list', [
				'label' => __( 'List', 'daisy-core' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$fields = array(
			array(
				'id'      => 'sec_rt_price',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Pricing Table', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
					'style3' => esc_html__( 'Style 3', 'daisy-core' ),
					'style4' => esc_html__( 'Style 4', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			/* = Title = */
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => __( 'Basic Plan', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'desc',
				'label'   => esc_html__( 'Description', 'daisy-core' ),
				'default' => __( 'Fusce consectetur erat id enim elementum tincidunt. Vestibulum accumsan.', 'daisy-core' ),
				'label_block' => true,
				'condition' => ['style' => ['style1', 'style3', 'style4' ] ],
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'image',
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1', 'style4' ) ),
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'showhide',
				'label'   => esc_html__( 'Shape', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'price_list',
				'label'   => esc_html__( 'Items', 'daisy-core' ),
				'prevent_empty' => false,
				'title_field' => '{{{ list }}}',
				'fields' => $repeater->get_controls(),
				'default' => array(
					array( 
						'icon' => 'fas fa-check icon',
						'list' => __( 'Graphic Design', 'daisy-core' )
					),
					array( 
						'icon' => 'fas fa-check icon',
						'list' => __( 'Web Design', 'daisy-core' )
					),
					array( 
						'icon' => 'fas fa-check icon',
						'list' => __( 'UI/UX', 'daisy-core' )
					),
					array( 
						'icon' => 'fas fa-check icon',
						'list' => __('HTML/CSS', 'daisy-core' )
					),
					array( 
						'icon' => 'fas fa-check icon',
						'list' => __('SEO Marketing', 'daisy-core' )
					),
					array( 
						'icon' => 'fas fa-check icon',
						'list' => __('Business Analysis', 'daisy-core' )
					),
				),
			),
			
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'price',
				'label'   => esc_html__( 'Price', 'daisy-core' ),
				'default' => '$95.00',
				'description' => esc_html__( 'Put your price with currency', 'daisy-core' ),			
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'price2',
				'label'   => esc_html__( 'Price 2', 'daisy-core' ),
				'default' => '$150.00',
				'description' => esc_html__( 'Put your 2nd price with currency', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2' ) ),			
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'period',
				'label'   => esc_html__( 'Period', 'daisy-core' ),
				'default' => 'Month',
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'period2',
				'label'   => esc_html__( 'Period 2', 'daisy-core' ),
				'default' => 'Year',
				'description' => esc_html__( 'Put your 2nd Period with currency', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'    => 'buttontext',
				'label'   => esc_html__( 'Button Text', 'daisy-core' ),
				'default' => 'Get A Quote',
				'label_block' => true,
			),
			array(
				'id'        => 'buttonurl',
				'type'        => Controls_Manager::URL,
				'label'       => __( 'Button URL', 'daisy-core' ),
				'placeholder' => 'https://your-link.com',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'offer_active',
				'label'   => esc_html__( 'Display Offer', 'daisy-core' ),
				'options' => array(
					'offer-active' 		=> esc_html__( 'Offer Active', 'daisy-core' ),
					'offer-inactive'  	=> esc_html__( 'Offer Inactive', 'daisy-core' ),
				),
				'default' => 'offer-inactive',
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);

		$styles = array(			
			// Style
			array(
				'id'      => 'full_table_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Full Item', 'daisy-core' ),
			),
			array(
				'id'      => 'full_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Full Table', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'name'     => 'pricing_table_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .pricing--style-1,
						{{WRAPPER}} .pricing--style-2
					',
			),
			array(
				'name'     => 'btn_ftable_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .pricing--style-2',
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'id'      => 'full_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'name'     => 'pricing_table_h_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .pricing--style-1:hover,
						{{WRAPPER}} .pricing--style-2:hover
					',
			),
			array(
				'name'     => 'btn_ftable_h_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .pricing--style-2:hover',
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'mode' => 'section_end',
			),

			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Content', 'daisy-core' ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .pricing__title' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .pricing__title',
			),
			array(
				'id'      => 'title_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .pricing__title' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} .pricing--style-3:hover .pricing__title' => 'background-color: {{VALUE}}', 
				),
				'condition'   => array( 'style' => array( 'style3', 'style4' ) ),
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .pricing--style-1:hover .pricing__title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .pricing--style-2:hover .pricing__title' => 'color: {{VALUE}}', 
				),
			),
			array(
				'id'      => 'desc_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Description', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'desc_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .pricing__desc' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'desc_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .pricing__desc',
			),
			array(
				'id'      => 'list_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Offer List', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'list_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .pricing__feature-list li' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'list_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .pricing__feature-list li',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'table_price_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Pricing', 'daisy-core' ),
			),
			array(
				'id'      => 'price_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Price', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'price_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .price' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .pricing__price-heading' => 'color: {{VALUE}}', 
				),
			),
			array(
				'id'      => 'price_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .pricing--style-1:hover .price' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .pricing--style-2:hover .pricing__price-heading' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'price_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .price, {{WRAPPER}} .pricing__price-heading',
			),
			array(
				'id'      => 'price_period_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Price Period', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'price_period_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .pack-duration' => 'color: {{VALUE}}' ),
			),
			array(
				'id'      => 'price_period_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .pricing--style-2:hover .pack-duration' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'price_period_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .pack-duration',
			),
			array(
				'mode' => 'section_end',
			),
			// Button
			array(
				'id'      => 'table_btn_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Button', 'daisy-core' ),
			),
			array(
				'id'      => 'price_btn_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-btn--4' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .rt-btn--7' => 'color: {{VALUE}}', 
				),
			),
			array(
				'id'      => 'price_btn_icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .icon--3 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .icon--4 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .icon--4 rect' => 'fill: {{VALUE}}', 
					),
			),
			array(
				'name'     => 'pricing_btn_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
				    	{{WRAPPER}} .rt-btn--4,
				    	{{WRAPPER}} .rt-btn--7
				    ',
			),
			array(
				'name'     => 'btn_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
							{{WRAPPER}} .rt-btn--4,
							{{WRAPPER}} .rt-btn--7
						',
			),
			array(
			    'id'      => 'pricing_btn_border_radius',
			    'type'    => Controls_Manager::DIMENSIONS,
			    'size_units' => [ 'px', '%', 'em' ],
			    'label'   => __( 'Border Radius', 'daisy-core' ),                 
			    'selectors' => array(
			        '{{WRAPPER}} .rt-btn--4' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			        '{{WRAPPER}} .rt-btn--7' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
			    ),
			),
			array(
				'id'      => 'pricing_btn_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'pricing_btn_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .pricing--style-1:hover .rt-btn--4' => 'color: {{VALUE}}', 
						'{{WRAPPER}} .pricing--style-2:hover .rt-btn--7' => 'color: {{VALUE}}', 
					),
			),
			array(
				'name'     => 'pricing_btn_h_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .rt-btn--4::before,
						{{WRAPPER}} .pricing--style-2:hover .rt-btn--7
					',
			),
			array(
				'name'     => 'btn_h_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
							{{WRAPPER}} .rt-btn--4::before,
							{{WRAPPER}} .pricing--style-2:hover .rt-btn--7
						',
			),
			array(
				'id'      => 'price_btn_hicon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Icon Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .pricing--style-1:hover .icon--3 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .pricing--style-2:hover .icon--4 path' => 'fill: {{VALUE}}', 
						'{{WRAPPER}} .pricing--style-2:hover .icon--4 rect' => 'fill: {{VALUE}}', 
					),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'angle_table_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Shape', 'daisy-core' ),
				'condition' => ['style' => ['style2' ] ],
			),
			array(
				'id'      => 'angle_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Normal', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'pricing_angle_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .shape-list svg path' => 'fill: {{VALUE}}' ),
			),
			array(
				'id'      => 'pricing_h_angle_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .pricing--style-2:hover .shape-list svg path' => 'fill: {{VALUE}}' ),
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);

		$fields = array_merge( $fields, $styles );
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ( $data['style'] ) {
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}