<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/counter/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Progress_Bar extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Progress Bar', 'daisy-core' );
		$this->rt_base = 'rt-progress-bar';
		parent::__construct( $data, $args );
	}

	private function rt_load_scripts(){}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'General', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
					'style3' => esc_html__( 'Style 3', 'daisy-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => esc_html__( 'UX / UI Design', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SLIDER,
				'id'      => 'number',
				'label'   => esc_html__( 'Percentage', 'daisy-core' ),
				'default' => array( 'size' => 80 ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'sec_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'bgcolor_color',
				'label'   => esc_html__( 'Bgcolor', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .skill--style-1 .skill__per' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} .skill--style-2 .skill__per' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} .skill--style-2 .skill__bar' => 'border-color: {{VALUE}}', 
					'{{WRAPPER}} .skill--style-3 .skill__per' => 'background: {{VALUE}}', 
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'per_color',
				'label'   => esc_html__( 'Percent Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .skill--style-1 .skill__per::before' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .skill--style-2 .skill__per::before' => 'color: {{VALUE}}', 
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'shape_color',
				'label'   => esc_html__( 'Shape Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .skill--style-2 .skill__per::before' => 'background: {{VALUE}}', 
					'{{WRAPPER}} .skill--style-2 .skill__per::after' => 'border-top-color: {{VALUE}}', 
					'{{WRAPPER}} .skill--style-3 .skill__per::before' => 'border-color: {{VALUE}}', 
				),
				'condition' => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'title_typo',
				'label'   => esc_html__( 'Title Style', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .skill--style-1 .skill__title, {{WRAPPER}} .skill--style-2 .skill__title',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'title_color',
				'label'   => esc_html__( 'Title Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( '{{WRAPPER}} .skill--style-1 .skill__title' => 'color: {{VALUE}}' ),
				'selectors' => array( '{{WRAPPER}} .skill--style-2 .skill__title' => 'color: {{VALUE}}' ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();
		$this->rt_load_scripts();

		switch ($data['style']) {
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}