<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Qualification extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'Qualification', 'daisy-core' );
		$this->rt_base = 'rt-qualification';	
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'year', [
				'type' 		  => Controls_Manager::NUMBER,
				'label'       => esc_html__( 'Year', 'daisy-core' ),
				'default'     => esc_html__( '2010', 'daisy-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'institute', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Institute Name', 'daisy-core' ),
				'default'     => esc_html__( 'University of California', 'daisy-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'daisy-core' ),
				'default'     => esc_html__( 'Diploma In Design', 'daisy-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'desc', [
				'type' 		  => Controls_Manager::TEXTAREA,
				'label'       => esc_html__( 'Description', 'daisy-core' ),
				'default'     => esc_html__( 'Fusce consectetur erat id enim elementum tincidunt. Vestibulum accumsan.', 'daisy-core' ),
				'label_block' => true,
			]
		);
		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => __( 'General', 'daisy-core' ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'qualification',
				'label'   => esc_html__( 'Add as many feature as you want', 'daisy-core' ),
				'fields'  => $repeater->get_controls(),
		       	'default' => [
					[
						'year' => __( '2010', 'daisy-core' ),
						'institute'  => __( 'University of California', 'daisy-core' ),
						'title'  => __( 'Diploma In Design', 'daisy-core' ),
						'desc'  => __( 'Fusce consectetur erat id enim elementum tincidunt. Vestibulum accumsan.', 'daisy-core' ),
					],
					[
						'year' => __( '2015', 'daisy-core' ),
						'institute'  => __( 'University of California', 'daisy-core' ),
						'title'  => __( 'Post Graduate In Math', 'daisy-core' ),
						'desc'  => __( 'Fusce consectetur erat id enim elementum tincidunt. Vestibulum accumsan.', 'daisy-core' ),
					],
					[
						'year' => __( '2017', 'daisy-core' ),
						'institute'  => __( 'University of California', 'daisy-core' ),
						'title'  => __( 'Bachelor of Science', 'daisy-core' ),
						'desc'  => __( 'Fusce consectetur erat id enim elementum tincidunt. Vestibulum accumsan.', 'daisy-core' ),
					],
				],
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'box_left_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Left', 'daisy-core' ),
			),
			array(
				'id'      => 'box_left_title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Style', 'daisy-core' ),
				'separator' => 'before',
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'left_box_title_typo',
				'label'   => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .timeline--style-1 .timeline__item .year',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'left_box_title_color',
				'label'   => esc_html__( 'Title 1 Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .timeline__item:nth-child(1) .year' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'left_box_title2_color',
				'label'   => esc_html__( 'Title 2 Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .timeline__item:nth-child(2) .year' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'left_box_title3_color',
				'label'   => esc_html__( 'Title 3 Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .timeline__item:nth-child(3) .year' => 'color: {{VALUE}}',
				),
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'left_box_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .timeline--style-1 .timeline__item .year' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                              
	            ),
	            'separator' => 'before',
	        ),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'mode'          => 'responsive',
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'left_box_title_margin',
	            'label'   => __( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .timeline--style-1 .timeline__item .year' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
	        array(
				'id'      => 'box_left_content_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Content Style', 'daisy-core' ),
				'separator' => 'before',
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'left_box_content_typo',
				'label'   => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .timeline--style-1 .institute-name',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'left_content_color',
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .institute-name' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'box_right_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Right', 'daisy-core' ),
			),
			array(
				'id'      => 'box_right_title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Style', 'daisy-core' ),
				'separator' => 'before',
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'right_box_title_typo',
				'label'   => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .timeline--style-1 .item-title',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'right_box_title_color',
				'label'   => esc_html__( 'Title 1 Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .item-title' => 'color: {{VALUE}}',
				),
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'right_box_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .timeline--style-1 .item-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                              
	            ),
	            'separator' => 'before',
	        ),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'mode'          => 'responsive',
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'right_box_title_margin',
	            'label'   => __( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .timeline--style-1 .item-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
	        array(
				'id'      => 'box_right_content_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Content Style', 'daisy-core' ),
				'separator' => 'before',
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'right_box_content_typo',
				'label'   => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .timeline--style-1 .item-detail',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'right_content_color',
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .item-detail' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'border_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Border Style', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'border_color',
				'label'   => esc_html__( 'Border Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1::after' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'dot1_color',
				'label'   => esc_html__( 'Dot 1 Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .timeline__stamp .timeline__bar' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .timeline--style-1 .timeline__stamp .timeline__bar::before' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'dot2_color',
				'label'   => esc_html__( 'Dot 2 Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .timeline__item:nth-child(2) .timeline__stamp .timeline__bar' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .timeline--style-1 .timeline__item:nth-child(2) .timeline__stamp .timeline__bar::before' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'dot3_color',
				'label'   => esc_html__( 'Dot 3 Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .timeline--style-1 .timeline__item:nth-child(3) .timeline__stamp .timeline__bar' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .timeline--style-1 .timeline__item:nth-child(3) .timeline__stamp .timeline__bar::before' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}
	protected function render() {
		$data 	  = $this->get_settings();

		$template = 'view';
		
		return $this->rt_template( $template, $data );		
	}
}