<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/services/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use radiustheme\daisy\inc\Helper;

$prefix = DAISY_CORE_THEME_PREFIX;

if ( ! defined( 'ABSPATH' ) ) exit;

class Service_Slider extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Service Slider', 'daisy-core' );
		$this->rt_base = 'rt-service-slider';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_rt_service',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Services', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Layout 1', 'daisy-core' ),
					'style2' => esc_html__( 'Layout 2', 'daisy-core' ),
					'style3' => esc_html__( 'Layout 3', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			array(
				'id'      => 'query_type',
				'type'    => Controls_Manager::SELECT2,
				'label'   => esc_html__( 'Get Posts by cats or title', 'daisy-core' ),
				'options' => array(
					'cats' => esc_html__( 'Posts by Categories', 'daisy-core' ),
					'titles' => esc_html__( 'Posts by Titles', 'daisy-core' ),
				),
				'label_block' => true,
			),
			array(
				'id'      => 'postbycats',
				'label' => __( 'Select Terms', 'daisy-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => Helper::service_categories_slug(),              
                'multiple' => true,
                'label_block' => true,
                'condition'   => array( 'query_type' => array( 'cats' ) ),
			),
			array(
				'id'      => 'postbytitle',
				'label'   => esc_html__( 'Posts By Title', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_service_posts_title(),
				'multiple' => true,
				'label_block' => true,
				'condition'   => array( 'query_type' => array( 'titles' ) ),
			),
			array(
				'id'      => 'number',
				'label'   =>esc_html__( 'Total number of post Member', 'daisy-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'description' =>esc_html__( 'Write -1 to show all', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'offset',
				'label'   =>esc_html__( 'Post Offset', 'daisy-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 0,
				'description' =>esc_html__( 'offset means start showing post not from the first post', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'orderby',
				'label'   => esc_html__( 'Order By', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_post_orderby(),
				'default' => 'date',
				'label_block' => true,
			),
			array(
				'id'      => 'excerpt',
				'label'   =>esc_html__( 'Content excerpt number', 'daisy-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '20',
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'buttontext',
				'label'   => esc_html__( 'Button Text', 'daisy-core' ),
				'default' => esc_html__( 'READ MORE', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider',
				'label'       => esc_html__( 'Slider Options', 'daisy-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_autoplay',
				'label'       => esc_html__( 'Autoplay', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slider_autoplay_speed',
				'label'   => esc_html__( 'Autoplay Speed', 'daisy-core' ),
				'options' => $this->rt_autoplay_speed(),
				'default' => '2000',
				'description' => esc_html__( 'Select any value for autopaly speed. Default: 2000', 'daisy-core' ),
				'condition'   => array( 
					'slider_autoplay' => 'yes', 
				),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_dots',
				'label'       => esc_html__( 'Dots', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'default'     => 'on',
				'description' => esc_html__( 'Enable or disable nav dots. Default: off', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_arrow',
				'label'       => esc_html__( 'Arrow', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable nav dots. Default: off', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show',
				'label'   => esc_html__( 'Slide To Show', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '3',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 6', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_lg',
				'label'   => esc_html__( 'Desktops: > 1199px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '3',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 4', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_md',
				'label'   => esc_html__( 'Desktops: > 991px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'This is mostly tab view.  Default: 3', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_sm',
				'label'   => esc_html__( 'Mobile View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for mobile device show. Default: 2', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_xs',
				'label'   => esc_html__( 'Mobile Small View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for small mobile device show. Default: 1', 'daisy-core' ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Style', 'daisy-core' ),
			),
			array(
				'id'      => 'fullbox_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Fullbox', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'name'     => 'fullbox_bg_color',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service--style-2,
					{{WRAPPER}} .service__img::after,
					{{WRAPPER}} .service__img a::before
				',
			),
			array(
				'id'      => 'shape_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Shape Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .service--style-2::before' => 'background-color: {{VALUE}} !important',
						'{{WRAPPER}} .service--style-2::after' => 'border-color: {{VALUE}} !important',
					),
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'        => 'fullbox_h_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'name'      => 'fullbox_h_bg_color',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Background', 'daisy-core' ),
				'selector'  => '
					{{WRAPPER}} .service--style-2:hover,
					{{WRAPPER}} .service__content::after,
					{{WRAPPER}} .service__img a::after
				',
			),
			array(
				'mode'      => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Elements Style', 'daisy-core' ),
			),
			array(
				'id'      => 'icon_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon Style', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service__icon i:before' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'name'     => 'icon_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service__icon i
				',
			),
			array(
				'id'      => 'icon_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon Hover', 'daisy-core' ),
				'separator' => 'before',
				'condition' => array( 'style' => array( 'style3' ) ),
			),
			array(
				'id'      => 'icon_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service--style-1:hover .service__icon i:before' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .service--style-4:hover .service__icon i:before' => 'color: {{VALUE}} !important',
				),
				'condition' => array( 'style' => array( 'style3' ) ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service__title a' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service__title a
				',
			),
			array(
				'id'      => 'title_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service__title a:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .service__title a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'text_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Text', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'text_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service--style-2 p' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .service--style-3 p' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .service--style-4 p' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'text_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service--style-2 p,
					{{WRAPPER}} .service--style-3 p,
					{{WRAPPER}} .service--style-4 p
				',
			),
			array(
				'id'      => 'text_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Text Hover', 'daisy-core' ),
				'separator' => 'before',
				'condition' => array( 'style' => array( 'style3' ) ),
			),
			array(
				'id'      => 'text_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service--style-1:hover p' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .service--style-4:hover p' => 'color: {{VALUE}} !important',
				),
				'condition' => array( 'style' => array( 'style3' ) ),
			),
			array(
				'id'      => 'link_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Link', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'link_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-btn--8' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .rt-btn--11' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .rt-btn--12' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'link_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .rt-btn--8,
					{{WRAPPER}} .rt-btn--11,
					{{WRAPPER}} .rt-btn--12
				',
			),
			array(
				'name'     => 'link_bg_color',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service--style-2,
					{{WRAPPER}} .rt-btn--11
				',
				'condition' => array( 'style' => array( 'style2' ) ),
			),
			array(
				'id'      => 'link_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Link Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'link_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-btn--8:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .rt-btn--11:hover' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .service--style-4:hover .rt-btn--12' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'link_icon_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'licon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .icon--4 svg path' => 'fill: {{VALUE}} !important',
					'{{WRAPPER}} .icon--4 svg rect' => 'fill: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'licon_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .rt-btn--8:hover .icon--4 svg path' => 'fill: {{VALUE}} !important',
					'{{WRAPPER}} .rt-btn--11:hover .icon--4 svg path' => 'fill: {{VALUE}} !important',
					'{{WRAPPER}} .rt-btn--11:hover .icon--4 svg rect' => 'fill: {{VALUE}} !important',
					'{{WRAPPER}} .service--style-4:hover .rt-btn--12 svg path' => 'fill: {{VALUE}} !important',
					'{{WRAPPER}} .service--style-4:hover .rt-btn--12 svg rect' => 'fill: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'dot_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Dots', 'daisy-core' ),
				'separator' => 'before',
				'condition'   => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'name'     => 'sdot_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .swiper-pagination-bullet
				',
				'condition'   => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'id'      => 'sdot_bgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .swiper-pagination-bullet::after' => 'background-color: {{VALUE}}', 
						'{{WRAPPER}} .swiper-pagination-bullet' => 'background-color: {{VALUE}}', 
					),
				'condition'   => array( 'style' => array( 'style2', 'style3' ) ),
			),
			// Active
			array(
				'id'        => 'dota_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Active Color', 'daisy-core' ),
				'separator' => 'before',
				'condition'   => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'id'      => 'sdot_hbgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active::after' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color: {{VALUE}}', 
				),
				'condition'   => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'id'      => 'sdot_hbbgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-color: {{VALUE}}' 
				),
				'condition'   => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),	
		);
		return $fields;
	}

	public function swiper(){
		wp_enqueue_style( 'swiper' );
		wp_enqueue_script( 'swiper' );
		wp_enqueue_script( 'swiper-func' );
	}

	protected function render() {
		$data = $this->get_settings();

		if ( $data['style'] == 'style1' ||  $data['style'] == 'style2' ||  $data['style'] == 'style3' ) {
			$this->swiper();
		}

		switch ($data['style']) {
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		if ( $data['style'] == 'style1' || $data['style'] == 'style2' || $data['style'] == 'style3' ) {
			$swiper_data = array(
				'col_xl'   => $data['slide_to_show'],
				'autoplay' => $data['slider_autoplay'] == 'yes' ? true : false,
				'speed'    => $data['slider_autoplay_speed'],
				'col_lg'  => $data['col_lg'],
				'col_md'  => $data['col_md'],
				'col_sm'  => $data['col_sm'],
				'col_xs'  => $data['col_xs'],
			);
			$data['swiper_data'] = json_encode( $swiper_data );
		}

		return $this->rt_template( $template, $data );
	}
}