<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/services/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use radiustheme\daisy\inc\Helper;

$prefix = DAISY_CORE_THEME_PREFIX;

if ( ! defined( 'ABSPATH' ) ) exit;

class Services extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Services', 'daisy-core' );
		$this->rt_base = 'rt-service';
		$this->rt_translate = array(
			'cols'  => array(
				'12' => esc_html__( '1 Col', 'daisy-core' ),
				'6'  => esc_html__( '2 Col', 'daisy-core' ),
				'4'  => esc_html__( '3 Col', 'daisy-core' ),
				'3'  => esc_html__( '4 Col', 'daisy-core' ),
				'2'  => esc_html__( '6 Col', 'daisy-core' ),
			),
		);
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_rt_service',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Services', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Layout 1', 'daisy-core' ),
					'style2' => esc_html__( 'Layout 2', 'daisy-core' ),
					'style3' => esc_html__( 'Layout 3', 'daisy-core' ),
					'style4' => esc_html__( 'Layout 4', 'daisy-core' ),
					'style5' => esc_html__( 'Layout 5', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			array(
				'id'      => 'query_type',
				'type'    => Controls_Manager::SELECT2,
				'label'   => esc_html__( 'Get Posts by cats or title', 'daisy-core' ),
				'options' => array(
					'cats' => esc_html__( 'Posts by Categories', 'daisy-core' ),
					'titles' => esc_html__( 'Posts by Titles', 'daisy-core' ),
				),
				'label_block' => true,
			),
			array(
				'id'      => 'postbycats',
				'label' => __( 'Select Terms', 'daisy-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => Helper::service_categories_slug(),              
                'multiple' => true,
                'label_block' => true,
                'condition'   => array( 'query_type' => array( 'cats' ) ),
			),
			array(
				'id'      => 'postbytitle',
				'label'   => esc_html__( 'Posts By Title', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_service_posts_title(),
				'multiple' => true,
				'label_block' => true,
				'condition'   => array( 'query_type' => array( 'titles' ) ),
			),
			array(
				'id'      => 'number',
				'label'   =>esc_html__( 'Total number of post Member', 'daisy-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'description' =>esc_html__( 'Write -1 to show all', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'offset',
				'label'   =>esc_html__( 'Post Offset', 'daisy-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 0,
				'description' =>esc_html__( 'offset means start showing post not from the first post', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'orderby',
				'label'   => esc_html__( 'Order By', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_post_orderby(),
				'default' => 'date',
				'label_block' => true,
			),
			array(
				'id'      => 'excerpt',
				'label'   =>esc_html__( 'Content excerpt number', 'daisy-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '20',
				'label_block' => true,
			),
			array(
                'type'        => Controls_Manager::SWITCHER,
                'id'          => 'shape',
                'label'       => esc_html__('Shape', 'daisy-core'),
                'label_on'    => esc_html__('Show', 'daisy-core'),
                'label_off'   => esc_html__('Hide', 'daisy-core'),
                'default'     => 'yes',
                'description' => esc_html__('Shape. Default: Show', 'daisy-core'),
                'condition' => array( 'style' => array( 'style1' ) ),
            ),
			array(
				'mode' => 'section_end',
			),
			// Responsive Columns
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_responsive',
				'label'   => esc_html__( 'Number of Responsive Columns', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_xl',
				'label'   => esc_html__( 'Desktops: > 1199px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '4',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_lg',
				'label'   => esc_html__( 'Desktops: > 991px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '4',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_md',
				'label'   => esc_html__( 'Tablets: > 767px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '6',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_sm',
				'label'   => esc_html__( 'Phones: > 576px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '12',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col',
				'label'   => esc_html__( 'Phones: < 576px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '12',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'box_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Box Style', 'daisy-core' ),
			),
			array(
				'id'      => 'fullbox_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Fullbox', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'name'     => 'fullbox_bg_color',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service--style-1,
					{{WRAPPER}} .why-choose--style-3,
					{{WRAPPER}} .why-choose--style-7
				',
			),
			array(
				'id'        => 'fullbox_h_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'name'      => 'fullbox_h_bg_color',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Background', 'daisy-core' ),
				'selector'  => '
					{{WRAPPER}} .service--style-1::after,
					{{WRAPPER}} .why-choose--style-3:hover,
					{{WRAPPER}} .why-choose--style-7:hover
				',
			),
			array(
				'id'      => 'shape_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Shape Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .why-choose__line::after' => 'background-color: {{VALUE}} !important', 
						'{{WRAPPER}} .why-choose__line::before' => 'background-color: {{VALUE}} !important', 
					),
				'condition' => array( 'style' => array( 'style2' ) ),
			),
			array(
				'mode'      => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Elements Style', 'daisy-core' ),
			),
			array(
				'id'      => 'icon_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon Style', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service__icon i:before' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .why-choose__icon i:before' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'name'     => 'icon_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service__icon i,
					{{WRAPPER}} .why-choose__icon i
				',
			),
			array(
				'name'      => 'icon_bg_color',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Background', 'daisy-core' ),
				'selector'  => '
					{{WRAPPER}} .service__icon,
					{{WRAPPER}} .why-choose__icon
				',
				'condition' => array( 'style' => array( 'style1', 'style4' ) ),
			),
			array(
				'id'      => 'icon_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Icon Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'icon_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service--style-1:hover .service__icon i:before' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .why-choose--style-5:hover .why-choose__icon i:before' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .why-choose--style-7:hover .why-choose__icon i:before' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .why-choose--style-8:hover .why-choose__icon i:before' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'name'      => 'icon_hbg_color',
				'mode'      => 'group',
				'type'      => Group_Control_Background::get_type(),
				'label'     => __( 'Hover Background', 'daisy-core' ),
				'selector'  => '{{WRAPPER}} .service--style-1:hover .service__icon',
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'id'      => 'title_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service__title a' => 'color: {{VALUE}} !important', 
					'{{WRAPPER}} .why-choose__title a' => 'color: {{VALUE}} !important', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service__title a,
					{{WRAPPER}} .why-choose__title a
				',
			),
			array(
				'id'      => 'title_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Title Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'title_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service--style-1:hover .service__title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .why-choose--style-5:hover .why-choose__title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .why-choose--style-7:hover .why-choose__title a' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .why-choose--style-8 .why-choose__title a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'text_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Text', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'text_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service--style-1 p' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .why-choose p' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'text_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .service--style-1 p,
					{{WRAPPER}} .why-choose p
				',
			),
			array(
				'id'      => 'text_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Text Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'text_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .service--style-1:hover p' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .why-choose--style-7:hover p' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),	
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style5':
			$template = 'view-5';
			break;
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}