<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/info-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Social_Box extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Social Box', 'daisy-core' );
		$this->rt_base = 'rt-social-box';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => __( 'Social Box', 'daisy-core' ),
			),
			//Icon Start
			array(	
				'id'      => 'icontype',				 
			   	'type'    => Controls_Manager::CHOOSE,
			   	'label'   => esc_html__( 'Media Type', 'daisy-core' ),
			   	'options' => [
				    'icon' => [
				       'title' => esc_html__( 'Left', 'daisy-core' ),
				       'icon' => 'fa fa-smile',
				    ],
				    'image' => [
				       'title' => esc_html__( 'Center', 'daisy-core' ),
				       'icon' => 'fa fa-image',
				    ],		     
			   	],
			   	'default' => 'icon',
			   	'label_block' => false,
			   	'toggle' => false,
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'icon_class',
				'label'   => esc_html__( 'Icon', 'daisy-core' ),
				'default' => [
			      'value' => 'fab fa-facebook',
			      'library' => 'fa-solid',
			  	],
			  	'condition'    => array(
					'icontype' => array( 'icon' ),
				),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'icon_image',
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'default' => [
                    'url' => $this->rt_placeholder_image(),
                ],
				'description' => esc_html__( 'Recommended full image', 'daisy-core' ),
				'condition'    => array(
					'icontype' => array( 'image' ),
				),
			),
			//Icon end
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => __( 'Facebook', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::URL,
				'id'      => 'link',
				'label'   => esc_html__( 'Link', 'daisy-core' ),
				'placeholder' => 'https://your-link.com',
			),
			array(
				'mode' => 'section_end',
			),
			// Full Item Style
			array(
				'id'      => 'full_item_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Full Item', 'daisy-core' ),
			),
			array(
				'name'       => 'box_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .social-box--style-1',
			),
			array(
				'id'      => 'shape_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Shape Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .social-box__inner::before' => 'background-color: {{VALUE}}', 
						'{{WRAPPER}} .social-box__inner::after' => 'background-color: {{VALUE}}',
						'{{WRAPPER}} .social-box__icon-text::before' => 'background-color: {{VALUE}}',
						'{{WRAPPER}} .social-box__icon-text::after' => 'background-color: {{VALUE}}',
					),
			),
			array(
				'id'      => 'shape_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Shape Hover Color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .social-box--style-1:hover .social-box__inner::before' => 'background-color: {{VALUE}}',
						'{{WRAPPER}} .social-box--style-1:hover .social-box__icon-text::before' => 'background-color: {{VALUE}}',
						'{{WRAPPER}} .social-box--style-1:hover .social-box__inner::after' => 'background-color: {{VALUE}}',
						'{{WRAPPER}} .social-box--style-1:hover .social-box__icon-text::after' => 'background-color: {{VALUE}}',
					),
			),
			array(
				'mode' => 'section_end',
			),
			// Icon Styles
			array(
				'id'      => 'icon_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Icon', 'daisy-core' ),
			),			
			array(
				'id'      => 'icon_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .rtin-icon' => 'color: {{VALUE}}' ),
			),
			array(
				'name'       => 'icon_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .rtin-icon',
			),
			array(
				'name'     => 'icon_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .rtin-icon',
			),
			array(
				'id'      => 'iconh_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'iconh_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .social-box--style-1:hover .rtin-icon' => 'color: {{VALUE}}' ),
			),
			array(
				'name'     => 'iconh_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .social-box--style-1:hover .rtin-icon',
			),
			array(
				'mode' => 'section_end',
			),
			// Title Style
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .social-box__icon-text' => 'color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'titleh_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .social-box--style-1:hover .social-box__icon-text' => 'color: {{VALUE}}',
				),
			),
			array(
				'name'       => 'title_typo',
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '
						{{WRAPPER}} .social-box__icon-text
					',
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}