<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/team/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;
use radiustheme\daisy\inc\Helper;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;


if ( ! defined( 'ABSPATH' ) ) exit;

class Team extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Team', 'daisy-core' );
		$this->rt_base = 'rt-team';
		$this->rt_translate = array(
			'cols'  => array(
				'12' => esc_html__( '1 Col', 'daisy-core' ),
				'6'  => esc_html__( '2 Col', 'daisy-core' ),
				'4'  => esc_html__( '3 Col', 'daisy-core' ),
				'3'  => esc_html__( '4 Col', 'daisy-core' ),
				'2'  => esc_html__( '6 Col', 'daisy-core' ),
			),
		);
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_rt_team',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'Team', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Layout 1', 'daisy-core' ),
					'style2' => esc_html__( 'Layout 2', 'daisy-core' ),
					'style3' => esc_html__( 'Layout 3', 'daisy-core' ),
					'style4' => esc_html__( 'Layout 4', 'daisy-core' ),
					'style5' => esc_html__( 'Layout 5', 'daisy-core' ),
					'style6' => esc_html__( 'Layout 6', 'daisy-core' ),
					'style7' => esc_html__( 'Layout 7', 'daisy-core' ),
				),
				'default' => 'style1',
			),
			//Query Type
			array(
				'id'      => 'query_type',
				'type'    => Controls_Manager::SELECT2,
				'label'   => esc_html__( 'Get Posts by cats or title', 'daisy-core' ),
				'options' => array(
					'cats' => esc_html__( 'Posts by Categories', 'daisy-core' ),
					'titles' => esc_html__( 'Posts by Titles', 'daisy-core' ),
				),
				'label_block' => true,
			),
			// Terms
			array(
				'id'      => 'postbycats',
				'label' => __( 'Select Terms', 'daisy-core' ),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'options' => Helper::team_categories_slug(),              
                'multiple' => true,
                'label_block' => true,
                'condition'   => array( 'query_type' => array( 'cats' ) ),
			),
			array(
				'id'      => 'postbytitle',
				'label'   => esc_html__( 'Posts By Title', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_team_posts_title(),
				'default' => '',
				'multiple' => true,
				'label_block' => true,
				'condition'   => array( 'query_type' => array( 'titles' ) ),
			),
			// Post per page
			array(
				'id'      => 'number',
				'label'   =>esc_html__( 'Total number of post Member', 'daisy-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'description' =>esc_html__( 'Write -1 to show all', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'offset',
				'label'   =>esc_html__( 'Post Offset', 'daisy-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 0,
				'description' =>esc_html__( 'offset means start showing post not from the first post', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'orderby',
				'label'   => esc_html__( 'Order By', 'daisy-core' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => $this->rt_post_orderby(),
				'default' => 'date',
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SWITCHER,
				'id'      => 'shape_showhide',
				'label'   => esc_html__( 'Shape', 'daisy-core' ),
				'label_on'    => esc_html__( 'Show', 'daisy-core' ),
				'label_off'   => esc_html__( 'Hide', 'daisy-core' ),
				'default'     => 'yes',
				'condition'   => array( 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'layout',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'layout1' => esc_html__( 'Grid layout', 'daisy-core' ),
					'layout2' => esc_html__( 'Slider layout', 'daisy-core' ),
				),
				'default' => 'layout1',
			),
			array(
				'mode' => 'section_end',
			),
			// Responsive Columns
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_responsive',
				'label'   => esc_html__( 'Number of Responsive Columns', 'daisy-core' ),
				'condition'   => array( 'layout' => array( 'layout1') ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'cols_xl',
				'label'   => esc_html__( 'Desktops: > 1199px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '4',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'cols_lg',
				'label'   => esc_html__( 'Desktops: > 991px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '4',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'cols_md',
				'label'   => esc_html__( 'Tablets: > 767px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '6',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'cols_sm',
				'label'   => esc_html__( 'Phones: > 576px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '12',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'cols',
				'label'   => esc_html__( 'Phones: < 576px', 'daisy-core' ),
				'options' => $this->rt_translate['cols'],
				'default' => '12',
			),
			array(
				'mode' => 'section_end',
				'condition'   => array( 'layout' => array( 'layout1') ),
			),
			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider',
				'label'       => esc_html__( 'Slider Options', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_autoplay',
				'label'       => esc_html__( 'Autoplay', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slider_autoplay_speed',
				'label'   => esc_html__( 'Autoplay Speed', 'daisy-core' ),
				'options' => $this->rt_autoplay_speed(),
				'default' => '2000',
				'description' => esc_html__( 'Select any value for autopaly speed. Default: 2000', 'daisy-core' ),
				'condition'   => array( 
					'style' => array( 'style2', 'style3', 'style4', 'style5' ), 
					'slider_autoplay' => 'yes', 
				),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_dots',
				'label'       => esc_html__( 'Dots', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'default'     => 'on',
				'description' => esc_html__( 'Enable or disable nav dots. Default: off', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show',
				'label'   => esc_html__( 'Slide To Show', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '3',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 6', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_lg',
				'label'   => esc_html__( 'Desktops: > 1199px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 4', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_md',
				'label'   => esc_html__( 'Desktops: > 991px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '2',
				'description' => esc_html__( 'This is mostly tab view.  Default: 3', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_sm',
				'label'   => esc_html__( 'Mobile View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for mobile device show. Default: 2', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_xs',
				'label'   => esc_html__( 'Mobile Small View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for small mobile device show. Default: 1', 'daisy-core' ),
				'condition'   => array( 'style' => array( 'style2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'mode' => 'section_end',
				'condition'   => array( 'layout' => array( 'layout2', 'style3', 'style4', 'style5' ) ),
			),
			// Style
			array(
				'id'      => 'team_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Style', 'daisy-core' ),
			),
			array(
				'id'      => 'contentbox_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Box Background', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .team--style-3 .team__content' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} .team--style-4 .team__content' => 'background-color: {{VALUE}}', 
					'{{WRAPPER}} .team--style-5 .team__social::before' => 'background-color: {{VALUE}}', 
				),
				'condition'   => array( 'style' => array( 'style3', 'style4', 'style5' ) ),
			),
			array(
				'id'      => 'name_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Name', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'name_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .team__author-name a' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'name_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .team__author-name a',
			),
			array(
				'id'      => 'name_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .team__author-name a:hover' => 'color: {{VALUE}}' ),
			),
			// Designation
			array(
				'id'      => 'designation_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Designation', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'designation_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .team__author-designation' => 'color: {{VALUE}}' ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'designation_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .team__author-designation',
			),
			// Social
			array(
				'id'      => 'social_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Social', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'social_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .social__item a' => 'color: {{VALUE}}' 
				),
			),
			array(
				'name'       => 'social_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => esc_html__( 'Background', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .social__item a',
			),
			array(
				'id'      => 'social_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'social_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Hover Color', 'daisy-core' ),
				'selectors' => array( '{{WRAPPER}} .social__item a:hover' => 'color: {{VALUE}}' ),
			),
			array(
				'name'       => 'social_h_bgcolor',
				'mode'     => 'group',
				'type'     => Group_Control_Background::get_type(),
				'label'    => __( 'Background', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .social__item a:hover',
			),
			array(
				'id'      => 'dot_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Dots', 'daisy-core' ),
				'separator' => 'before',
				'condition'   => array( 'layout' => array( 'layout2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'name'     => 'sdot_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .swiper-pagination-bullet
				',
				'condition'   => array( 'layout' => array( 'layout2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'id'      => 'sdot_bgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background color', 'daisy-core' ),
				'selectors' => array( 
						'{{WRAPPER}} .swiper-pagination-bullet::after' => 'background-color: {{VALUE}}', 
					),
				'condition'   => array( 'layout' => array( 'layout2', 'style3', 'style4', 'style5' ) ),
			),
			// Active
			array(
				'id'        => 'dota_heading',
				'type'      => Controls_Manager::HEADING,
				'label'     => __( 'Active Color', 'daisy-core' ),
				'separator' => 'before',
				'condition'   => array( 'layout' => array( 'layout2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'id'      => 'sdot_hbgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active::after' => 'background-color: {{VALUE}}' 
				),
				'condition'   => array( 'layout' => array( 'layout2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'id'      => 'sdot_hbbgc',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-color: {{VALUE}}' 
				),
				'condition'   => array( 'layout' => array( 'layout2', 'style3', 'style4', 'style5' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}


	public function swiper(){
		wp_enqueue_style( 'swiper' );
		wp_enqueue_script( 'swiper' );
		wp_enqueue_script( 'swiper-func' );
	}

	protected function render() {
		$data = $this->get_settings();

		if ( $data['style'] == 'style2' ||  $data['style'] == 'style3' ||  $data['style'] == 'style4' ||  $data['style'] == 'style5' ) {
			$this->swiper();
		}

		$template = 'view';
		switch ($data['style']) {
			case 'style7':
			$template = 'view-7';
			break;
			case 'style6':
			$template = 'view-6';
			break;
			case 'style5':
			$template = 'view-5';
			break;
			case 'style4':
			$template = 'view-4';
			break;
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		if ( $data['style'] == 'style2' || $data['style'] == 'style3' || $data['style'] == 'style4' || $data['style'] == 'style5' ) {
			$swiper_data = array(
				'col_xl'   => $data['slide_to_show'],
				'autoplay' => $data['slider_autoplay'] == 'yes' ? true : false,
				'speed'    => $data['slider_autoplay_speed'],
				'col_lg'  => $data['col_lg'],
				'col_md'  => $data['col_md'],
				'col_sm'  => $data['col_sm'],
				'col_xs'  => $data['col_xs'],
			);
			$data['swiper_data'] = json_encode( $swiper_data );
		}

		return $this->rt_template( $template, $data );
	}
}