<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit;

class Testimonial extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Testimonial', 'daisy-core' );
		$this->rt_base = 'rt-testimonial';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'picture', [
				'type'    => Controls_Manager::MEDIA,
				'label'   => esc_html__( 'Picture', 'daisy-core' ),
				'default' => [
	                'url' => $this->rt_placeholder_image(),
	            ],
				'description' => esc_html__( 'Image size should be 100px', 'daisy-core' ),
				'show_label' => false,
			]
		);
		$repeater->add_control(
			'title', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'daisy-core' ),
				'default'     => esc_html__( 'ALICE JOHNSON', 'daisy-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'designation', [
				'type' 		  => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Designation', 'daisy-core' ),
				'default'     => esc_html__( 'Marketing Manager', 'daisy-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'desc', [
				'type' 		  => Controls_Manager::TEXTAREA,
				'label'       => esc_html__( 'Description', 'daisy-core' ),
				'default'     => esc_html__( 'Fusce consectetur erat id enim elementum tincidunt. Vestibulum accumsan elementum leo, et viverra justo ultricies ac. Vivamus quis dolor ac orci tempus ornare. In volutpat vitae ligula vitae lacinia.', 'daisy-core' ),
				'label_block' => true,
			]
		);
		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'General', 'daisy-core' ),
			),
			array(
				'id'      	  => 'layout',
				'type'    	  => Controls_Manager::SELECT2,
				'label'   	  => esc_html__( 'Layout', 'daisy-core' ),
				'options' 	  => array(
					'layout1' 	  => esc_html__( 'Layout 1', 'daisy-core' ),
					'layout2' 	  => esc_html__( 'Layout 2', 'daisy-core' ),
					'layout3' 	  => esc_html__( 'Layout 3', 'daisy-core' ),
					'layout4' 	  => esc_html__( 'Layout 4', 'daisy-core' ),
					'layout5' 	  => esc_html__( 'Layout 5', 'daisy-core' ),
				),
				'default' 	  => 'layout1',
				'description' => esc_html__( 'Testimonial Layout. Default: Layout 1', 'daisy-core' ),
				'label_block' => true,
			),
			// Title
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => __( 'Title', 'daisy-core' ),
				'default' => __( 'Client\'s Feedback', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'layout' => array( 'layout1', 'layout4' ) ),
			),
			array(
				'id'      => 'heading_tag',
				'mode'    => 'responsive',
				'type'    => Controls_Manager::SELECT,
				'label'   => __( 'HTML Tag', 'daisy-core' ),
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
				],
				'default' => 'h2',
				'condition'   => array( 'layout' => array( 'layout1', 'layout4' ) ),
			),
			// Sub Title
			array(
				'id'      => 'subtitle',
				'type'    => Controls_Manager::TEXT,
				'label'   => __( 'Sub Title', 'daisy-core' ),
				'default' => __( 'Testimonial', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'layout' => array( 'layout1', 'layout4' ) ),
			),
			array(
				'id'      => 'secdesc',
				'type'    => Controls_Manager::TEXTAREA,
				'label'   => __( 'Section Description', 'daisy-core' ),
				'default' => __( 'Daisy started its operation in the year 1999. We are World, based Web, App and Digital Marketing Company. Domain is Web Design, App Development, Digital', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'layout' => array( 'layout4' ) ),
			),
			array (
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'testimonials',
				'label'   => esc_html__( 'Items', 'daisy-core' ),
				'fields' => $repeater->get_controls(),
				'default'  => [
					[
						'picture'  => $this->rt_placeholder_image(),
						'title' => __( 'ALICE JOHNSON', 'daisy-core' ),
						'designation' => __( 'Marketing Manager', 'daisy-core' ),
						'desc'  => __( 'Fusce consectetur erat id enim elementum tincidunt. Vestibulum accumsan elementum leo, et viverra justo ultricies ac. Vivamus quis dolor ac orci tempus ornare. In volutpat vitae ligula vitae lacinia.', 'daisy-core' ),
					],
				],
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'mode'        => 'section_start',
				'id'          => 'sec_slider',
				'label'       => esc_html__( 'Slider Options', 'daisy-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_autoplay',
				'label'       => esc_html__( 'Autoplay', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slider_autoplay_speed',
				'label'   => esc_html__( 'Autoplay Speed', 'daisy-core' ),
				'options' => $this->rt_autoplay_speed(),
				'default' => '800',
				'description' => esc_html__( 'Select any value for autopaly speed. Default: 800', 'daisy-core' ),
				'condition'   => array( 
					'slider_autoplay' => 'yes', 
				),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_dots',
				'label'       => esc_html__( 'Dots', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Enable or disable nav dots. Default: off', 'daisy-core' ),
				'condition'   => array( 'layout' => array( 'layout3' ) ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_arrow',
				'label'       => esc_html__( 'Arrow', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Enable or disable nav dots. Default: off', 'daisy-core' ),
				'condition'   => array( 'layout' => array( 'layout1', 'layout2', 'layout4', 'layout5' ) ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'slider_quote',
				'label'       => esc_html__( 'Quote', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'default'     => 'yes',
				'description' => esc_html__( 'Enable or disable autoplay. Default: On', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'slide_to_show',
				'label'   => esc_html__( 'Slide To Show', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 6', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_lg',
				'label'   => esc_html__( 'Desktops: > 1199px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for desktop device show. Default: 4', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_md',
				'label'   => esc_html__( 'Desktops: > 991px', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'This is mostly tab view.  Default: 3', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_sm',
				'label'   => esc_html__( 'Mobile View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for mobile device show. Default: 2', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'col_xs',
				'label'   => esc_html__( 'Mobile Small View', 'daisy-core' ),
				'options' => $this->rt_number_options(),
				'default' => '1',
				'description' => esc_html__( 'Select any value for small mobile device show. Default: 1', 'daisy-core' ),
			),
			array(
				'mode' => 'section_end',
			),
			//Section Title
			array(
				'id'      => 'sec_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Section Title', 'daisy-core' ),
				'condition'   => array( 'layout' => array( 'layout1', 'layout4' ) ),
			),
			array(
				'id'      => 'sec_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading__title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .section-headingFour__title' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sec_title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-heading__title, {{WRAPPER}} .section-headingFour__title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'sec_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                   
	                '{{WRAPPER}} .section-headingFour__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'sec_title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                        
	                '{{WRAPPER}} .section-headingFour__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                        
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			//Section Sub Title
			array(
				'id'      => 'sec_sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Section Sub Title', 'daisy-core' ),
				'condition'   => array( 'layout' => array( 'layout1', 'layout4' ) ),
			),
			array(
				'id'      => 'sec_sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .section-heading__sub-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .section-headingFour__sub-title' => 'color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'sec_sub_title_dot_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Dot Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .section-heading__sub-title::after' => 'border-color: {{VALUE}}',
				),
				'condition'   => array( 'layout' => array( 'layout1' ) ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sec_sub_title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-heading__sub-title, {{WRAPPER}} .section-headingFour__sub-title',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'sec_sub_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                   
	                '{{WRAPPER}} .section-headingFour__sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'mode'          => 'responsive',
	            'id'      => 'sec_sub_title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                        
	                '{{WRAPPER}} .section-headingFour__sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                        
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			//Section Description
			array(
				'id'      => 'sec_desc_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Section Description', 'daisy-core' ),
				'condition'   => array( 'layout' => array( 'layout4' ) ),
			),
			array(
				'id'      => 'sec_desc_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-headingFour p' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sec_desc_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-headingFour p',
			),
			array(
				'mode' => 'section_end',
			),
			// Icon Styles
			array(
				'id'      => 'testi_icon_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Icon', 'daisy-core' ),
			),
			array(
				'id'        => 'icon_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .quote-left path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .quote-right path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .quote path' => 'fill: {{VALUE}}',
				),
			),
			array(
				'id'        => 'iconr_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Right Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .quote-right path' => 'fill: {{VALUE}}',
				),
				'condition'   => array( 'layout' => array( 'layout1' ) ),
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .testimonial .author__name' => 'color: {{VALUE}}',  
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .testimonial .author__name',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial .author__name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                 
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial .author__name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'designation_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Designation', 'daisy-core' ),
			),
			array(
				'id'      => 'designation_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .testimonial .author__designation' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'designation_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .testimonial .author__designation',
			),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Content', 'daisy-core' ),
			),
			array(
				'id'      => 'content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'selectors' => array( 
					'{{WRAPPER}} .testimonial__text' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'content_typo',
				'label'    => __( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .testimonial__text',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'content_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial__text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'content_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .testimonial__text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                   
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			// Arrow
			array(
				'id'      => 'arrow_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Arrow', 'daisy-core' ),
				'condition'   => array( 'layout' => array( 'layout1', 'layout2', 'layout4', 'layout5' ) ),
			),
			array(
				'id'      => 'arrow_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .test-navigation__slider-btn:before' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .slider-nav--style-3 .slider-btn i' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .test-navigation__slider-btn svg path' => 'fill: {{VALUE}} !important',
					'{{WRAPPER}} .test-navigation__slider-btn svg rect' => 'fill: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'arrow_b_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .test-navigation__slider-btn' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .slider-nav--style-3 .slider-btn' => 'border-color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'arrow_bg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .test-navigation__slider-btn' => 'background-color: {{VALUE}} !important',
				),
				'condition'   => array( 'layout' => array( 'layout4' ) ),
			),
			array(
				'id'      => 'arrow_h_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'arrow_h_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .test-navigation__slider-btn:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .slider-btn:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .test-navigation__slider-btn:hover svg rect' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .test-navigation__slider-btn:hover svg path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .slider-btn:hover i' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'arrow_hbg_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Background Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .test-navigation__slider-btn:hover' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .slider-btn::after' => 'background: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'arrow_h_bcolor',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Border Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .test-navigation__slider-btn:hover' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .slider-btn:hover' => 'border-color: {{VALUE}}',
				),
			),
			array(
				'mode' => 'section_end',
			),
			// Dot
			array(
				'id'      => 'dot_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => __( 'Dot', 'daisy-core' ),
				'condition'   => array( 'layout' => array( 'layout3' ) ),
			),
			array(
				'id'      => 'dot_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .swiper-pagination-bullet::after' => 'background-color: {{VALUE}} !important',
				),
			),
			array(
				'id'      => 'dot_a_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Active', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'id'      => 'dot_a_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => __( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-color: {{VALUE}} !important',
					'{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active::after' => 'background-color: {{VALUE}} !important',
				),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	public function swiper(){
		wp_enqueue_style( 'swiper' );
		wp_enqueue_script( 'swiper' );
		wp_enqueue_script( 'swiper-func' );
	}

	protected function render() {
		$data = $this->get_settings();

		$this->swiper();

		switch ( $data['layout'] ) {
			case 'layout5':
			$template = 'view-5';
			break;
			case 'layout4':
			$template = 'view-4';
			break;
			case 'layout3':
			$template = 'view-3';
			break;
			case 'layout2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		if ( $data['layout'] == 'layout1' || $data['layout'] == 'layout2' || $data['layout'] == 'layout3' || $data['layout'] == 'layout4' || $data['layout'] == 'layout5' ) {
			$swiper_data = array(
				'col_xl'   => $data['slide_to_show'],
				'autoplay' => $data['slider_autoplay'] == 'yes' ? true : false,
				'speed'    => $data['slider_autoplay_speed'],
				'allowSlideNext' => $data['slider_arrow'] == 'yes' ? true : false,
				'allowSlidePrev' => $data['slider_arrow'] == 'yes' ? true : false,
				'col_lg'  => $data['col_lg'],
				'col_md'  => $data['col_md'],
				'col_sm'  => $data['col_sm'],
				'col_xs'  => $data['col_xs'],
			);
			$data['swiper_data'] = json_encode( $swiper_data );
		}

		return $this->rt_template( $template, $data );
	}
}