<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/title/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Background;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit;

class Title_Text_Button extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'Title Text With Button', 'daisy-core' );
		$this->rt_base = 'rt-title-text-button';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'id'      => 'sec_general',
				'mode'    => 'section_start',
				'label'   => esc_html__( 'General', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'daisy-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'daisy-core' ),
					'style2' => esc_html__( 'Style 2', 'daisy-core' ),
					'style3' => esc_html__( 'Style 3', 'daisy-core' ),
				),
				'default' => 'style1',
				'label_block' => true,
			),
			array(
            	'type'    => Controls_Manager::CHOOSE,
				'mode'	  => 'responsive',
				'id'      => 'alignment',
				'label'   => esc_html__( 'Alignment', 'fdaisy-core' ),
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'daisy-core' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'daisy-core' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'daisy-core' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .section-heading' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .section-headingTwo' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .section-headingFour' => 'text-align: {{VALUE}};',
                ],
				'default' => 'left',
            ),
			array(
				'id'      => 'title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => esc_html__( 'Section Title', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'id'      => 'sub_title',
				'type'    => Controls_Manager::TEXT,
				'label'   => esc_html__( 'Sub Title', 'daisy-core' ),
				'default' => esc_html__( 'Sub title', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'borderalign',
				'label'   => esc_html__( 'Border Alignment', 'daisy-core' ),
				'options' => array(
					'borderleft'  => esc_html__( 'Left', 'daisy-core' ),
					'bordercenter' => esc_html__( 'Center', 'daisy-core' ),
					'borderright' => esc_html__( 'Right', 'daisy-core' ),
				),
				'default' => 'borderleft',
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'name'     => 'section_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-heading__sub-title::after',
				'condition' => array( 'style' => array( 'style1' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXTAREA,
				'id'      => 'description',
				'label'   => esc_html__( 'Description', 'daisy-core' ),
				'default' => esc_html__( 'Grursus mal suada faci lisis Lorem ipsum dolarorit more a ametion consectetur elit. Ipsumm and dum fadolorit to the consectetur elit.', 'daisy-core' ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'button_display',
				'label'       => esc_html__( 'Button Display', 'daisy-core' ),
				'label_on'    => esc_html__( 'On', 'daisy-core' ),
				'label_off'   => esc_html__( 'Off', 'daisy-core' ),
				'default'     => false,
				'description' => esc_html__( 'Show or Hide Content. Default: off', 'daisy-core' ),
			),
			array(
				'type'    	  => Controls_Manager::TEXT,
				'id'      	  => 'buttontext1',
				'label'   	  => esc_html__( 'Button 1 Text', 'daisy-core' ),
				'default' 	  => esc_html__( 'Hire Me', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 'button_display' => array( 'yes' ) ),
			),
			array(
				'type'    => Controls_Manager::URL,
				'id'      => 'button1url',
				'label'   => esc_html__( 'Button 1 URL', 'daisy-core' ),
				'placeholder' => 'https://your-link.com',
				'condition'   => array( 'button_display' => array( 'yes' ) ),
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'btn1_icon',
				'label'   => esc_html__( 'Button 1 Icon', 'daisy-core' ),
				'default' => array(
			      'value' => 'far fa-envelope',
			      'library' => 'far fa-envelope',
				),
				'condition'   => array( 'button_display' => array( 'yes' ) ),
			),
			array(
				'type'    	  => Controls_Manager::TEXT,
				'id'      	  => 'buttontext2',
				'label'   	  => esc_html__( 'Button 2 Text', 'daisy-core' ),
				'default' 	  => esc_html__( 'Download Resume', 'daisy-core' ),
				'label_block' => true,
				'condition'   => array( 
					'style' => array( 'style1'), 
					'button_display' => 'yes', 
				),
			),
			array(
				'type'    => Controls_Manager::URL,
				'id'      => 'button2url',
				'label'   => esc_html__( 'Button 2 URL', 'daisy-core' ),
				'placeholder' => 'https://your-link.com',
				'condition'   => array( 
					'style' => array( 'style1'), 
					'button_display' => 'yes', 
				),
			),
			array(
				'type'    => Controls_Manager::ICONS,
				'id'      => 'btn2_icon',
				'label'   => esc_html__( 'Button 2 Icon', 'daisy-core' ),
				'default' => array(
			      'value' => 'fas fa-cloud-download-alt',
			      'library' => 'fas fa-cloud-download-alt',
				),
				'condition'   => array( 
					'style' => array( 'style1'), 
					'button_display' => 'yes', 
				),
			),
			array(
				'mode' => 'section_end',
			),
			// Sub Title
			array(
				'id'      => 'sub_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Sub Title', 'daisy-core' ),
			),
			array(
				'id'      => 'sub_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading__sub-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .section-headingTwo__sub-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .section-headingFour__sub-title' => 'color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'sub_title_b_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Border Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading__sub-title::after' => 'border-color: {{VALUE}}', 
					'{{WRAPPER}} .section-headingTwo__sub-title__bar' => 'background: {{VALUE}}', 
				),
				'condition' => array( 'style' => array( 'style1', 'style2' ) ),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'sub_title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .section-heading__sub-title,
					{{WRAPPER}} .section-headingTwo__sub-title,
					{{WRAPPER}} .section-headingFour__sub-title
				',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'sub_title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                   
	                '{{WRAPPER}} .section-headingTwo__sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                   
	                '{{WRAPPER}} .section-headingFour__sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                   
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'sub_title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                        
	                '{{WRAPPER}} .section-headingTwo__sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                        
	                '{{WRAPPER}} .section-headingFour__sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                                        
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			// Title
			array(
				'id'      => 'title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading__title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-headingTwo__title' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-headingFour__title' => 'color: {{VALUE}}', 
				),
			),			
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .section-heading__title,
					{{WRAPPER}} .section-headingTwo__title,
					{{WRAPPER}} .section-headingFour__title
				',
			),
			array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	            'id'      => 'title_padding',
	             'mode'          => 'responsive',
	            'label'   => esc_html__( 'Padding', 'daisy-core' ),
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .section-headingTwo__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	                '{{WRAPPER}} .section-headingFour__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                  
	            ),
	            'separator' => 'before',
	        ),  
	        array(
	            'type'    => Controls_Manager::DIMENSIONS,
	            'size_units' => [ 'px', '%', 'em' ],
	             'mode'          => 'responsive',
	            'id'      => 'title_margin',
	            'label'   => esc_html__( 'Margin', 'daisy-core' ),                 
	            'selectors' => array(
	                '{{WRAPPER}} .section-heading__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-headingTwo__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	                '{{WRAPPER}} .section-headingFour__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',                    
	            ),
	            'separator' => 'before',
	        ),
			array(
				'mode' => 'section_end',
			),
			array(
				'id'      => 'content_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Content', 'daisy-core' ),
			),
			array(
				'id'      => 'content_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-heading .desc1' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-headingTwo p' => 'color: {{VALUE}}', 
					'{{WRAPPER}} .section-headingFour p' => 'color: {{VALUE}}', 
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'content_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .section-heading .desc1,
					{{WRAPPER}} .section-headingTwo p,
					{{WRAPPER}} .section-headingFour p
				',
			),
			array(
				'mode' => 'section_end',
			),
			// Button style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_button1_style',
				'label'   => esc_html__( 'Button 1 Style', 'daisy-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
				'condition'   => array( 'button_display' => 'yes' ),
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'button1_typo',
				'label'   => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '
					{{WRAPPER}} .rt-btn--1,
					{{WRAPPER}} .rt-btn--7,
					{{WRAPPER}} .rt-btn--14
				',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button1_text_color',
				'label'   => esc_html__( 'Text Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-btn--1' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--7' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--14' => 'color: {{VALUE}}',
				),
			),
			array(
				'name'     => 'btn_border',
				'mode'     => 'group',
				'type'     => Group_Control_Border::get_type(),
				'label'    => __( 'Border', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .rt-btn--7',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button1_bg_color',
				'label'   => esc_html__( 'Background Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-btn--1' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--7' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--14' => 'background-color: {{VALUE}}',
				),
				'condition' => array( 'style' => array( 'style2', 'style3' ) ),
			),
			array(
				'id'      => 'btn_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button1_text_hover_color',
				'label'   => esc_html__( 'Text Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-btn--1:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--7:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--14:hover' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button1_bg_h_color',
				'label'   => esc_html__( 'Background Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-btn--1::before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--7:hover' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .rt-btn--14:hover' => 'background-color: {{VALUE}}',
				),
			),	
			array(
				'mode' => 'section_end',
			),
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_button2 _style',
				'label'   => esc_html__( 'Button 2 Style', 'daisy-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
				'condition'   => array( 
					'style' => array( 'style1'), 
					'button_display' => 'yes', 
				),
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'button2_typo',
				'label'   => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .rt-btn--2',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button2_text_color',
				'label'   => esc_html__( 'Text Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-btn--2' => 'color: {{VALUE}}',
				),
			),
			array(
				'id'      => 'btn2_heading',
				'type' => Controls_Manager::HEADING,
				'label'   => __( 'Hover', 'daisy-core' ),
				'separator' => 'before',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button2_text_hover_color',
				'label'   => esc_html__( 'Text Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-btn--2:hover' => 'color: {{VALUE}}',
				),
			),	
			array(
				'mode' => 'section_end',
			),
			// Animation style
			array(
	            'mode'    => 'section_start',
	            'id'      => 'sec_animation_style',
	            'label'   => esc_html__( 'Animation', 'daisy-core' ),
	            'tab'     => Controls_Manager::TAB_STYLE,
	        ),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation',
				'label'   => esc_html__( 'Animation', 'daisy-core' ),
				'options' => array(
					'wow'        => esc_html__( 'On', 'daisy-core' ),
					'hide'        => esc_html__( 'Off', 'daisy-core' ),
				),
				'default' => 'wow',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'animation_effect',
				'label'   => esc_html__( 'Entrance Animation', 'daisy-core' ),
				'options' => array(
                    'none' => esc_html__( 'none', 'daisy-core' ),
					'bounce' => esc_html__( 'bounce', 'daisy-core' ),
					'flash' => esc_html__( 'flash', 'daisy-core' ),
					'pulse' => esc_html__( 'pulse', 'daisy-core' ),
					'rubberBand' => esc_html__( 'rubberBand', 'daisy-core' ),
					'shakeX' => esc_html__( 'shakeX', 'daisy-core' ),
					'shakeY' => esc_html__( 'shakeY', 'daisy-core' ),
					'headShake' => esc_html__( 'headShake', 'daisy-core' ),
					'swing' => esc_html__( 'swing', 'daisy-core' ),					
					'fadeIn' => esc_html__( 'fadeIn', 'daisy-core' ),
					'fadeInDown' => esc_html__( 'fadeInDown', 'daisy-core' ),
					'fadeInLeft' => esc_html__( 'fadeInLeft', 'daisy-core' ),
					'fadeInRight' => esc_html__( 'fadeInRight', 'daisy-core' ),
					'fadeInUp' => esc_html__( 'fadeInUp', 'daisy-core' ),					
					'bounceIn' => esc_html__( 'bounceIn', 'daisy-core' ),
					'bounceInDown' => esc_html__( 'bounceInDown', 'daisy-core' ),
					'bounceInLeft' => esc_html__( 'bounceInLeft', 'daisy-core' ),
					'bounceInRight' => esc_html__( 'bounceInRight', 'daisy-core' ),
					'bounceInUp' => esc_html__( 'bounceInUp', 'daisy-core' ),			
					'slideInDown' => esc_html__( 'slideInDown', 'daisy-core' ),
					'slideInLeft' => esc_html__( 'slideInLeft', 'daisy-core' ),
					'slideInRight' => esc_html__( 'slideInRight', 'daisy-core' ),
					'slideInUp' => esc_html__( 'slideInUp', 'daisy-core' ), 
                ),
				'default' => 'fadeInUp',
				'condition'   => array('animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'delay',
				'label'   => esc_html__( 'Delay', 'daisy-core' ),
				'default' => '200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'duration',
				'label'   => esc_html__( 'Duration', 'daisy-core' ),
				'default' => '1200',
				'condition'   => array( 'animation' => array( 'wow' ) ),
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ($data['style']) {
			case 'style3':
			$template = 'view-3';
			break;
			case 'style2':
			$template = 'view-2';
			break;
			default:
			$template = 'view-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}