<?php
/**
 * This file can be overridden by copying it to yourtheme/elementor-custom/about-box/class.php
 * 
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Utils;


if ( ! defined( 'ABSPATH' ) ) exit;

class Watermark_Title extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = __( 'Watermark Title', 'daisy-core' );
		$this->rt_base = 'rt-watermark-title';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$fields = array(
			array(
				'id'      => 'sec_elements',
				'mode'    => 'section_start',
				'label'   => __( 'General', 'daisy-core' ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'default' => __( 'Services', 'daisy-core' ),
				'label_block' => true,
			),
			array(
				'type'    => Controls_Manager::HEADING,
				'id'      => 'title_position',
				'label'   => esc_html__( 'Title Position', 'daisy-core' ),
	            'separator' => 'before',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'title_horizontal_position',
				'label'   => esc_html__( 'Horizontal Position Base', 'daisy-core' ),
				'options' => array(
					'left' => esc_html__( 'Left', 'daisy-core' ),
					'right' => esc_html__( 'Right', 'daisy-core' ),
				),
				'default' => 'left',
			),
			array(
				'type' => Controls_Manager::SLIDER,
				'id'      => 'title_position_horizontal_left',
				'label'   => esc_html__( 'Horizontal Position', 'daisy-core' ),
				'size_units' => [ 'px', '%', 'vh' ],
	            'range' => [
	                'px' => [
	                    'min' => -5000,
	                    'max' => 5000,
	                    'step' => 1,
	                ],
	                '%' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	                'vh' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	            ],
	            'default' => [
	                'unit' => 'px',
	                'size' => 0,
	            ],
	            'selectors' => [
	                '{{WRAPPER}} .section-watermark--2' => 'left: {{size}}{{unit}}',
	            ],
	            'condition' => [
	                'title_horizontal_position' => 'left',
	            ],
			),
			array(
				'type' => Controls_Manager::SLIDER,
				'id'      => 'title_position_horizontal_right',
				'label'   => esc_html__( 'Horizontal Position', 'daisy-core' ),
				'size_units' => [ 'px', '%', 'vh' ],
	            'range' => [
	                'px' => [
	                    'min' => -5000,
	                    'max' => 5000,
	                    'step' => 1,
	                ],
	                '%' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	                'vh' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	            ],
	            'default' => [
	                'unit' => 'px',
	                'size' => 0,
	            ],
	            'selectors' => [
	                '{{WRAPPER}} .section-watermark--2' => 'right: {{size}}{{unit}}',
	            ],
	            'condition' => [
	                'title_horizontal_position' => 'right',
	            ],
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'title_vertical_position',
				'label'   => esc_html__( 'Vertical Position Base', 'daisy-core' ),
				'options' => array(
					'top'  => __( 'Top', 'daisy-core' ),
	                'bottom'  => __( 'Bottom', 'daisy-core' ),
				),
				'default' => 'top',
			),
			array(
				'type' => Controls_Manager::SLIDER,
				'id'      => 'title_position_vartical_top',
				'label'   => esc_html__( 'Vertical Position', 'daisy-core' ),
				'size_units' => [ 'px', '%', 'vh' ],
	            'range' => [
	                'px' => [
	                    'min' => -5000,
	                    'max' => 5000,
	                    'step' => 1,
	                ],
	                '%' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	                'vh' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	            ],
	            'default' => [
	                'unit' => 'px',
	                'size' => 0,
	            ],
	            'selectors' => [
	                '{{WRAPPER}} .section-watermark--2' => 'top: {{size}}{{unit}}',
	            ],
	            'condition' => [
	                'title_vertical_position' => 'top',
	            ],
			),
			array(
				'type' => Controls_Manager::SLIDER,
				'id'      => 'title_position_vartical_bottom',
				'label'   => esc_html__( 'Vertical Position', 'daisy-core' ),
				'size_units' => [ 'px', '%', 'vh' ],
	            'range' => [
	                'px' => [
	                    'min' => -5000,
	                    'max' => 5000,
	                    'step' => 1,
	                ],
	                '%' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	                'vh' => [
	                    'min' => -100,
	                    'max' => 100,
	                ],
	            ],
	            'default' => [
	                'unit' => 'px',
	                'size' => 0,
	            ],
	            'selectors' => [
	                '{{WRAPPER}} .section-watermark--2' => 'bottom: {{size}}{{unit}}',
	            ],
	            'condition' => [
	                'title_vertical_position' => 'bottom',
	            ],
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'title_z-index',
				'label'   => esc_html__( 'Z-Index', 'daisy-core' ),
				'min' => -500,
	            'max' => 500,
	            'step' => 1,
	            'default' => 0,
	            'selectors' => [
	                '{{WRAPPER}} .section-watermark--2' => 'z-index: {{VALUE}}',
	            ],
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'title_rotate',
				'label'   => esc_html__( 'Title Rotate', 'daisy-core' ),
				'options' => array(
					'90deg'  => __( '90 Deg', 'daisy-core' ),
	                'minus90deg'  => __( '-90 Deg', 'daisy-core' ),
				),
				'default' => 'minus90deg',
			),
			array(
				'mode' => 'section_end',
			),
			// Style
			array(
				'id'      => 'portfolio_title_style',
				'mode'    => 'section_start',
				'tab'     => Controls_Manager::TAB_STYLE,
				'label'   => esc_html__( 'Title', 'daisy-core' ),
			),
			array(
				'id'      => 'sec_title_color',
				'type'    => Controls_Manager::COLOR,
				'label'   => esc_html__( 'Color', 'daisy-core' ),
				'default' => '',
				'selectors' => array( 
					'{{WRAPPER}} .section-watermark--2' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode'     => 'group',
				'type'     => Group_Control_Typography::get_type(),
				'name'     => 'title_typo',
				'label'    => esc_html__( 'Typography', 'daisy-core' ),
				'selector' => '{{WRAPPER}} .section-watermark--2',
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'view';

		return $this->rt_template( $template, $data );
	}
}