<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use \WP_Widget;
use \RT_Widget_Fields;
use radiustheme\Daisy\inc\Helper;
use radiustheme\daisy\inc\RDTheme;

class About_Author extends WP_Widget {
	public function __construct() {
		$id = DAISY_CORE_THEME_PREFIX . '_about_author';
		parent::__construct(
            $id, // Base ID
            esc_html__( 'Daisy: Author About', 'daisy-core' ), // Name
            array( 'description' => esc_html__( 'Daisy: Author About Widget', 'daisy-core' )
        ) );
	}

	public function widget( $args, $instance ){

		echo wp_kses_post( $args['before_widget'] );

		$title = $instance['title'];
		if( !empty( $instance['author_img'] ) ){
		    $img = wp_get_attachment_image( $instance['author_img'], 'full' );
		}else{
		    $img = Helper::get_img( 'author-img.jpg' );
		    $img = "<img width='92' height='92' src='". esc_url( $img ) ."' alt='". esc_attr( get_bloginfo( 'name' ) ). "'>";
		}
		$desc  = $instance['desc'];

	    ?>
	    <div class="blog-about rounded text-center">
	    	<?php if( !empty( $img ) ) : ?>
			<figure>
				 <?php echo wp_kses( $img, 'alltext_allow' ); ?>
			</figure>
			<?php endif; ?>
			<?php if( !empty( $title ) ) : ?>
			<h3 class="blog-about__title mb-10"><?php echo wp_kses_post( $title ); ?></h3>
			<?php endif; if( !empty( $desc ) ) : ?>
			<p class="blog-about__text mb-10"><?php echo wp_kses_post( $desc ); ?></p>
			<?php endif; ?>
			
			<ul class="social social--style-5 justify-content-center pt-10">
				<?php
				if( !empty( $instance['facebook'] ) ){
					?><li class="social__item"><a class="social__link" href="<?php echo esc_url( $instance['facebook'] ); ?>" target="_blank"><i class="fab fa-facebook-f"></i></a></li><?php
				}
				if( !empty( $instance['twitter'] ) ){
					?><li class="social__item"><a class="social__link" href="<?php echo esc_url( $instance['twitter'] ); ?>" target="_blank"><i class="fab fa-twitter"></i></a></li><?php
				}
				if( !empty( $instance['linkedin'] ) ){
					?><li class="social__item"><a class="social__link" href="<?php echo esc_url( $instance['linkedin'] ); ?>" target="_blank"><i class="fab fa-linkedin-in"></i></a></li><?php
				}
				if( !empty( $instance['pinterest'] ) ){
					?><li class="social__item"><a class="social__link" href="<?php echo esc_url( $instance['pinterest'] ); ?>" target="_blank"><i class="fab fa-pinterest"></i></a></li><?php
				}
				if( !empty( $instance['youtube'] ) ){
					?><li class="social__item"><a class="social__link" href="<?php echo esc_url( $instance['youtube'] ); ?>" target="_blank"><i class="fab fa-youtube"></i></a></li><?php
				}
				if( !empty( $instance['rss'] ) ){
					?><li class="social__item"><a class="social__link" href="<?php echo esc_url( $instance['rss'] ); ?>" target="_blank"><i class="fa fa-rss"></i></a></li><?php
				}
				if( !empty( $instance['instagram'] ) ){
					?><li class="social__item"><a class="social__link" href="<?php echo esc_url( $instance['instagram'] ); ?>" target="_blank"><i class="fab fa-instagram"></i></a></li><?php
				}
				?>
			</ul>
		</div>
        <?php 
		echo wp_kses_post( $args['after_widget'] );
	}

	public function update( $new_instance, $old_instance ){
		$instance               = array();
		$instance['title']      = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['author_img'] = ( ! empty( $new_instance['author_img'] ) ) ? sanitize_text_field( $new_instance['author_img'] ) : '';
		$instance['desc']       = ( ! empty( $new_instance['desc'] ) ) ? sanitize_text_field( $new_instance['desc'] ) : '';
		$instance['facebook']   = ( ! empty( $new_instance['facebook'] ) ) ? sanitize_text_field( $new_instance['facebook'] ) : '';
		$instance['twitter']    = ( ! empty( $new_instance['twitter'] ) ) ? sanitize_text_field( $new_instance['twitter'] ) : '';
		$instance['linkedin']   = ( ! empty( $new_instance['linkedin'] ) ) ? sanitize_text_field( $new_instance['linkedin'] ) : '';
		$instance['pinterest']  = ( ! empty( $new_instance['pinterest'] ) ) ? sanitize_text_field( $new_instance['pinterest'] ) : '';
		$instance['youtube']    = ( ! empty( $new_instance['youtube'] ) ) ? sanitize_text_field( $new_instance['youtube'] ) : '';
		$instance['rss']        = ( ! empty( $new_instance['rss'] ) ) ? sanitize_text_field( $new_instance['rss'] ) : '';
		$instance['instagram']  = ( ! empty( $new_instance['instagram'] ) ) ? sanitize_text_field( $new_instance['instagram'] ) : '';

		return $instance;
	}

	public function form( $instance ){
		$defaults = array(
			'title'      => '',
			'author_img' => '',
			'desc'	     => '',
			'facebook'   => '',
			'twitter'    => '',
			'linkedin'   => '',
			'pinterest'  => '',
			'youtube'    => '',
			'rss'        => '', 
			'instagram'  => ''
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$fields = array(
			'title'       => array(
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'type'    => 'text',
			),
			'author_img'  => array(
				'label'   => esc_html__( 'Image', 'daisy-core' ),
				'type'    => 'image',
			),
			'desc'        => array(
				'label'   => esc_html__( 'Description', 'daisy-core' ),
				'type'    => 'textarea',
			),
			'facebook'    => array(
				'label'   => esc_html__( 'Facebook URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'twitter'     => array(
				'label'   => esc_html__( 'Twitter URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'linkedin'    => array(
				'label'   => esc_html__( 'Linkedin URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'pinterest'   => array(
				'label'   => esc_html__( 'Pinterest URL', 'roofix-core' ),
				'type'    => 'url',
			),
			'youtube'       => array(
				'label'   => esc_html__( 'Youtube URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'rss'         => array(
				'label'   => esc_html__( 'Rss Feed URL', 'roofix-core' ),
				'type'    => 'url',
			),
			'instagram'   => array(
				'label'   => esc_html__( 'Instagram URL', 'roofix-core' ),
				'type'    => 'url',
			),
		);

		RT_Widget_Fields::display( $fields, $instance, $this );
	}
}