<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use \WP_Widget;
use \RT_Widget_Fields;
use radiustheme\Daisy\Helper;

class Footer_Post_Widget extends WP_Widget {
	public function __construct() {
		$id = DAISY_CORE_THEME_PREFIX . '_footer_post';
		parent::__construct(
            $id, // Base ID
            esc_html__( 'Daisy: Footer Posts', 'daisy-core' ), // Name
            array( 'description' => esc_html__( 'Daisy: Footer Posts Widget', 'daisy-core' )
        ) );
	}

	public function widget( $args, $instance ){
		echo wp_kses_post( $args['before_widget'] );

		if (!empty($instance['title'])) {
        	$title = $instance['title'];
      	} else {
        	$title = '';
      	} 
		$q_args = array(
			'cat'                 => (int) $instance['cat'],
			'orderby'             => $instance['orderby'],
			'posts_per_page'      => $instance['number'],
			'ignore_sticky_posts' => true,
		);

		switch ( $instance['orderby'] ){
			case 'title':
			case 'menu_order':
			$q_args['order'] = 'ASC';
			break;
		}

		$query = new \WP_Query( $q_args );
		?>
		<?php if ( $query->have_posts() ) :?>
			<div class="widget">
				<?php if (!empty($title)) { ?>
				<h3 class="footer-widget-heading heading-light"><?php echo esc_html( $title ); ?></h3>
				<?php } ?>
				<ul class="footer-posts">
					<?php while ( $query->have_posts() ) : $query->the_post();?>
					<li class="footer-post">
						<?php if( has_post_thumbnail( ) ) : ?>
						<div class="entry-figure">
							<?php the_post_thumbnail( 'daisy-thumb-size-6' ); ?>
						</div>
						<?php endif; ?>
						<div class="entry-content">
							<div class="entry-date"><?php the_time( get_option( 'date_format' ) ); ?></div>
							<h4 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
						</div>
					</li>
					<?php endwhile;?>
				</ul>
			</div>
			<?php else: ?>
			<div><?php esc_html_e( 'Currently there are no posts to display', 'daisy-core' ); ?></div>
			<?php endif;?>
			<?php wp_reset_postdata();?>
			<?php
			echo wp_kses_post( $args['after_widget'] );
	}

	public function update( $new_instance, $old_instance ){
		$instance             = array();
		$instance['title']    = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['cat']      = ( ! empty( $new_instance['cat'] ) ) ? sanitize_text_field( $new_instance['cat'] ) : '';
		$instance['orderby']  = ( ! empty( $new_instance['orderby'] ) ) ? sanitize_text_field( $new_instance['orderby'] ) : '';
		$instance['number']   = ( ! empty( $new_instance['number'] ) ) ? sanitize_text_field( $new_instance['number'] ) : '';
		return $instance;
	}

	public function form( $instance ){
		$defaults = array(
			'title'   => '',
			'cat'     => '0',
			'orderby' => '',
			'number'  => '2',
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$categories = get_categories();
		$category_dropdown = array( '0' => __( 'All Categories', 'daisy-core' ) );

		foreach ( $categories as $category ) {
			$category_dropdown[$category->term_id] = $category->name;
		}

		$orderby = array(
			'date'        => __( 'Date (Recents comes first)', 'daisy-core' ),
			'title'       => __( 'Title', 'daisy-core' ),
			'menu_order'  => __( 'Custom Order (Available via Order field inside Page Attributes box)', 'daisy-core' ),
		);

		$fields = array(
			'title'       => array(
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'type'    => 'text',
			),
			'cat'        => array(
				'label'   => esc_html__( 'Category', 'daisy-core' ),
				'type'    => 'select',
				'options' => $category_dropdown,
			),
			'orderby' => array(
				'label'   => esc_html__( 'Order by', 'daisy-core' ),
				'type'    => 'select',
				'options' => $orderby,
			),
			'number' => array(
				'label'   => esc_html__( 'Number of Post', 'daisy-core' ),
				'type'    => 'number',
			),
		);
		RT_Widget_Fields::display( $fields, $instance, $this );
	}
}