<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use \WP_Widget;
use \RT_Widget_Fields;
use radiustheme\Daisy\Helper;

class Post_Widget extends WP_Widget {
	public function __construct() {
		$id = DAISY_CORE_THEME_PREFIX . '_post';
		parent::__construct(
            $id, // Base ID
            esc_html__( 'Daisy: Posts', 'daisy-core' ), // Name
            array( 'description' => esc_html__( 'Daisy: Posts Widget', 'daisy-core' )
        ) );
	}

	public function widget( $args, $instance ){
		echo wp_kses_post( $args['before_widget'] );

		if (!empty($instance['title'])) {
        	$title = $instance['title'];
      	} else {
        	$title = '';
      	} 
		$q_args = array(
			'cat'                 => (int) $instance['cat'],
			'orderby'             => $instance['orderby'],
			'posts_per_page'      => $instance['number'],
			'ignore_sticky_posts' => true,
		);

		switch ( $instance['orderby'] ){
			case 'title':
			case 'menu_order':
			$q_args['order'] = 'ASC';
			break;
		}

		$query = new \WP_Query( $q_args );
		?>
		<?php if ( $query->have_posts() ) :?>
			<div class="blog-post">
				<?php if (!empty($title)) { ?>
					<h3 class="blog-post__title"><?php echo esc_html( $title ); ?></h3>
				<?php } ?>
				<?php while ( $query->have_posts() ) : $query->the_post();?>
				<div class="blog-post__list">
                  <a class="blog-post__link" href="<?php the_permalink(); ?>">
                  	<?php if ( has_post_thumbnail() ) { ?>
                  	<div class="blog-post__image">
                    	<?php the_post_thumbnail( 'thumbnail' ); ?>
                  	</div>
                  	<?php } ?>
	                <div class="blog-post__content">
	                  <h3 class="blog-post__heading"><?php the_title(); ?></h3>
	                  <span class="blog-post__date"><svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
		<path d="M17.5 2H14.5V0.5C14.5 0.367392 14.4473 0.240215 14.3536 0.146447C14.2598 0.0526785 14.1326 0 14 0C13.8674 0 13.7402 0.0526785 13.6464 0.146447C13.5527 0.240215 13.5 0.367392 13.5 0.5V2H6.5V0.5C6.5 0.367392 6.44732 0.240215 6.35355 0.146447C6.25979 0.0526785 6.13261 0 6 0C5.86739 0 5.74021 0.0526785 5.64645 0.146447C5.55268 0.240215 5.5 0.367392 5.5 0.5V2H2.5C1.8372 2.00079 1.20178 2.26444 0.73311 2.73311C0.264441 3.20178 0.000793929 3.8372 0 4.5V17.5C0.000793929 18.1628 0.264441 18.7982 0.73311 19.2669C1.20178 19.7356 1.8372 19.9992 2.5 20H17.5C18.1629 19.9995 18.7985 19.7359 19.2672 19.2672C19.7359 18.7985 19.9995 18.1629 20 17.5V4.5C19.9995 3.83712 19.7359 3.20154 19.2672 2.73282C18.7985 2.26409 18.1629 2.00053 17.5 2ZM19 17.5C19 17.8978 18.842 18.2794 18.5607 18.5607C18.2794 18.842 17.8978 19 17.5 19H2.5C2.10218 19 1.72064 18.842 1.43934 18.5607C1.15804 18.2794 1 17.8978 1 17.5V9H19V17.5ZM19 8H1V4.5C1 3.672 1.67 3 2.5 3H5.5V4.5C5.5 4.63261 5.55268 4.75979 5.64645 4.85355C5.74021 4.94732 5.86739 5 6 5C6.13261 5 6.25979 4.94732 6.35355 4.85355C6.44732 4.75979 6.5 4.63261 6.5 4.5V3H13.5V4.5C13.5 4.63261 13.5527 4.75979 13.6464 4.85355C13.7402 4.94732 13.8674 5 14 5C14.1326 5 14.2598 4.94732 14.3536 4.85355C14.4473 4.75979 14.5 4.63261 14.5 4.5V3H17.5C17.8978 3 18.2794 3.15804 18.5607 3.43934C18.842 3.72064 19 4.10218 19 4.5V8Z" fill="black"/>
		</svg><?php the_time( get_option( 'date_format' ) ); ?></span>
	                </div>
                  </a>
                </div>
                <?php endwhile;?>
		   </div>
			<?php else: ?>
			<div><?php esc_html_e( 'Currently there are no posts to display', 'daisy-core' ); ?></div>
			<?php endif;?>
			<?php wp_reset_postdata();?>
			<?php
			echo wp_kses_post( $args['after_widget'] );
	}

	public function update( $new_instance, $old_instance ){
		$instance             = array();
		$instance['title']    = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['cat']      = ( ! empty( $new_instance['cat'] ) ) ? sanitize_text_field( $new_instance['cat'] ) : '';
		$instance['orderby']  = ( ! empty( $new_instance['orderby'] ) ) ? sanitize_text_field( $new_instance['orderby'] ) : '';
		$instance['number']   = ( ! empty( $new_instance['number'] ) ) ? sanitize_text_field( $new_instance['number'] ) : '';
		return $instance;
	}

	public function form( $instance ){
		$defaults = array(
			'title'   => '',
			'cat'     => '0',
			'orderby' => '',
			'number'  => '3',
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$categories = get_categories();
		$category_dropdown = array( '0' => __( 'All Categories', 'daisy-core' ) );

		foreach ( $categories as $category ) {
			$category_dropdown[$category->term_id] = $category->name;
		}

		$orderby = array(
			'date'        => __( 'Date (Recents comes first)', 'daisy-core' ),
			'title'       => __( 'Title', 'daisy-core' ),
			'menu_order'  => __( 'Custom Order (Available via Order field inside Page Attributes box)', 'daisy-core' ),
		);

		$fields = array(
			'title'       => array(
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'type'    => 'text',
			),
			'cat'        => array(
				'label'   => esc_html__( 'Category', 'daisy-core' ),
				'type'    => 'select',
				'options' => $category_dropdown,
			),
			'orderby' => array(
				'label'   => esc_html__( 'Order by', 'daisy-core' ),
				'type'    => 'select',
				'options' => $orderby,
			),
			'number' => array(
				'label'   => esc_html__( 'Number of Post', 'daisy-core' ),
				'type'    => 'number',
			),
		);
		RT_Widget_Fields::display( $fields, $instance, $this );
	}
}