<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use \WP_Widget;
use \RT_Widget_Fields;
use radiustheme\Daisy\Helper;

class Service_Widget extends WP_Widget {
	public function __construct() {
		$id = DAISY_CORE_THEME_PREFIX . '_service';
		parent::__construct(
            $id, // Base ID
            esc_html__( 'Daisy: Services', 'daisy-core' ), // Name
            array( 'description' => esc_html__( 'Daisy: Services Widget', 'daisy-core' )
        ) );
	}

	public function widget( $args, $instance ){
		echo wp_kses_post( $args['before_widget'] );

		$q_args = array(
			'post_type'           => 'daisy_service',
			'orderby'             => $instance['orderby'],
			'posts_per_page'      => $instance['number'],
			'ignore_sticky_posts' => true,
		);

		switch ( $instance['orderby'] ){
			case 'title':
			case 'menu_order':
			$q_args['order'] = 'ASC';
			break;
		}

		$query = new \WP_Query( $q_args );

		?>
		<?php if ( $query->have_posts() ) :?>
	        <div class="serviceDetails-menu">
                <ul>
                	<?php 
                		global $current_id;
                		while ( $query->have_posts() ) : $query->the_post(); 

                		$icon_type  = get_post_meta( get_the_ID(), "daisy_service_icon_type", true );
					    $icon       = get_post_meta( get_the_ID(), "daisy_service_icon", true );
					    $image_id   = get_post_meta( get_the_ID(), "daisy_service_iconimg", true );
					    $icon_image = wp_get_attachment_image( $image_id, 'full' );

                		if (get_the_ID() == $current_id ) {
                			$current_post = 'current-post';
                		} else {
                			$current_post = '';
                		}
                	?>
                	<li class="serviceDetails-menu__item">
                        <a href="<?php the_permalink(); ?>" class="serviceDetails-menu__link">
                          <?php if( $icon_type == 'image' ) { ?>
                          <span class="serviceDetails-menu__icon">
                          	<?php echo wp_kses_post( $icon_image ); ?>
                          </span>
                          <?php }else{ ?>
                          <span class="serviceDetails-menu__icon">
                          	<i class="<?php echo esc_attr( $icon ); ?>"></i>
                          </span>
                          <?php } ?>
                          <span class="serviceDetails-menu__text"><?php the_title(); ?></span>
                          <svg class="serviceDetails-menu__arrow" width="22" height="10" viewBox="0 0 22 10">
                            <g data-name="Group 565" transform="translate(-367 -742)">
                              <path data-name="Polygon 8" d="M5,0l5,8H0Z" transform="translate(389 742) rotate(90)" fill="#6b6b6b" />
                              <rect data-name="Rectangle 240" width="14" height="2" transform="translate(367 746)" fill="#6b6b6b" />
                            </g>
                          </svg>
                        </a>
                      </li>
                    <?php endwhile;?>
                </ul>
            </div>
		<?php else: ?>
			<div class="widget-service"><?php esc_html_e( 'Currently there are no posts.', 'daisy-core' ); ?></div>
		<?php endif;?>
		<?php wp_reset_postdata();?>
		<?php
		echo wp_kses_post( $args['after_widget'] );
	}

	public function update( $new_instance, $old_instance ){
		$instance             = array();
		$instance['title']    = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['orderby']  = ( ! empty( $new_instance['orderby'] ) ) ? sanitize_text_field( $new_instance['orderby'] ) : '';
		$instance['number']   = ( ! empty( $new_instance['number'] ) ) ? sanitize_text_field( $new_instance['number'] ) : '';
		return $instance;
	}

	public function form( $instance ){
		$defaults = array(
			'title'   => '',
			'orderby' => '',
			'number'  => '4',
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$orderby = array(
			'date'        => esc_html__( 'Date (Recents comes first)', 'daisy-core' ),
			'title'       => esc_html__( 'Title', 'daisy-core' ),
			'menu_order'  => esc_html__( 'Custom Order (Available via Order field inside Page Attributes box)', 'daisy-core' ),
		);

		$fields = array(
			'title'       => array(
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'type'    => 'text',
			),
			'orderby' => array(
				'label'   => esc_html__( 'Order by', 'daisy-core' ),
				'type'    => 'select',
				'options' => $orderby,
			),
			'number' => array(
				'label'   => esc_html__( 'Number of Post', 'daisy-core' ),
				'type'    => 'number',
			),
		);
		RT_Widget_Fields::display( $fields, $instance, $this );
	}
}