<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use \WP_Widget;
use \RT_Widget_Fields;
use radiustheme\Daisy\Helper;

class Sidebar_Contact extends WP_Widget {
	public function __construct() {
		$id = DAISY_CORE_THEME_PREFIX . '_sidebar_contact';
		parent::__construct(
            $id, // Base ID
            esc_html__( 'Daisy: Sidebar Contact', 'daisy-core' ), // Name
            array( 'description' => esc_html__( 'Daisy: Sidebar Contact Widget', 'daisy-core' )
        ) );
	}

	public function widget( $args, $instance ){

		echo wp_kses_post( $args['before_widget'] );
		if ( ! empty( $instance['title'] ) ) {
			echo wp_kses_post( $args['before_title'] ) . apply_filters( 'widget_title', esc_html( $instance['title'] ) ) . wp_kses_post( $args['after_title'] );
		}
		?>
		<div class="widget-contacts">
			<ul class="list-item">
				<?php if( !empty( $instance['phone'] ) ){ ?>
	            <li>
	            	<i class="fas fa-phone"></i>
	            	<a href="tel:<?php echo esc_attr( str_replace( ' ', '', $instance['phone'] ) ); ?>"><span><?php echo esc_html( $instance['phone'] ); ?></span></a>
	            </li>
	        <?php } ?>
			<?php if( !empty( $instance['email'] ) ){ ?>
	            <li>
	            	<i class="fas fa-envelope"></i>
	            	<a href="mailto:<?php echo esc_attr( $instance['email'] ); ?>"><span><?php echo esc_html( $instance['email'] ); ?></span></a>
	        	</li>
	        <?php } ?>
	        </ul>
        </div>
		<?php
		echo wp_kses_post( $args['after_widget'] );
	}

	public function update( $new_instance, $old_instance ){
		$instance              = array();
		$instance['title']     = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['phone']     = ( ! empty( $new_instance['phone'] ) ) ? sanitize_text_field( $new_instance['phone'] ) : '';
		$instance['email']     = ( ! empty( $new_instance['email'] ) ) ? sanitize_email( $new_instance['email'] ) : '';
		return $instance;
	}

	public function form( $instance ){
		$defaults = array(
			'title'   => esc_html__( 'Contacts' , 'daisy-core' ),
			'phone'   => '',
			'email'   => '',
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$fields = array(
			'title'     => array(
				'label' => esc_html__( 'Title', 'daisy-core' ),
				'type'  => 'text',
			),
			'phone'     => array(
				'label' => esc_html__( 'Phone', 'daisy-core' ),
				'type'  => 'text',
			),
			'email'     => array(
				'label' => esc_html__( 'Email', 'daisy-core' ),
				'type'  => 'text',
			),		
		);

		RT_Widget_Fields::display( $fields, $instance, $this );
	}
}