<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Daisy_Core;

use \WP_Widget;
use \RT_Widget_Fields;
use radiustheme\Daisy\Helper;

class Socials extends WP_Widget {
	public function __construct() {
		$id = DAISY_CORE_THEME_PREFIX . '_socials';
		parent::__construct(
            $id, // Base ID
            esc_html__( 'Daisy: Socials', 'daisy-core' ), // Name
            array( 'description' => esc_html__( 'Daisy: Social Widget', 'daisy-core' )
        ) );
	}

	public function widget( $args, $instance ){
		echo wp_kses_post( $args['before_widget'] );

		if ( !empty( $instance['title'] ) ) {
			$html = apply_filters( 'widget_title', $instance['title'] );
			$html = $args['before_title'] . $html .$args['after_title'];
		}
		else {
			$html = '';
		}

		echo wp_kses_post( $html );
		?>
		<div class="d-flex justify-content-center">		
			<ul class="inline-list social">
				<?php
				if( !empty( $instance['facebook'] ) ){ ?>
					<li>
						<a href="<?php echo esc_url( $instance['facebook'] ); ?>" target="_blank" class="facebook">
							<i class="fab fa-facebook-f"></i>
						</a>
					</li>
				<?php }
				if( !empty( $instance['twitter'] ) ){ ?>
					<li>
						<a href="<?php echo esc_url( $instance['twitter'] ); ?>" target="_blank" class="twitter">
							<i class="fab fa-twitter"></i>
						</a>
					</li>
				<?php }
				if( !empty( $instance['linkedin'] ) ){ ?>
					<li>
						<a href="<?php echo esc_url( $instance['linkedin'] ); ?>" target="_blank" class="linkedin">
							<i class="fab fa-linkedin-in"></i>
						</a>
					</li>
				<?php }
				if( !empty( $instance['pinterest'] ) ){ ?>
					<li>
						<a href="<?php echo esc_url( $instance['pinterest'] ); ?>" target="_blank" class="pinterest">
							<i class="fab fa-pinterest-p"></i>
						</a>
					</li>
				<?php }
				if( !empty( $instance['youtube'] ) ){ ?>
					<li>
						<a href="<?php echo esc_url( $instance['youtube'] ); ?>" target="_blank" class="youtube">
							<i class="fab fa-youtube"></i>
						</a>
					</li>
				<?php }
				if( !empty( $instance['rss'] ) ){ ?>
					<li>
						<a href="<?php echo esc_url( $instance['rss'] ); ?>" target="_blank" class="rss">
							<i class="fa fa-rss"></i>
						</a>
					</li>
				<?php }
				if( !empty( $instance['instagram'] ) ){ ?>
					<li>
						<a href="<?php echo esc_url( $instance['instagram'] ); ?>" target="_blank" class="instagram">
							<i class="fab fa-instagram"></i>
						</a>
					</li>
				<?php } ?>
			</ul>
		</div>
		<?php
		echo wp_kses_post( $args['after_widget'] );
	}

	public function update( $new_instance, $old_instance ){
		$instance                  = array();
		$instance['title']         = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['facebook']      = ( ! empty( $new_instance['facebook'] ) ) ? sanitize_text_field( $new_instance['facebook'] ) : '';
		$instance['twitter']       = ( ! empty( $new_instance['twitter'] ) ) ? sanitize_text_field( $new_instance['twitter'] ) : '';
		$instance['linkedin']      = ( ! empty( $new_instance['linkedin'] ) ) ? sanitize_text_field( $new_instance['linkedin'] ) : '';
		$instance['pinterest']     = ( ! empty( $new_instance['pinterest'] ) ) ? sanitize_text_field( $new_instance['pinterest'] ) : '';
		$instance['youtube']     = ( ! empty( $new_instance['youtube'] ) ) ? sanitize_text_field( $new_instance['youtube'] ) : '';
		$instance['rss']           = ( ! empty( $new_instance['rss'] ) ) ? sanitize_text_field( $new_instance['rss'] ) : '';
		$instance['instagram']     = ( ! empty( $new_instance['instagram'] ) ) ? sanitize_text_field( $new_instance['instagram'] ) : '';
		return $instance;
	}

	public function form( $instance ){
		$defaults = array(
			'title'         => '',
			'facebook'      => '',
			'twitter'       => '',
			'linkedin'      => '',
			'pinterest'     => '',
			'youtube'       => '',
			'rss'           => '', 
			'instagram'     => ''
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$fields = array(
			'title'       => array(
				'label'   => esc_html__( 'Title', 'daisy-core' ),
				'type'    => 'text',
			),
			'facebook'    => array(
				'label'   => esc_html__( 'Facebook URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'twitter'     => array(
				'label'   => esc_html__( 'Twitter URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'linkedin'    => array(
				'label'   => esc_html__( 'Linkedin URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'pinterest'   => array(
				'label'   => esc_html__( 'Pinterest URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'youtube'       => array(
				'label'   => esc_html__( 'Youtube URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'rss'         => array(
				'label'   => esc_html__( 'Rss Feed URL', 'daisy-core' ),
				'type'    => 'url',
			),
			'instagram'   => array(
				'label'   => esc_html__( 'Instagram URL', 'daisy-core' ),
				'type'    => 'url',
			),
		);

		RT_Widget_Fields::display( $fields, $instance, $this );
	}
}